//      Macro used frpm mapfleet.pov to define objects or values        //  



// Persistence of Vision Ray Tracer Scene Include File
// File: sunpos.inc
// Desc: This macro returns the suns position,          
//       on a given date, time, and location on earth.  
// Date: 15-09-1998
// Updated : 2001-07-27
// Auth: Ingo Janssen
//
// ====================================================== 
//
// Assumption: in the scene north is in the +Z direction, south is -Z.
//
// Invoke in your scene:
//   light_source {
//      SunPos(Year, Month, Day, Hour, Minute, Lstm, LAT, LONG)
//      rgb 1
//   }
//
// Greenwich, noon on the longest day of 2000 (no daylight saving):
//   SunPos(2000, 6, 21, 12, 2, 0, 51.4667, 0.00) 
//
// Year:  in four digits
// Month: number
// Dat:   number
// Time:  in 24 hour format
// Lstm:  Meridian of your local timezone (+1 hour =  +15 deg)
//        in degrees (east = positive, west = negative)
// Location on earth: 
// LAT:   Lattitude in degrees.decimal, northern hemisphere = positive, southern = negative
// LONG:  Longitude in degrees.decimal, east = positive, west is negative
//
// The macro returns the position of the sun, but also declares it as the vector SolarPosition. 
// Also the found Azimuth (Az) and Altitude (Al) are declared, this can be usefull for 
// aligning an object with the sunlight: cylinder{
//                                          <-2,0,0>,<2,0,0>,0.1
//                                          rotate <0, Az-90, Al>
//                                          texture {.. LightRay ..}
//                                        }
//
// ======================================================
//
// Find your local position at http://gnpswww.nima.mil/geonames/GNS/ (Gazetteer search)
//
// Local time(zone) at http://www.hilink.com.au/times/
//
// Equations used here can be found at http://hotel04.ausys.se/pausch/english.htm (Computing rise/set times)
//  not only for the sun but also for the moon, planets and other stuff up there.
//
// ======================================================
//

#macro SunPos6(Year, Month, Day, Hour, Minute, Lstm, LAT, LONG)
//SunPos6 (copy of sunpos with smaller distance to use a skysphere)

   #if (abs(LONG-Lstm)>30)
       #debug "\nREMARK: \nLongitude differs by more than 30 degrees from timezone meridian.\n"
       #debug concat("Local timezone meridian is:",str(Lstm,5,0),"\n")
       #debug concat("Longitude is:",str(LONG,5,0),"\n")
   #end
   
       // Calculate universal time (UT)
   #local T= Hour+(Minute/60);
   #local UT= T-Lstm/15;
   #if (0>UT)
       #local Day= Day-1;
       #local UT= 24+UT;
   #end
   #if (UT>24)
       #local Day= Day+1;
       #local UT= UT-24;
   #end
   
       // Amount of days to, or from, the year 2000
   #local d= 367*Year-int((7*int((Year+int((Month+9))/12)))/4)+int((275*Month)/9)+Day-730530+UT/24;
   
       // Longitude of perihelion (w), eccentricity (e)
   #local w= 282.9404+4.70935E-5*d;
   #local e= 0.016709-1.151E-9*d;
   
       // Mean anomaly (M), sun's mean longitude (L)
   #local M= 356.0470+0.9856002585*d;
   #if (0<M<360)
       #local M= M-floor(M/360)*360;
   #end
   #local L= w+M;
   #if (0<L<360)
       #local L= L-floor(L/360)*360;
   #end
   
       // Obliquity of the ecliptic, eccentric anomaly (E)
   #local oblecl= 23.4393-3.563E-7*d;
   #local E= M+(180/pi)*e*sin(radians(M))*(1+e*cos(radians(M)));
   
       // Sun's rectangular coordinates in the plane of ecliptic (A,B)
   #local A= cos(radians(E))-e;
   #local B= sin(radians(E))*sqrt(1-e*e);
   
       // Distance (r), true anomaly (V), longitude of the sun (lon)
   #local r= sqrt(A*A+B*B);
   #local V= degrees(atan2(radians(B),radians(A)));
   #local lon= V+w;
   #if (0<lon<360)
       #local lon= lon-floor(lon/360)*360;
   #end
   
       // Calculate declination (Decl) and right ascension (RA)
   #local Decl= degrees(asin(sin(radians(oblecl))*sin(radians(lon))));
   #local RA= degrees(atan2(sin(radians(lon))*cos(radians(oblecl)),cos(radians(lon))))/15;
   
       // Greenwich meridian siderial time at 00:00 (GMST0),siderial time (SIDTIME), hour angle (HA)
   #local GMST0= L/15+12;
   #local SIDTIME= GMST0+UT+LONG/15;
   #local HA= (SIDTIME-RA)*15;
   
       // This is what we're looking for: Altitude & Azimuth
   #declare Al= degrees(asin(sin(radians(LAT))*sin(radians(Decl))+cos(radians(LAT))*cos(radians(Decl))*cos(radians(HA))));
   #declare Az= degrees(atan2(sin(radians(HA)),cos(radians(HA))*sin(radians(LAT))-tan(radians(Decl))*cos(radians(LAT))))+180;
   
   #declare SolarPosition=vrotate(<0,0,10000000>,<-Al,Az,0>);
   (SolarPosition)

#end   //SunPos6 (copy of sunpos with smaller distance to use a skysphere)

      


#macro distinatmos(earth_ray,atmos_height,Al)  
//it is based on the equation giving the 3rd length  of a triangle

        // Al is the altitude of sun between -90 and 90

        //this is the angle between the sun ray o this place and this place to center earth
        #local ka=(90+Al)*pi/180;
        //#debug concat("ka is:",str(ka,10,10),"\n") 

        // 
        #local atmos_ray = earth_ray + atmos_height;
        //#debug concat("atmosray is:",str(atmos_ray,10,10),"\n")
        #local a=1;
        #local b= -2 * earth_ray * cos(ka); 
        #local c= earth_ray*earth_ray - atmos_ray*atmos_ray;

        #local delta = b*b-4*a*c;
        //#debug concat("b is:",str(b,10,10),"\n")
        //#debug concat("c is:",str(c,10,10),"\n")
        //#debug concat("delta is:",str(delta,10,0),"\n")

        #local sol1= (-b + sqrt(delta)) / 2;
        #local sol2= (-b - sqrt(delta)) / 2;

        //#debug concat("sol 1  :",str(sol1,10,10),"\n")
        //#debug concat("sol 2  :",str(sol2,10,10),"\n")

        #declare distin = sol1;
        (distin)
#end  //Macro distinatmos  


//Macro giving the radius of inner and outer circle of a triangle
//Both end of RWidth and middle point height 
#macro getRC(RWidth,MHeight)  
        #local d = 180;
        #local a = RWidth;
        #local b = sqrt((a/2)*(a/2)+ MHeight * MHeight);
        #local c = b;  
        #debug concat("W   :",str(RWidth ,10,10),"\n")
        #debug concat("H   :",str(MHeight ,10,10),"\n")
        
        //#debug concat("b   :",str(b ,10,10),"\n")
        
        #local p = (a+b+c)/2;
        #local s = sqrt(p*(p-a)*(p-b)*(p-c));        
        
        #declare ri = s/p;
        
        #declare aa = 2*d/pi*atan(ri/(p-a));
        #debug concat("aa   :",str(aa ,10,10),"\n")
        
        #declare bb = 2*d/pi*atan(ri/(p-b)); 
        #debug concat("bb   :",str(bb ,10,10),"\n")
        
        #declare cc = 2*d/pi*atan(ri/(p-c));
        #debug concat("cc   :",str(cc ,10,10),"\n")
        
        #declare rc = a/(2*sin(aa*pi/d)); 
        #debug concat("rc   :",str(rc ,10,10),"\n")
        
        #declare  teta = acos((rc-MHeight)/rc)*2*d/pi;
        #declare rcteta =<rc,teta>;
        #debug concat("teta   :",str(teta ,10,10),"\n")
         
        (rcteta)

#end //macro GetRC       



//Macro giving the coordinates of vertical cylinder joining to points giving
//a wished stickout
#macro getRCAll (pntA,pntB,stickOut)

        //(RWidth,MHeight)        
        
        
 #local antizero = .0000001;
        
        
        #local antizero = .0001;
        #local dPnt = sqrt((pntB.u-pntA.u)*(pntB.u-pntA.u)+(pntB.v-pntA.v)*(pntB.v-pntA.v));
        #if (pntB.v >= pntA.v)
                #local AngleRad =  acos((pntB.u-pntA.u)/dPnt);
        #else
                #local AngleRad =  acos(-(pntB.u-pntA.u)/dPnt) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        
        
                
        #local d = 180;
        #local a = dPnt;
        #local b = sqrt((a/2)*(a/2)+ stickOut * stickOut);
        #local c = b;  
        #debug concat("W   :",str(dPnt ,10,10),"\n")
        #debug concat("H   :",str(stickOut ,10,10),"\n")
        
        #debug concat("b   :",str(b ,10,10),"\n")
        
        #local p = (a+b+c)/2;
        #local s = sqrt(p*(p-a)*(p-b)*(p-c));        
        
        #declare ri = s/p;
        
        #declare aa = 2*d/pi*atan(ri/(p-a));
        #debug concat("aa   :",str(aa ,10,10),"\n")
        
        #declare bb = 2*d/pi*atan(ri/(p-b)); 
        #debug concat("bb   :",str(bb ,10,10),"\n")
        
        #declare cc = 2*d/pi*atan(ri/(p-c));
        #debug concat("cc   :",str(cc ,10,10),"\n")
        
        #declare rc = a/(2*sin(aa*pi/d)); 
        #debug concat("rc   :",str(rc ,10,10),"\n") 
        
        #local uMid = (pntB.u+pntA.u)/2; 
        #local vMid = (pntB.v+pntA.v)/2; 
        
        #local uCtr = uMid + (rc-stickOut) * cos(pi/2 + AngleRad);
        #local vCtr = vMid + (rc-stickOut) * sin(pi/2 + AngleRad);
        
        #declare  teta = acos((rc-stickOut)/rc)*2*d/pi;
        #declare coordCyl =<uCtr,vCtr,rc,teta>;
        #debug concat("teta   :",str(teta ,10,10),"\n")
        #debug concat("rc   :",str(rc ,10,10),"\n")
        #debug concat("uCtr   :",str(uCtr ,10,10),"\n")
        #debug concat("vCtr   :",str(vCtr ,10,10),"\n") 
        //cylinder {<uCtr,0,vCtr>,<uCtr,200,vCtr>,rc}
        (coordCyl)

#end //macro GetRCAll

//Macro giving the coordinates of vertical cylinder joining to points giving
//a wished stickout
#macro getRCAll2 (pntA,pntB,stickOut)

        //(RWidth,MHeight)        
        
        
 #local antizero = .0000001;
        
        
        
        #local dPnt = pntB-pntA;
        
        
        
                
        #local d = 180;
        #local a = dPnt;
        #local b = sqrt((a/2)*(a/2)+ stickOut * stickOut);
        #local c = b;  
        //#debug concat("W   :",str(dPnt ,10,10),"\n")
        //#debug concat("H   :",str(stickOut ,10,10),"\n")
        
        //#debug concat("b   :",str(b ,10,10),"\n")
        
        #local p = (a+b+c)/2;
        #local s = sqrt(p*(p-a)*(p-b)*(p-c));        
        
        #declare ri = s/p;
        
        #declare aa = 2*d/pi*atan(ri/(p-a));
        //#debug concat("aa   :",str(aa ,10,10),"\n")
        
        #declare bb = 2*d/pi*atan(ri/(p-b)); 
        //#debug concat("bb   :",str(bb ,10,10),"\n")
        
        #declare cc = 2*d/pi*atan(ri/(p-c));
        //#debug concat("cc   :",str(cc ,10,10),"\n")
        
        #declare rc = a/(2*sin(aa*pi/d)); 
        //#debug concat("rc   :",str(rc ,10,10),"\n") 
        
        #local pMid = (pntB+pntA)/2; 
         
        
        #local uCtr = pMid;
        #local vCtr = rc-stickOut;
        
        #declare  teta = acos((rc-stickOut)/rc)*2*d/pi;
        #declare coordCyl =<uCtr,vCtr,rc,teta>;
        //#debug concat("teta   :",str(teta ,10,10),"\n")
        //#debug concat("rc   :",str(rc ,10,10),"\n")
        //#debug concat("uCtr   :",str(uCtr ,10,10),"\n")
        //#debug concat("vCtr   :",str(vCtr ,10,10),"\n") 
        //cylinder {<uCtr,0,vCtr>,<uCtr,200,vCtr>,rc}
        (coordCyl)

#end //macro GetRCAll2        

#macro getLogia01(lAngleRef,wPntA,wPntB,lDeepth)
        //gives back the coordinates of front point and side width of a logia from a wished deepth and width at main wall
        //lAngleRef is the internal angle between sides and main wall
        //wPntA is the starting point on  main wall level
        //wPntB is the ending point on  main wall level
        //lDeepth is the wished distance between both faces  

       #local lSide = lDeepth/sin(lAngleRef*pi/180);
       #local dPntA = wPntA + lSide * cos(lAngleRef*pi/180);
       #local dPntB = wPntB - lSide * cos(lAngleRef*pi/180);
       
       #local retour = <lSide,dPntA,dPntB>; 
        #debug concat("lSide   :",str(lSide ,10,10),"\n")
        #debug concat("dPntA   :",str(dPntA ,10,10),"\n")
        //#debug concat("lSide   :",str(lSide ,10,10),"\n")
       (retour)

#end
#macro makeFrontShop(arcCyl,radCyl,nPane,hPane,npx,npy,thframe,thbp,perfactor,typeframe,typepatch)
  #local angleface = arcCyl/nPane;
  #local wPane = 2 * radCyl * sin (angleface*pi/360);
  #local tzPane = radCyl * cos (angleface*pi/360);
  
  #local indPane = 0;
  union {
  #while (indPane < nPane)
       #local randseq = nPane+hPane+indPane+thframe;
       #local spx=0;
       #local spy=0;
       #local swx=wPane+thframe;
       #local swy=hPane; 
       object {britwindowpanel(npx,npy,spx,spy,swx,swy,thframe,thbp,perfactor,Tframe,typepatch,randseq)
       //box {<0,0,0>,<wPane,hPane,1>
            translate <-wPane/2,0,-tzPane+thframe/2>
            rotate -y * (angleface/2+angleface*indPane-arcCyl/2)
       } 
       
       

       
       
       #local indPane = indPane + 1;
  #end
  }
#end 



#macro toise (difamb, eMin, eMax, pOrg, dAxe, uLng, subDiv1, subDiv2, subDiv3, fEc, rToise, sMode) 
/*
#declare difamb = <.9,.1>;   // Sete diffuse ambient ration for easier view
#declare eMin = 0;           // Min end point for the gauge
#declare eMax = 500;         // Max end point for the gauge
#declare pOrg=<0,0,0>;       // Select the coordinates of point 0 aof the gauge
#declare pExt=<0,1,0>;       // Select the coorsinate of the check point on the gauge
                             // This point and pOrg will define the geauge orientation
                             // The distance between these two points and the rotation angle are displayed in message tab
                             
#declare dAxe=pExt-pOrg;     //
#declare uLng=1;             // 1 meter 2 feets
#declare subDiv1 = 2;  // How much subdiv1 in uLng
#declare subDiv2 = 5;  // How much subdiv2 in subdiv1
#declare subDiv3 = 1;  // How much subdiv3 in subdiv2
#declare fEc = 1;      // Scale factor 1 gives 1 pixel p cm. .01 would give 100 pixels per cm
#declare rToise = 3;   // radius of the gauge     
#declare sMode = 0;     // Mode 0 fast endering with 2 stripe per smaller division
                        // Mode 1 for fine graduation with 3 subdivision levels (quite longer rendering...)


object {toise (difamb, eMin, eMax, pOrg, dAxe, uLng, subDiv1, subDiv2, subDiv3, fEc, rToise, sMode)
        translate <(100+120)/2,altSW,(-70-160)/2>
}    
*/    
            #local antizero = .0000001;
        
        
        #local Hypy = sqrt((dAxe.x)*(dAxe.x)+(dAxe.z)*(dAxe.z));
        #if (dAxe.z <= 0)
                #local AngleRady =  acos((dAxe.x)/(Hypy+antizero));
        #else
                #local AngleRady =  acos(-(dAxe.x)/(Hypy+antizero)) + pi;
        #end     
        
        #local Hypz = sqrt((dAxe.y)*(dAxe.y)+(Hypy)*(Hypy));
        #local AngleRadz =  asin(dAxe.y/(Hypz+antizero));
        #local Degz = AngleRadz * 180/pi; 
        
        
        #local Degy = AngleRady * 180/pi;
             
            #debug concat("+++++++++++ toise ","")
            #if (uLng=1)
                #debug concat("Unit meter","\n")
                #declare vU  = 100 * fEc;
                
                 
            #end  
            #if (uLng=2) 
                #debug concat("Unit foot","\n")
                #declare vU  = 30 * fEc; 
                 
            #end  
            
            
            #debug concat("dx   :",str(dAxe.x ,10,10),"\n")
            #debug concat("dy   :",str(dAxe.y ,10,10),"\n")
            #debug concat("dz   :",str(dAxe.z ,10,10),"\n")
            #debug concat("A z   :",str(Degz ,10,10),"\n")
            #debug concat("A y   :",str(Degy ,10,10),"\n")
            #debug concat("Origin to Ext   :",str(Hypz ,10,10),"\n")
            
            #declare vU1 = vU/subDiv1;
            #declare vU2 = vU1/subDiv2;
            #declare vU3 = vU2/subDiv3;
            
            #if (sMode<3)   
                    #declare pigmenttoisep = pigment {
                        gradient x
                        color_map{
                                [0.0 color Yellow]
                                [0.5 color Yellow]
                                [0.5 color Red]
                                [1.0 color Red]
                        }
        
                     }
                     #declare pigmenttoisem = pigment {
                        gradient x
                        color_map{
                                [0.0 color Cyan]
                                [0.5 color Cyan]
                                [0.5 color Blue]
                                [1.0 color Blue]
                        }
        
                     }
             #else 
                  #declare pigmenttoisep = pigment{Yellow}
                  #declare pigmenttoisem = pigment {Cyan}
             #end
             
            intersection {
            cylinder{<eMin,0,0>,<eMax,0,0>,rToise*3
                         
                        

                   }
            
            union { 
                    #if (eMax != 0)
                    cylinder{<0,0,0>,<eMax,0,0>,rToise
                        texture { 
                             pigment {pigmenttoisep scale vU3} 
                             finish {ambient difamb.v diffuse difamb.u}
                        } 
                        

                   }
                   #end
                   #if (eMin != 0) 
                   cylinder{<0,0,0>,<eMin,0,0>,rToise
                        texture { 
                             pigment {pigmenttoisem scale vU3} 
                             finish {ambient difamb.v diffuse difamb.u}
                        } 
                        

                   }
                   #end
                   sphere{<0,0,0>,1 scale <rToise/2,rToise*2,rToise*2>
                        texture { 
                             pigment {Red} 
                             finish {ambient difamb.v diffuse difamb.u}
                        } 
                        

                   }
                   #if (sMode=1) //Fine graduation mode 
                           #declare ind=vU;
                           #while (ind <= eMax) 
                                #if (ind >= eMin)
                                   cylinder {<0,0,0>,<-1,0,0>,1 scale <rToise/4,rToise*2,rToise*2>
                                        texture { 
                                             pigment {Gray20} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind+vU;
                                
                           #end  
                           
                           #declare ind=-vU;
                           #while (ind >= eMin) 
                                #if (ind <= eMax)
                                   cylinder {<0,0,0>,<-1,0,0>,1 scale <rToise/4,rToise*2,rToise*2>
                                        texture { 
                                             pigment {Black} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind-vU;
                                
                           #end
                           
                           #declare ind=vU1;
                           #while (ind <= eMax) 
                                #if (ind >= eMin)
                                   cylinder {<-0.0001,0,0>,<-.9999,0,0>,1 scale <rToise/6,rToise*1.6,rToise*1.6>
                                        texture { 
                                             pigment {Gray40} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind+vU1;
                                
                           #end  
                           
                           #declare ind=-vU1;
                           #while (ind >= eMin) 
                                #if (ind <= eMax)
                                   cylinder {<-0.0001,0,0>,<-.9999,0,0>,1 scale <rToise/6,rToise*1.6,rToise*1.6>
                                        texture { 
                                             pigment {Gray20} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind-vU1;
                                
                           #end
                           
                           //////////////vU2
                           #declare ind=vU2;
                           #while (ind <= eMax) 
                                #if (ind >= eMin)
                                   cylinder {<-0.001,0,0>,<-.999,0,0>,1 scale <rToise/7,rToise*1.2,rToise*1.2>
                                        texture { 
                                             pigment {Gray60} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind+vU2;
                                
                           #end  
                           
                           #declare ind=-vU2;
                           #while (ind >= eMin) 
                                #if (ind <= eMax)
                                   cylinder {<-0.001,0,0>,<-.999,0,0>,1 scale <rToise/8,rToise*1.2,rToise*1.2>
                                        texture { 
                                             pigment {Gray40} 
                                             finish {ambient difamb.v diffuse difamb.u}
                                        } 
                                   translate x*ind     
                
                                   } 
                                #end  
                                //#debug concat("ind   :",str(ind ,10,10),"\n")
                                #declare ind=ind-vU2;
                                
                           #end             
                           
                   #end // fine graduatins when sMode=1
                   }//intersection
                   
                   
                   
                   
                   rotate z*Degz
                   rotate y*Degy
                   translate pOrg 
            }
#end //toise



#macro britwindowpanel(npx,npy,spx,spy,swx,swy,thframe,thbp,perfactor,Tframe,typepatch,randseq)
        //npx is the number of patch along x (width) MANDATORY >= 1
        //npy is the number of patch along y (height) MANDATORY >= 1 
        
        //spx is the size of a patch along x, if this value is >=0, it will be calculated from swx and spx + thframe + thpp * (npx +1)
        //spy is the size of a patch along y, if this value is >=0, it will be calculated from swy and spy + thframe + thpp * (npy +1)
        
        //swx is the total size of window along x, if this value is >=0, it will be calculated from nwx and spx - (thframe + thpp * (npx +1))
        //swy is the total size of window along y, if this value is >=0, it will be calculated from nwy and spy - (thframe + thpp * (npy +1))
        
        //thframe is the thickness of external frame for the panel
        //thbp is the distance between each patch (internal patch frames)
        
        //perfactor if 1 som random values will give an handmade touch
        
        //typeframe will determine texture and shapes for the frame
        //type patch will determine textures and states for the patches
        
        #if ((npx <= 0) |  (npy <= 0))// The macro can't work without number of patches
             #debug concat("The number of patches must be defined on width and height","\n")
        #else  // calculate the dimensions
             // dimensions along width
             #if (swx > 0) // Priority is given to the total size of window
                  #debug concat("building a panel upon total width of ",str(swx,10,10)," cm \n")
                  #local x_minus_frame  = swx - (2 * thframe);
                  # declare spx = (x_minus_frame - thbp*npx) / npx;
                  #debug concat("   with ",str(npx,10,0)," patches of ",str(spx,10,10)," cm width\n")
             #else 
                  #if (spx > 0)  // Then use the size and number of patches to calculate total size
                       #debug concat("building a panel with ",str(npx,10,0)," patches of ",str(spx,10,10)," cm along width","\n") 
                       # declare swx = npx*spx + npx*thbp + 2*thframe; 
                       #debug concat("   having total width of ",str(swx,10,10)," cm \n")
                  #else
                       #debug concat("both width of window and patches are missing...","\n")
                  #end // calculation of total width
             #end  // calculation of patch width
             
             //dimensions along height
             #if (swy > 0) // Priority is given to the total size of window
                  #debug concat("total height of ",str(swy,10,10)," cm \n")
                  #local y_minus_frame  = swy - (2 * thframe);
                  # declare spy = (y_minus_frame - thbp*npy) / npy;
                  #debug concat("   with ",str(npy,10,0)," patches of ",str(spy,10,10)," cm height\n")
             #else 
                  #if (spy > 0)  // Then use the size and number of patches to calculate total size
                       #debug concat("with ",str(npy,10,0)," patches of ",str(spy,10,10)," cm along height","\n") 
                       # declare swy = npy*spy + npy*thbp + 2*thframe; 
                       #debug concat("   having total height of ",str(swy,10,10)," cm \n") 
                  #else
                       #debug concat("both height of panel and patches are missing...","\n")
                  #end // calculation of total size
             
             #end  // calculation of patch size
             #local thpatch = thbp / 5;
        #end  // calculation of values
        
        
        
        #local int_frame_v = intersection  {
                box {
                    <-.5,-.5,0><.5,.5,1> 
                    
                    rotate z*45
                }
                box {
                    <-.5,-.5,0><.5,.5,1> 
                    
                }     
                  
                texture {Tframe rotate <-1,1,0>}
                scale <thbp,thbp,y_minus_frame>
                rotate -x*90 
        }
        
        #local int_frame_h = intersection  {
                box {
                    <-.5,-.5,0><.5,.5,1> 
                    
                    rotate z*45
                }
                box {
                    <-.5,-.5,0><.5,.5,1> 
                    
                }     
                  
                texture {Tframe rotate <-1,1,0>}
                scale <thbp,thbp,x_minus_frame>
                rotate y*90 
        }   
        
        #local ext_frame_h = difference {
                intersection {
                        box {
                            <-.5,-.5,0>,<.5,.5,swx/thframe> 
                        }
                        #local chanfr=1.25;
                        box {
                            <-.5*chanfr,-.5*chanfr,0><.5*chanfr,.5*chanfr,swx/thframe>
                            rotate z * 45 
                        }
                } 
                box {
                    <-.6,0,0>,<.6,2,-1>
                    rotate x * 45
                    translate -y*0.5
                }
                box {
                    <-.6,0,0>,<.6,2,1>
                    rotate -x * 45
                    translate -y*0.5
                    translate z*swx/thframe
                }
                texture {Tframe rotate <-1,1,0>}
                scale thframe
                rotate y*90 
                translate <-thframe,-thframe/2,0>        
                
         }//difference ext_frame_h 
        
        #local ext_frame_v = difference {
                intersection {
                        box {
                            <-.5,-.5,0>,<.5,.5,swy/thframe> 
                        }
                        #local chanfr=1.25;
                        box {
                            <-.5*chanfr,-.5*chanfr,0><.5*chanfr,.5*chanfr,swy/thframe>
                            rotate z * 45 
                        }
                }  
                box {
                    <-.6,0,0>,<.6,2,-1>
                    rotate x * 45
                    translate -y* .5
                }
                box {
                    <-.6,0,0>,<.6,2,1>
                    rotate -x * 45
                    translate -y* .5//thframe/2
                    translate z*swy/thframe
                }
                texture {Tframe rotate <-1,1,0>}
                //texture {pigment {rgb <1,1,.5>}}
                scale thframe
                rotate -z*90
                rotate -x*90 
                translate <-thframe/2,-thframe*sqrt(1),0>
        }//difference ext_frame_v    
        
        
        
        
        
        
        #local RP = seed(randseq);
        #local frame = union { 
                #local index = 0;
                #while  (index <= npx)
                      object {int_frame_v translate x * index * (spx+thbp) } 
                      #local index = index +1;  
                #end // vertical sticks
                #local index = 0;
                #while  (index <= npy)
                      object {int_frame_h translate y * index * (spy+thbp) } 
                      #local index = index +1;  
                #end // horizontal sticks
                
                
                #local  SupaleVtr = 1/5;      
                #local flgcrd = 0;
                #local roulette = rand(RP);
                #if (roulette < SupaleVtr )  
                        #local flgcrd = 1; 
                #end
                        
                 
                #if (perfactor = 1 | typepatch=2 | typepatch=3)
                        #declare Ipatch = interior { 
                             ior 1.5 // Glass refraction
                         }
                        #local indexH = 0;
                        #while  (indexH < npx)
                                #local indexV = 0;
                                #while  (indexV < npy)
                                        #if (typepatch=1)
                                                #declare Tpatch = texture {
                                                         pigment { 
                                                             //rgbt <0.45+rand(RP)/7, 0.50+rand(RP)/7, 0.5+rand(RP)/10, 0.95+rand(RP)/7>
                                                             //rgbt <0.25+rand(RP)/7, 0.30+rand(RP)/7, 0.3+rand(RP)/10, 0.95+rand(RP)/7>
                                                             //rgbt <0.10+rand(RP)/7, 0.12+rand(RP)/7, 0.13+rand(RP)/10, 0.98+rand(RP)/7>
                                                             rgbt <0.04+rand(RP)/7, 0.06+rand(RP)/7, 0.075+rand(RP)/10, 0.88+rand(RP)/7>
                                                             //rgbt <1,1,1,0>
                                                         } 
                                                         finish   { 
                                                             phong 0.07 phong_size 40  // A highlight
                                                             reflection { 0.22, rgb <1,0.8,0.9> * 0.77}  // Glass reflects a bit
                                                             //ambient 0
                                                             //diffuse 0
                                                             //reflection {1,1}
                                                         }
                                                         
                                                         normal { 
                                                             bumps 0.02+rand(RP)/10 scale <10,10,.3> 
                                                         }    
                                                         
                                                          
                                                }
                                
                                                
                                                
                                                
                                                
                                                box {
                                                     <0-thpatch,0-thpatch,0>,<spx+thpatch,spy+thpatch,thpatch >
                                                     texture {Tpatch} 
                                                     interior {Ipatch}
                                                     rotate <rand(RP)-.5,rand(RP)-.5,rand(RP)-.5>
                                                     translate <thbp/2+(thbp+spx)*indexH,thbp/2+(thbp+spy)*indexV,thpatch/2>
                                                } 
                                                #local indexV = indexV+1;
                                        #end // patch=1 vitre
                                        
                                        #if (typepatch=2)
                                                #declare Tpatch = texture {Tframe rotate <-1,1,0> scale <2,30,.2>}
                                
                        
                                                
                                                
                                                
                                                box {
                                                     <0,0,0>,<spx,spy,thpatch >
                                                     texture {Tpatch} 
                                                     interior {Ipatch}
                                                     rotate <rand(RP)-.5,rand(RP)-.5,rand(RP)-.5>
                                                     translate <thbp/2+(thbp+spx)*indexH,thbp/2+(thbp+spy)*indexV,thpatch/2>
                                                } 
                                                #local indexV = indexV+1;
                                        #end // patch=2 flatPanel
                                        #if (typepatch=3)
                                                #declare Tpatch = texture {Tframe rotate <-1,1,0> scale <2,30,.2>}
                                
                        
                                                #declare DoorPanelWood = prism {
                                                  linear_sweep linear_spline
                                                  -(spx/2),(spx/2)
                                                  9,
                                                  <0,0>, <0,0.5*thframe/3>, <2*(spx/2)/4.5,0.5*thframe/3>, <2.1*(spx/2)/4.5,0.4*thframe/3>, 
                                                  <3.5*(spx/2)/4.5,0.1*thframe/3>,<4*(spx/2)/4.5,0.1*thframe/3>, 
                                                  <4.5*(spx/2)/4.5,0.5*thframe/3>, <4.5*(spx/2)/4.5,0>, <0,0>
                                                  scale <1,1,-1>
                                                }
                                                
                                                #declare DoorPanelQuarter = intersection { 
                                                //Triangular piece of inner panel on top and bottom
                                                //Used also on side if the panel is square
                                                  object { DoorPanelWood  }
                                                  plane { y,0 rotate 45*z }
                                                  plane { -y,0 rotate -45*z }
                                                  //texture { WhiteGloss }
                                                  texture { Tpatch scale <7,7,.5>}
                                                }
                                                    
                                                #declare DoorPanelSquare = union { 
                                                //square panel on top
                                                  object { DoorPanelQuarter }
                                                  object { DoorPanelQuarter rotate 90*z }
                                                  object { DoorPanelQuarter rotate 180*z }
                                                  object { DoorPanelQuarter rotate 270*z }   
                                                  scale<1.01,1.01,1>
                                                  translate <spx/2,spx/2,1*thframe/3>
                                                }
                                                
                                                
                                                object {DoorPanelSquare scale <1.1,1.1*spy/spx,3>
                                                     texture {Tpatch} 
                                                     //interior {Ipatch}
                                                     rotate <rand(RP)-.5,rand(RP)-.5,rand(RP)-.5>
                                                     translate <thbp/2+(thbp+spx)*indexH,1*thbp/2+(thbp+spy)*indexV,-2*thframe/2>
                                                } 
                                                #local indexV = indexV+1;
                                        #end // patch=3 doorpanel                                                                                
                                #end
                                #local indexH = indexH+1;
                        #end
                #end //if (perfactor = 1)
                
                object {ext_frame_h}
                object {
                      ext_frame_h
                      rotate x*180
                      translate y*y_minus_frame
                }
                object {ext_frame_v} 
                object {
                      ext_frame_v
                      rotate y*180
                      translate x*x_minus_frame
                }
        //the bottom left low corner is on <0,0,0>         
        translate <thframe,thframe,-thframe/2>
        }            
        
        
        
        
        
        object {frame}
          
#end  // of britwindowpanel      



#macro hungwindow(howopen,xstool,ystool,zstool,xycase,zcase,rec, npx,npy, swcx,swcy,thframe,thbp,perfactor,Tframe,typepatch)

        //Outside dimension of the window 
        //swcx cm Width made of 2 * case width +  panel width
        //swcy cm height made of stool eigth + 2 * panel height - panel overlap  + case height 
        
        //Dimensions for the case
        //xycase  cm width of the case
        //zcase   cm deepth of the case       
        
        //dimension for the stool
        //ystool cm height
        //zstool cm deepth
        //xstool cm wider on each side than the outside window dimension
        
        //how thick is the panel frame
        //thframe cm the panel frame has a square section of thframe cm side
        
        //thbp cm how thick are the patch frames square section too
            
        
        // number of patches per panel
        //npx patches on width
        //npy patches on height for one panel (2 panels one above the other for a hung window 
        
        //howopen  ;how open is the window. from 0 closed to 1 fully open
          
        
        //rec cm overlap between frames when window is fully closed
        
             
        
        #//calculate the dimension inside case and stool
        #local siwx= swcx - 2 * xycase;     
        #local siwy= swcy - xycase - ystool;
        
        #//calculate the dimension of each panel
        #local swy= (siwy + rec)/2;    
        #local swx= siwx;
        
        //dummy values to call the panel macro (which can also be calculated upon patch sizes)
        #local spx = 0;
        #local spy = 0;     
        
        #local randseq = 25;
        #local uwpanel = britwindowpanel(npx,npy,spx,spy,swx,swy,thframe,thbp,perfactor,Tframe,typepatch,randseq)
                
        #local randseq = 33;
        #local bwpanel =  union {
                britwindowpanel(npx,npy,spx,spy,swx,swy,thframe,thbp,perfactor,Tframe,typepatch,randseq)
                object {obj_handle rotate x*180 scale y*.75 translate <swx/5,thframe*2/3.2,0> } 
                object {obj_handle rotate x*180 scale y*.75 translate <swx*4/5,thframe*2/3.2,0> }
        }       
        #local inrpnl = box{<-thframe/2,-thframe/4,0>,<0,thframe/4,swy>}
        #local exrpnl = box{<-thframe/1.5,-thframe/3,0>,<0.01,thframe/3,siwy>}      
        
        #local contrepan =  difference {
                union {  
                        box {<0,0,0>,<siwx,thframe/3,thframe/6>}
                        cylinder {<0,0,0>,<siwx,0,0>,thframe/6 
                                  translate <0,0,thframe/6>
                        }
                
                }
                cylinder {<0,0,0>,<siwx,0,0>,thframe/6 
                          translate <0,thframe*1.1/3,thframe*1.2/6>  
                          //translate <0,
                } 
                
                texture {Tframe scale thframe rotate <-1,91,0>}  
                
        }
        
        #local wstool = difference {
                
                        box {
                            <-.5*zstool,-.5*ystool,0>,<.5*zstool,.5*ystool,xstool> 
                        }
                        #local chanfr=ystool/4;
                        box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+xstool> 
                            rotate z*45
                            translate <.5*zstool, .5*ystool,0>
                        }    
                        box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+xstool> 
                            rotate z*-45
                            translate <-.5*zstool, .5*ystool,0>
                        }
                 
                
                texture {Tframe scale thframe rotate <-1,1,0>}
                rotate y*90 
                translate <-(xycase+(xstool-swcx)/2),-ystool/2,0> 
        }  
        #local wcase_V1 = difference {
                box { <-.5*xycase,-.5*zcase,0>,<0.5*xycase,0.5*zcase,siwy+xycase>}
                box { 
                        <-.5*xycase*1.8,-.5*zcase*1.01,0>,<.5*xycase*1.8,.5*zcase*1.01,xycase>
                        rotate y*45
                        translate z*(siwy+xycase/2)
                } 
                #local chanfr=xycase/8;
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, .5*zcase,0>
                        } 
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, -.5*zcase,0>
                        }  
                object {exrpnl translate <0.5*xycase,-thframe/2,0>}                                              
                
                texture {Tframe scale thframe rotate <-1,1,0>}
                rotate x*-90
                translate<-xycase/2,0,0>
        }
        #local wcase_V2 = difference {
                box { <-.5*xycase,-.5*zcase,0>,<0.5*xycase,0.5*zcase,siwy+xycase>}
                box { 
                        <-.5*xycase*1.8,-.5*zcase*1.01,0>,<.5*xycase*1.8,.5*zcase*1.01,xycase>
                        rotate y*45
                        translate z*(siwy+xycase/2)
                } 
                #local chanfr=xycase/8;
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, .5*zcase,0>
                        } 
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, -.5*zcase,0>
                        }  
                object {exrpnl translate <0.5*xycase,thframe/2,0>}                                              
                
                texture {Tframe scale thframe rotate <-1,1,0>}
                rotate x*-90
                translate<-xycase/2,0,0>
        }
        #local wcase_h = difference {
                box { <-.5*xycase,-.5*zcase,0>,<0.5*xycase,0.5*zcase,swcx>}
                box { 
                        <-.5*xycase*1.8,-.5*zcase*1.01,0>,<.5*xycase*1.8,.5*zcase*1.01,xycase>
                        rotate y*45
                        translate z*(swcx-xycase/2)
                }
                box { 
                        <-.5*xycase*1.8,-.5*zcase*1.01,0>,<.5*xycase*1.8,.5*zcase*1.01,-xycase>
                        rotate y*-45
                        translate z*(xycase/2)
                }
                #local chanfr=xycase/8;
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, .5*zcase,0>
                        } 
                box {
                            <-chanfr,-chanfr,-.01><chanfr,chanfr,.1+siwy+xycase> 
                            rotate z*-45
                            translate <.5*xycase, -.5*zcase,0>
                        }
                
                texture {Tframe scale thframe rotate <-1,1,0>}
                rotate z * 90
                rotate y * 90
                rotate x * 180
                translate<-xycase,siwy+xycase/2,0>
        }    
        
        #declare wlatch =  union {
                                text {
                                    ttf "timrom.ttf" "," 1, 0
                                     
                                    scale <7,10,.5> 
                                    rotate <-90,90,0>
                                    translate <.4,0,.5>
                                } 
                                sphere {
                                     <0,0,0>.4 
                                     scale <1,0.7,1>
                                     translate y*.3
                                } 
                                texture { blckir }  
                                scale <thframe*1.5/4,thframe*1.5/2.5,thframe*1.5/3>                                
                        } //wlatch    
        
        
        union {
                object {uwpanel translate <0,swy-rec,0>}
                object {bwpanel translate <0,(swy-rec)*howopen,thframe*1.05>} 
                object {wstool}   
                object {contrepan translate z*(thframe*1.05)}
                object {contrepan scale -y translate y*(siwy)}
                object {wcase_V1}
                object {wcase_V2 rotate y * 180 translate <swx,0,0>}
                object {wcase_h}
                object {wlatch   rotate y*180 translate <siwx/2,swy,-thframe/14>} 
                
                translate <xycase,ystool,0>
        }
        
        
#end  // of hungwindow     


#macro britishdoor1(FWidth, FHeight, FDeepth, FThick ,DDeepth, DShift, AngleOpen, VsWidth, VmWidth, TeHeight, TmHeight, LckAlt, LckScale, TexGloss)
/*
 PARAMETERS EXAMPLES FOR THE MACRO
//User defined size  

//Outer frame size
#declare FWidth = 96;
#declare FHeight = 210; 
#declare AngleOpen = 115;

//Deepth of door frame (should fit with the wall thickness)
#declare FDeepth = 30;

//Deepth (or thickness) of door panel (z)
#declare DDeepth = 4; 

// how much the door goes deepin the frame from 0 to 1
#declare DShift = 0;


//thickness of door frame (x,y)
#declare FThick = 8; 

//width for side verticals
#declare VsWidth = 12;

//width for middle vertical
#declare VmWidth = 10;       

//Height of low and high transversals
#declare TeHeight = 15; 

//Height of middle low and high transversal
#declare TmHeight = 10;                
//Lock altitude above doors bottom will place the low transversal
//in such altitude the lock is at middle height of this transvrsal

//This transversal position will also determine the heights and altitudes of 
//low and middle panels  
#declare LckAlt = 105;
*/
// END OF EXAMPLE PARAMETERS 


        //For the transversals 
        #declare TexGlossTR  = texture {
          TexGloss
          normal {
            waves, 0.9 turbulence <.6,.6,0> translate y*1 scale<1, 0.1, 0.1>  
          }
          scale TeHeight / 6
        } 
        
        //For the verticals 
        #declare TexGlossVR  = texture {
          TexGloss
          normal {
            waves, 0.7 turbulence <.6,.6,0> scale< 0.15, 1, 0.15>
          }
          scale VsWidth/4
        }
        
        //For objects allong z like frame fronts 
        #declare TexGlossFR  = texture {
          TexGloss
          normal {
            waves, 0.7 turbulence <.6,.6,0> scale< 0.05, 0.05, 1>
          } 
          scale FThick / 3.5
        }  







        //////////////////////////////////////////////////////////////
        //getting all resulting sizes
        
        //Door size from frame size and thikness
        #declare DWidth = FWidth - 2 * FThick;    
        #declare DHeight = FHeight - FThick;  
        //#declare DS=DDeepth / 3;     // DS is space around the edge of a door to allow it to fit inside a door frame without touching
        #declare DS=1;
        
        //width for all transversals//
        #declare TWidth = DWidth - 2 * VsWidth;  
        
        //Altitude for lower transversal
        #declare TelAlt = DS;
        
        //Altitude for top transversal
        #declare TehAlt = DHeight - TeHeight; 
        #debug concat("top Panel's alt is:",str(TehAlt,5,2),"\n")
        
        //Altitude for middle low transversal is dependent of lock's altitude (at it's middle)
        #declare TmlAlt = LckAlt - TmHeight/2;         
        #debug concat("mid low Panel's alt is:",str(TmlAlt,5,2),"\n")
        
        //Altitude for middle high transversal is dependent of the square panel's side
        #declare TmhAlt = DHeight - TeHeight - (TWidth - VmWidth) / 2 - TmHeight;
        #debug concat("mid high Panel's alt is:",str(TmhAlt,5,2),"\n")   
        
        //panels dimensions
        //panels width 
        #declare PWidth =  (TWidth - VmWidth) / 2;
        #debug concat("Panel's width is:",str(PWidth,5,2),"\n")  
        
        //panels height
        //Top panels are square, then...
        #declare PtHeight = PWidth;
        
        //middle panels height which are between both middle transversals
        #declare PmHeight = TmhAlt - (TmlAlt + TmHeight) ;
        #debug concat("mid Panel's height is:",str(PmHeight,5,2),"\n")
        
        //Low panels height which are between bottom and low middle transversals
        #declare PlHeight = TmlAlt - (TelAlt + TeHeight);
        #debug concat("low Panel's height is:",str(PlHeight,5,2),"\n")
        
        
        
        //Objects for inner panels
        ///////////////////////////////////////////////////////  
        #declare DoorPanelWood = prism {
          linear_sweep linear_spline
          -(PWidth/2),(PWidth/2)
          9,
          <0,0>, <0,0.5*DDeepth/3>, <2*(PWidth/2)/4.5,0.5*DDeepth/3>, <2.1*(PWidth/2)/4.5,0.4*DDeepth/3>, 
          <3.5*(PWidth/2)/4.5,0.1*DDeepth/3>,<4*(PWidth/2)/4.5,0.1*DDeepth/3>, 
          <4.5*(PWidth/2)/4.5,0.5*DDeepth/3>, <4.5*(PWidth/2)/4.5,0>, <0,0>
          scale <1,1,-1>
        }
        
        #declare DoorPanelQuarter = intersection { 
        //Triangular piece of inner panel on top and bottom
        //Used also on side if the panel is square
          object { DoorPanelWood  }
          plane { y,0 rotate 45*z }
          plane { -y,0 rotate -45*z }
          //texture { WhiteGloss }
          texture { TexGlossVR }
        }
            
        #declare DoorPanelSquare = union { 
        //square panel on top
          object { DoorPanelQuarter }
          object { DoorPanelQuarter rotate 90*z }
          object { DoorPanelQuarter rotate 180*z }
          object { DoorPanelQuarter rotate 270*z }   
          scale<1.01,1.01,1>
          translate <PWidth/2,PWidth/2,1*DDeepth/3>
        }
          
        #declare DoorPanelShortPiece = intersection {    
        //Sides of short rectangular panel at middle height
          object { DoorPanelWood scale <1,2*PmHeight/PWidth,1>  }
          plane { y,0 rotate 45*z }
          plane { -y,0 rotate -45*z translate -y*(PmHeight-PWidth) }
          //texture { WhiteGloss }
          texture { TexGlossVR }  
        }
        
        #if (PmHeight >= PWidth)        
                #declare DoorPanelShort = union { 
                //short rectangular panel at middle height
                
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelShortPiece }
                  object { DoorPanelShortPiece rotate 180*z translate -y*(PmHeight-PWidth) }
                  object { DoorPanelQuarter rotate 270*z translate -y*(PmHeight-PWidth) } 
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PmHeight-PWidth/2,1*DDeepth/3>
                }
        #else
                  #declare DoorPanelShort  = union { 
                  //square panel on top
                  object { DoorPanelQuarter }
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelQuarter rotate 180*z }
                  object { DoorPanelQuarter rotate 270*z }
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PWidth/2,1*DDeepth/3>
                  scale <1,PmHeight/PWidth,1>
        } 
        # end 
        
        
        #declare DoorPanelLongPiece = intersection {     
        //Sides of long rectangular panel at bottom
          object { DoorPanelWood scale <1,2*PlHeight/PWidth,1> }
          plane { y,0 rotate 45*z }
          plane { -y,0 rotate -45*z translate -y*(PlHeight-PWidth) }
          //texture { WhiteGloss }   
          texture { TexGlossVR }
        }
        
        
        #if (PlHeight >= PWidth)
         
                #declare DoorPanelLong = union {     
                //long rectangular panel at bottom
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelLongPiece }
                  object { DoorPanelLongPiece rotate 180*z translate -y*(PlHeight-PWidth) }
                  object { DoorPanelQuarter rotate 270*z translate -y*(PlHeight-PWidth) }
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PlHeight-PWidth/2,1*DDeepth/3>
                  scale<1.01,1.01,1>
                }
        #else
                  #declare DoorPanelLong  = union { 
                  //square panel on top
                  object { DoorPanelQuarter }
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelQuarter rotate 180*z }
                  object { DoorPanelQuarter rotate 270*z }
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PWidth/2,1*DDeepth/3>
                  scale y*PlHeight/PWidth
        } 
        #end
         
         
        
        
        
        
        //limits for vericals
        //near rotation
        #local sidevrx1 = DS;
        #local sidevrx2 = VsWidth;   
        
        
        //middle  
        #local sidevmx1 = VsWidth+PWidth;
        #local sidevmx2 = sidevmx1+VmWidth; 
        
        //near lock
        #local sidevlx1 = sidevmx2+PWidth;
        #local sidevlx2 = sidevlx1+VsWidth-DS; 
        
        
        #declare DoorBox = union {
          box { <sidevrx1,DS,0>, <sidevrx2,DHeight-DS,DDeepth> texture { TexGlossVR }}        //vertical side near rotation axis
          box { <sidevmx1,DS,0>, <sidevmx2,DHeight-DS,DDeepth> texture { TexGlossVR }}       //vertical in middle
          box { <sidevlx1,DS,0>, <sidevlx2,DHeight-DS,DDeepth> texture { TexGlossVR }}    //vertical side near lock
          box { <sidevrx2,0,-0.005>, <sidevlx1,TeHeight-DS,DDeepth + 0.005> texture { TexGlossTR }  translate y*TelAlt}        //Tranversal low
          box { <sidevrx2,0,-0.005>, <sidevlx1,TmHeight,DDeepth + 0.005> texture { TexGlossTR } translate y*TmlAlt} //transversal between long and short panels
          box { <sidevrx2,0,-0.005>, <sidevlx1,TmHeight,DDeepth + 0.005> texture { TexGlossTR } translate y*TmhAlt} //transversal between short and square panels
          box { <sidevrx2,0,-0.005>, <sidevlx1,TeHeight-DS,DDeepth + 0.005> texture { TexGlossTR } translate y*TehAlt} //Tranversal top
          //texture { Reperage }
        }
        
        
        
        #declare DoorSide = union { 
        //the six inner panels
          object { DoorPanelSquare translate <VsWidth,TmhAlt+TmHeight,0> }
          object { DoorPanelSquare translate <VsWidth+PWidth+VmWidth,TmhAlt+TmHeight,0> }
          object { DoorPanelShort translate <VsWidth,TmlAlt+TmHeight,0> }
          object { DoorPanelShort translate <VsWidth+PWidth+VmWidth,TmlAlt+TmHeight,0> }
          object { DoorPanelLong translate <VsWidth,TeHeight,0> }
          object { DoorPanelLong translate <VsWidth+PWidth+VmWidth,TeHeight,0> } 
          
        }  
        
        
        
        #declare CSG002 = union {
          sphere { // Sphere001
            <0,0,0>,1
            scale <1.2, 1.2, 0.95>
          }
          torus { // Torus001
            0.867, 0.5  rotate -x*90
          }
          torus { // Torus003
            1.333, 0.136  rotate -x*90
          }
        }
        #declare CSG001 = difference {
          object { CSG002 }
          torus { // Torus002
            0.721, 0.213  rotate -x*90
            translate  0.682889*z
          }
          torus { // Torus004
            1.216, 0.021  rotate -x*90
            translate  -0.347022*z
          }
        }
        #declare CSG003 = intersection {
          object { CSG001 }
          sphere { // Sphere002
            <0,0,0>,1
            scale 3.0
            translate  <0.0, 0.022861, 2.160371>
          }
        }   
        
        #declare copperknob = union { // CSG004
          object { CSG003 }
          superellipsoid { // SuperQ001
            <1.0, 0.121>
            scale <0.4, 0.4, 1.5>
            translate  0.640844*z
          }
          translate -z*1.5
          texture {
            Copper_Texture
          }
        }
        
        #declare FBWidth = VsWidth - 4*DS; 
        
        #declare keyhole = union {
                cylinder {<-(2*DS+FBWidth/2),0,-DDeepth* 0.06>,<-(2*DS+FBWidth/2),0,DDeepth* 1.06>,1 }
                box      {<-.7,-FBWidth/2.5,-DDeepth* 0.06>,<.7,0,DDeepth* 1.06>
                          translate -x*(2*DS+FBWidth/2)}  
                scale LckScale          
                translate -y*FBWidth/2
        }
         
         //face framing
         #declare FaceLockFrame= union {
         intersection {
                            torus {
                                FBWidth / 4, FBWidth / 30 
                            }
                            box { 
                                <-FBWidth/3, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <-FBWidth/2,TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <-FBWidth,TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<-FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <0,TmHeight*1.5,-DDeepth* 0.05>
                    } 
                    
                    
                    intersection {
                            torus {
                                FBWidth / 4, FBWidth / 30 
                            }
                            box { 
                                <-FBWidth/3, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <-FBWidth/2,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <-FBWidth,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<-FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <0,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    cylinder { 
                        <-FBWidth, -(TmHeight*1.5-FBWidth/6), -DDeepth* 0.05>,<-FBWidth, TmHeight*1.5-FBWidth/6, -DDeepth* 0.05>,FBWidth/30 
                        translate  x*FBWidth/30   
                    }
                    cylinder { 
                        <0, -(TmHeight*1.5-FBWidth/6), -DDeepth* 0.05>,<0, TmHeight*1.5-FBWidth/6, -DDeepth* 0.05>,FBWidth/30 
                        translate  -x*FBWidth/30   
                    }
        } //object face lock framing           
         
        
        
        
        
        
        #declare clockbox = union {
         //inside lock
         box {<DS+.01,-TmHeight*.75,DDeepth* 0.1>,<-VsWidth*.7,TmHeight*.75,DDeepth*.9> texture{Steel_Texture} }
         //face lock  
        
         
         difference {
                 union { 
                    
                     
                    box {<0,-TmHeight*1.5,-DDeepth* 0.05>,<-FBWidth,TmHeight*1.5,DDeepth*1.05> }
                    cylinder {
                        <0,0,-DDeepth* 0.05>,<0,0,DDeepth* 1.05>,FBWidth / 3
                        translate <-FBWidth/2,-TmHeight*1.5,0> 
                    } 
                    cylinder {
                        <0,0,-DDeepth* 0.05>,<0,0,DDeepth* 1.05>,FBWidth / 3
                        translate <-FBWidth/2,TmHeight*1.5,0> 
                    }
                    
                       
                    
                    
                    object {FaceLockFrame}
                    object {FaceLockFrame translate z*DDeepth*1.1}
                    
                    
                    object {copperknob 
                            scale FBWidth/2.5
                            translate <-FBWidth/2,0,0>}
                    
                    object {copperknob 
                            scale FBWidth/2.5 
                            rotate y*180
                            translate <-FBWidth/2,0,DDeepth>}
                    
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <0,TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <-FBWidth,TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <0,-TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <-FBWidth,-TmHeight*1.5,0> 
                 }
                 //scale y*.65
                 texture {Copper_Texture scale 5*VsWidth/4}
         } 
         
         
         translate <-2*DS,TmHeight/2,0>
        
        }
        
        #declare gache = box {
                <-.01,-TmHeight*.75,DDeepth* 0.1>,<.9,TmHeight*.75,DDeepth*.9> 
                texture {Steel_Texture scale VsWidth/4}
                translate <DWidth-.1,TmlAlt+TmHeight/2,0>
        }
        
        
        
        
        
        
        
        
        
        #declare DoorPanel =  difference {
        union {
          object { DoorBox }
          object { DoorSide }
          object { DoorSide scale <1,1,-1> translate z*DDeepth } 
          object {clockbox scale LckScale translate <DWidth, TmlAlt,0>}
          
          
          
        }  
          object {keyhole translate <DWidth, TmlAlt,0> }
        }
        
        // 29" x 6'6" door, frame out dim=3.5" wider
        
        // scale along the z axis before use
        
        #declare DoorFrameWood = union {
          cylinder { <0.5,3.5-0.75,0>, <0.5,3.5-0.75,1>, 0.5 }
          difference {
            box { <0,0,0>, <1,3.5,1> }
            box { <0.5,3.5-1.05,-0.01>, <1.01,3.51,1.01> }
            cylinder { <1.05,3.5-1.05,-0.01>, <1.05,3.5-1.05,1.01>, 0.5 } 
            
          }
          scale <FThick/3.5,FThick/3.5,1>
          texture { TexGlossFR}
        }
        
        
        #declare DoorFrameTop = intersection {
          object { DoorFrameWood scale <1,-1,FWidth> }
          plane { -y,0 rotate 45*x }
          plane { -y,0 rotate -45*x translate FWidth*z}  
          
        }
        
        #declare DoorFrameLeft = intersection {
          object { DoorFrameWood scale <1,-1,FHeight> }
          plane { -y,0 rotate 45*x }
          rotate 90*x
          translate FWidth*z
        }
        
        #declare DoorFrameRight = intersection {
          object { DoorFrameWood scale <1,-1,FHeight> }
          plane { -y,0 rotate 45*x }
          rotate 90*x
          scale <1,1,-1>
        }
        
        #declare DoorFrame1 = union {
          object { DoorFrameTop }
          object { DoorFrameLeft }
          object { DoorFrameRight }
          rotate 90*y translate FHeight*y
        }
        
        #declare DoorFrame = union {
          object { DoorFrame1 }
          object { DoorFrame1 scale <1,1,-1> translate FDeepth*z }
          difference {
            box { <0,0,0>, <FWidth-0, FHeight-0, FDeepth - 0.001> }
            box { <FThick,-0.01,-0.001>, <FWidth-FThick, FHeight-FThick, FDeepth + 0.001>}
            texture { TexGlossVR }
          }           
          
          // Inside frame
            difference {
            box { <FThick,0,DDeepth+(FDeepth-DDeepth)*DShift>, <FWidth-FThick, FHeight-FThick, FDeepth - 0.001> }
            box { <FThick+DS*1.5,-0.01,-0.001>, <FWidth-(FThick+DS*1.5), FHeight-(FThick+DS*1.5), FDeepth + 0.001>}
            texture { TexGlossVR }
          }
          
          
          
        }  
        
        
        
        
        
        
        // for bounding or CSG use
        #declare DoorSpace = box { <0,0,-0.01>, <FWidth, FHeight, 9.01> pigment { Black } translate -0.5*z }
        
        #declare Door = union {
          object { DoorFrame }
          object { DoorPanel rotate AngleOpen*y translate <FThick,0,(FDeepth-DDeepth)*DShift> } 
          object {gache translate <FThick,0,(FDeepth-DDeepth)*DShift>}
        }
        
        object { Door translate -FThick*x*0}
#end //macro  britishdoor1



#macro makewallBrickNorm(x1Wall,z1Wall,x2Wall, z2Wall,yWall,eWall,xBrick,yBrick,zBrick,eMortar,TBrick,TMortar,turb,pMortar)
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi; 
        
        #local Tvide = texture{pigment{color rgbt <1,1,1,1>}}; 
        
        #local T_Wall = texture { brick texture { Tvide },texture{TBrick} brick_size<xBrick,yBrick,zBrick> mortar eMortar};
        
        union{
                box{<0,0,-eWall/2>,<xWall,yWall,eWall/2> texture{T_Wall} 
                        rotate -AngleDeg*y
                        translate <x1Wall,0,z1Wall>       
                }
        
                box{<0,0,-(eWall-pMortar)/2>,<xWall,yWall,(eWall-pMortar)/2> texture{TMortar} 
                        rotate -AngleDeg*y
                        translate <x1Wall,0,z1Wall>       
                }
        }

#end //macro makewallBrick




#macro churchwin  (x1Wall,z1Wall,x2Wall, z2Wall,epWall,debrdz,debrdxy,xWin,yWin,cGoth,tx,ty,Tdebrd) 
        #local xWinM = xWin +2*debrdxy;
        #local yWinM = yWin +1*debrdxy;
        #local centreA = xWinM/2 - xWinM * cGoth/ 2;
        #local centreB = xWinM/2 + xWinM * cGoth/ 2; 
        
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        
        
        #local rad = centreB; 
        
        #if (cGoth != 0)
                #local ogive =intersection {
                        cylinder{<centreA,yWinM,-(epWall/2+debrdz)>,<centreA,yWinM,(epWall/2+debrdz)>,rad}
                        cylinder{<centreB,yWinM,-(epWall/2+debrdz*1.1)>,<centreB,yWinM,(epWall/2+debrdz*1.1)>,rad}
                }
        #else 
                #local ogive = cylinder{<centreA,yWinM,-(epWall/2+debrdz)>,<centreA,yWinM,(epWall/2+debrdz)>,rad}
        #end
        
        merge {
                box {<0,0,-(epWall/2+debrdz)>,<xWinM,yWinM,epWall/2+debrdz>}
                object {ogive }
                texture{Tdebrd}        
                rotate -AngleDeg*y
                translate <x1Wall+(tx-debrdxy)*cos(AngleRad),ty-debrdxy,z1Wall+(tx-debrdxy)*sin(AngleRad)>
              }  
              
#end // macro churchwin           


//=========================================
// Straight wall and round wall macro for Pov-ray 3.1 & higher
// (c) 1999 Gilles Tran tran@inapg.inra.fr
//-----------------------------------------
// This file contains 2 macros to build stone & brick walls
//
// The brick can be a box or an ellipsoid
// These macros make quite simplistic walls
// You may need to modify them, particularly the texture part

#macro MakeWall(typeWall,pEllipsoid,x1Wall,z1Wall,x2Wall, z2Wall,yWall,eMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srd3,srdcol,patternWall,pigWall,txtMortar,doMortar)
//----------------------------------------- 
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        
        #local R1=seed(seedWall);                        
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid-0.5*srd3+rand(R1)*srd3,pEllipsoid-0.5*srd3+rand(R1)*srd3>}
                #break                        
        #end                
        union{  
                #if (doMortar != 0)                     
                        box{0,<xWall,yWall,eWall> texture{txtMortar} translate 0*eWall*z}
                        #debug concat("xWall ",str(xWall,10,10),"\n")
                        #debug concat("yWall ",str(yWall,10,10),"\n")
                        #debug concat("**************************************eWall ",str(eWall,10,10),"\n")
                         
                #end
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(yBrickMin+yBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                //#warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                        #while (xPos<=xWall)
                                #switch (patternWall)
                                        #case (1) // no gradient
                                                #local spatternWall=1;
                                                #break            
                                        #case (2) // gradient y up
                                                #local spatternWall=(yPos+0.2)/(yWall-0.2);
                                                #break            
                                        #case (3) // gradient y down
                                                #local spatternWall=1-((yPos+0.2)/(yWall-0.2));
                                                #break                               
                                #end
                                #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigWall*(0.5+(1+srdcol*rand(R1)))*0.5*spatternWall]
                                                                [1 color pigWall*(0.5+(1+srdcol*rand(R1)))*spatternWall]
                                                        }
                                                #else
                                                        color pigWall   // uniform color
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary
                                        finish{ambient 0.04 diffuse 0.26 specular 0.05 roughness 0.05}
                                        //scale xBrickMax*0.1 
                                        translate xPos+yPos
                                }
                                
                                
                                //#local txtBrick=Tgranite;
                                
                                
                                #local xBrick=(xBrickMin+xBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local xBrick=max(min(xBrick,xBrickMax),xBrickMin);  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(yBrickMin+yBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,yBrickMax),yBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,0>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(yBrickMin+yBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                
                }
         scale <1,yWall/yMax,1> 
                rotate -AngleDeg*y
                #declare angleWall = AngleDeg;  
                #declare lengthWall = xWall;
                translate <x1Wall,0,z1Wall>
                
        }
#end   //MakeWall


//-----------------------------------------
#macro MakeSingleRowWall(typeWall,pEllipsoid,x1Wall,z1Wall,x2Wall, z2Wall,yWall,eMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srd3,srdcol,patternWall,pigWall,txtMortar,doMortar)
//----------------------------------------- 
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        
        #local R1=seed(seedWall);                        
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid-0.5*srd3+rand(R1)*srd3,pEllipsoid-0.5*srd3+rand(R1)*srd3>}
                #break                        
        #end                
        union{  
                #if (doMortar != 0)                     
                        box{<0,-(1-pEllipsoid)*yWall,pEllipsoid*eWall/10>,<xWall,(1-pEllipsoid)*yWall,(1-pEllipsoid)*eWall/10> texture{txtMortar} translate <0,yWall+.3,-0.5*eWall+.75>}
                        #debug concat("xWall ",str(xWall,10,10),"\n")
                        #debug concat("yWall ",str(yWall,10,10),"\n")
                        #debug concat("**************************************eWall ",str(eWall,10,10),"\n")
                         
                #end
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(yBrickMin+yBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                //#warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                        #while (xPos<=xWall)
                                #switch (patternWall)
                                        #case (1) // no gradient
                                                #local spatternWall=1;
                                                #break            
                                        #case (2) // gradient y up
                                                #local spatternWall=(yPos+0.2)/(yWall-0.2);
                                                #break            
                                        #case (3) // gradient y down
                                                #local spatternWall=1-((yPos+0.2)/(yWall-0.2));
                                                #break                               
                                #end
                                #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigWall*(0.5+(1+srdcol*rand(R1)))*0.5*spatternWall]
                                                                [1 color pigWall*(0.5+(1+srdcol*rand(R1)))*spatternWall]
                                                        }
                                                #else
                                                        color pigWall   // uniform color
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary
                                        finish{ambient 0.10 diffuse 0.26 specular 0.05 roughness 0.05
                                        //reflection {0.05,0.15}
                                        }
                                        //scale xBrickMax*0.1 
                                        translate xPos+yPos
                                }
                                
                                
                                //#local txtBrick=Tgranite;
                                
                                
                                #local xBrick=(xBrickMin+xBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local xBrick=max(min(xBrick,xBrickMax),xBrickMin);  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(yBrickMin+yBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,yBrickMax),yBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,0>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(yBrickMin+yBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                
                }
         scale <1,yWall/yMax,1> 
                rotate -AngleDeg*y
                #declare angleWall = AngleDeg;  
                #declare lengthWall = xWall;
                translate <x1Wall,0,z1Wall>
                
        }
#end   //MakeSingleRowWall
//-----------------------------------------
// MakeRoundWall macro
// MakeRoundWall : creates a round wall of radius rWall and height yWall, centered on <0,0,0>
// the wall goes from -tetaWall/2 to tetaWall/2
//-----------------------------------------
#macro MakeRoundWall(typeWall,pEllipsoid,tetaWall,yWall,rWall,eMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srdcol,patternWall,pigWall,txtMortar)
//-----------------------------------------
/*
#declare tetaWall=90;              // angle (360 = round tower)
#declare rWall=20;                 // radius
*/
//-----------------------------------------

        #local R1=seed(seedWall);                        
        #local xWall=rWall*radians(tetaWall);
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid,pEllipsoid>}
                #break                        
        #end                
        union{                       
                //cylinder{0,yWall*y,(rWall-eWall) texture{txtMortar}}
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(yBrickMin+yBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                #warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                
                
                        #while (xPos<=xWall)
                                #switch (patternWall)
                                #case (1) // rpartition gale
                                        #local spatternWall=1;
                                        #break            
                                #case (2) // gradient y croissant
                                        #local spatternWall=(yPos+0.2)/(yWall-0.2);
                                        #break            
                                #case (3) // gradient y dcroissant
                                        #local spatternWall=1-((yPos+0.2)/(yWall-0.2));
                                        #break            
                                #end
                                #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigWall*(0.5+(1+srdcol*rand(R1)))*0.5*spatternWall]
                                                                [1 color pigWall*(0.5+(1+srdcol*rand(R1)))*spatternWall]
                                                        }
                                                #else
                                                        color pigWall
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary
                                        finish{ambient 0.04 diffuse 0.26 specular 0.05 roughness 0.05}
                                        //scale xBrickMax*0.1 
                                        translate xPos+yPos
                                }
                                #local xBrick=(xBrickMin+xBrickMax)*0.5*(rand(R1)*srd1+1);
//                                #local xBrick=max(min(xBrick,xBrickMax),xBrickMin);  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(yBrickMin+yBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,yBrickMax),yBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,0>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2>
                                        translate y*yPos
                                        translate -z*rWall
                                        rotate -y*degrees(xPos/rWall)
                                        texture{txtBrick}
                                        }
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2>
                                        translate y*yPos
                                        translate -z*rWall
                                        rotate -y*degrees(xPos/rWall)
                                        texture{txtBrick}
                                        }
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(yBrickMin+yBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                scale <1,yWall/yMax,1>
                }

        rotate y*-90
        //translate z*cos(radians(tetaWall*0.5))*rWall // centers the wall on <0,0,0>
        }
        #warning concat("the width of the wall is 2 * ",str(cos(radians(tetaWall*0.5))*rWall,0,3)," \n") 
        
#end       

#macro MakeSideWalk(typeWall,pEllipsoid,xWall,yWall,eMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srdcol,patternWall,pigWall,txtMortar,doMortar)

//----------------------------------------- 
        #local dxBrickMax = xBrickMax / 2;
        #local dxBrickMin = xBrickMin / 2;
        #local dyBrickMax = yBrickMax / 2;
        #local dyBrickMin = yBrickMin / 2; 
        
        #warning concat("Making pavement ","\n")
        
        #local R1=seed(seedWall);
        #local R2=seed(seedWall+50);                        
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid,pEllipsoid>}
                #break                        
        #end                
        union{  
                #if (doMortar != 0)                     
                        box{(pEllipsoid/10)*eWall,<xWall,yWall,(1-pEllipsoid)*eWall> texture{txtMortar} translate -.5*eWall*z+.2} 
                #end 
                
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(dyBrickMin+dyBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                //#warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                        #while (xPos<=xWall)
                                #switch (patternWall)
                                        #case (1) // no gradient
                                                #local spatternWall=1;
                                                #break            
                                        #case (2) // gradient y up
                                                #local spatternWall=(yPos+0.04)/(yWall-0.04);
                                                #break            
                                        #case (3) // gradient y down
                                                #local spatternWall=1-(yPos*0.2)/yWall;
                                                #break                               
                                #end  
                                #local flgSupAleS =rand(R1)*11;
                                #local flgSupAleC =rand(R1)*9;
                                #local flgSupAleN =rand(R1)*13;
                                
                                #local cfSupAleS =1;
                                #local cfSupAleC =1;
                                #local cfSupAleN =1;
                                
                                #if (flgSupAleS <1.5)
                                        #local cfSupAleS = 1-.4 + .8 * rand(R2);
                                #end 
                                
                                #if (flgSupAleC <1.5)
                                        #local cfSupAleC = 1-.4 +.6 * rand(R2);
                                #end
                                #if (flgSupAleN <1.5)
                                        #local cfSupAleN = rand(R2);
                                #end
                                 
                                
                                
                                #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0) 
                                                        #local pigdalle= pigWall*(0.5+(1+srdcol*rand(R1)));
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigdalle*0.5*spatternWall* cfSupAleC]
                                                                [1 color pigdalle*0.5*(1+srdcol*rand(R1)/5)*spatternWall * cfSupAleC]
                                                        }
                                                        scale <1,1,1>
                                                #else
                                                        color pigWall   // uniform color
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary    
                                        normal
                                 {
                                    crackle , .3+.3*rand(R1) - (.2+.6*rand(R2))*(1-cfSupAleN)
                                    warp
                                    {
                                       turbulence <0.500164, 0.500364, 0.499804>
                        
                                       omega 0.500404
                                       lambda 1.999712
                                    }
                                    scale  <15-(10+20*rand(R2))*(1-cfSupAleN),1-(.5+rand(R2))*(1-cfSupAleN),1-(.5+rand(R2))*(1-cfSupAleN)>
                                    rotate <0,0,180*cfSupAleN>
                                 } 
                                        finish{ambient 0.15 diffuse 0.46 specular 0.05 roughness 0.05  
                                        //reflection {0.05,0.15}
                                        }
                                        //scale xBrickMax*0.1 
                                        translate xPos+yPos
                                }
                                
                                
                                //#local txtBrick=Tgranite;
                                
                                
                                #local xBrick=(dxBrickMin+dxBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local xBrick=max(min(xBrick,dxBrickMax),dxBrickMin) * cfSupAleN;  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(dyBrickMin+dyBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,dyBrickMax),dyBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,rand(R1)-0.5>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,-rand(R1)*1.3> texture{txtBrick}}
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,-rand(R1)*1.3> texture{txtBrick}} 
                                        
                                        //#if (flgSupAleS <1)
                                                //cylinder{<xPos-3,yPos,-50>,<xPos,yPos,50>,1 texture{ pigment{Red} finish{ambient .7}}}
                                        //#end
                                        //#if (flgSupAleC <1)
                                                //cylinder{<xPos,yPos,-50>,<xPos,yPos,50>,1 texture{ pigment{Green} finish{ambient .7}}}
                                        //#end
                                        //#if (flgSupAleN <1)
                                                //cylinder{<xPos+3,yPos,-50>,<xPos,yPos,50>,1 texture{ pigment{Blue} finish{ambient .7}}}
                                        //#end
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(dyBrickMin+dyBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                
                scale <1,yWall/yMax,1> 
                
                }
                
                
        }
#end   // makesidewalk

#macro makeroundSideWalk (rad, hTrot, pigwall,patternWall)   
        #switch (patternWall)
                                        #case (1) // no gradient
                                                #local spatternWall=1;
                                                #break            
                                        #case (2) // gradient y up
                                                #local spatternWall=(yPos+0.2)/(yWall-0.2);
                                                #break            
                                        #case (3) // gradient y down
                                                #local spatternWall=1-((yPos+0.2)/(yWall-0.2));
                                                #break                               
                                #end
        #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigWall*(0.5+(1+srdcol*.5))*0.5*spatternWall]
                                                                [1 color pigWall*(0.5+(1+srdcol*.6))*spatternWall]
                                                        }
                                                #else
                                                        color pigWall   // uniform color
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary
                                        finish{ambient 0.04 diffuse 0.26 specular 0.05 roughness 0.05}
                                         
                                        
                                }   
            
        
cylinder {0,<0,hTrot,0>,rad texture{txtBrick}}
#end       


#macro paveroute(typeWall,pEllipsoid,RWidth,MHeight,yWall,rWall,eMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srd3,srdcol,patternWall,pigWall,txtMortar)

        #declare rWall = getRC(RWidth,MHeight).u;
        #declare tetaWall = getRC(RWidth,MHeight).v;
        #debug concat("rWall   :",str(rWall ,10,10),"\n")
        #debug concat("teta   :",str(tetaWall ,10,10),"\n")
        
//#declare tetaWall=90; 
//#declare rWall=300;       
//-----------------------------------------
/*
#declare tetaWall=90;              // angle (360 = round tower)
#declare rWall=20;                 // radius
*/
//-----------------------------------------

        #local R1=seed(seedWall);                        
        #local xWall=rWall*radians(tetaWall);
        
        
                #local dxBrickMax = xBrickMax / 2;
        #local dxBrickMin = xBrickMin / 2;
        #local dyBrickMax = yBrickMax / 2;
        #local dyBrickMin = yBrickMin / 2;
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid-0.5*srd3+rand(R1)*srd3,pEllipsoid-0.5*srd3+rand(R1)*srd3>}
                #break                        
        #end                
        union{                       
                cylinder{0,yWall*y,rWall+(1-pEllipsoid/3)*eWall texture{txtMortar}}
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(yBrickMin+yBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                //#warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                
                
                        #while (xPos<=xWall)
                                #switch (patternWall)
                                #case (1) // rpartition gale
                                        #local spatternWall=1;
                                        #break            
                                #case (2) // gradient y croissant
                                        #local spatternWall=(yPos+0.2)/(yWall-0.2);
                                        #break            
                                #case (3) // gradient y dcroissant
                                        #local spatternWall=1-((yPos+0.2)/(yWall-0.2));
                                        #break            
                                #end
                                #local txtBrick=texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        crackle // replace if necessary
                                                        turbulence 0.5
                                                        color_map{
                                                                [0 color pigWall*(0.5+(1+srdcol*rand(R1)))*0.5*spatternWall]
                                                                [1 color pigWall*(0.5+(1+srdcol*rand(R1)))*spatternWall]
                                                        }
                                                #else
                                                        color pigWall
                                                #end
                                                
                                        }                          
                                                
                                        // add normal if necessary
                                        finish{ambient 0.09 diffuse 0.26 specular 0.15 roughness 0.05 
                                        //reflection {0.05,0.3}
                                        }
                                        scale dxBrickMax*0.1 
                                        translate xPos+yPos
                                }
                                #local xBrick=(dxBrickMin+dxBrickMax)*0.5*(rand(R1)*srd1+1);
//                                #local xBrick=max(min(xBrick,xBrickMax),xBrickMin);  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(dyBrickMin+dyBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,dyBrickMax),dyBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,0>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall>
                                        translate y*yPos
                                        translate -z*rWall
                                        rotate -y*degrees(xPos/rWall)
                                        texture{txtBrick}
                                        }
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall>
                                        translate y*yPos
                                        translate -z*rWall
                                        rotate -y*degrees(xPos/rWall)
                                        texture{txtBrick}
                                        }
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(dyBrickMin+dyBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                scale <1,yWall/yMax,1>
                }

        rotate y*tetaWall*0.5 // rotates so that the wall looks at -z
        translate z*(cos(radians(tetaWall*0.5))*rWall+eWall) // centers the wall on <0,0,0>
        }
        
        rotate x*90 
        rotate y*90
        translate -z*RWidth/2
        #warning concat("the width of the wall is 2 * ",str(cos(radians(tetaWall*0.5))*rWall,0,3)," \n") 
        
#end  //paveroute
                     
                     
#macro MakeWallTex(typeWall,pEllipsoid,x1Wall,z1Wall,x2Wall, z2Wall,yWall,eMortar,zMortar,eWall,xBrickMin,xBrickMax,yBrickMin,yBrickMax,seedWall,srd1,srd2,srd3,srdcol,srdCrand,patternWall,pigWall,difamb,txtMortar,doMortar)


//-----------------------------------------  
       
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        #local dxBrickMax = xBrickMax / 2;
        #local dxBrickMin = xBrickMin / 2;
        #local dyBrickMax = yBrickMax / 2;
        #local dyBrickMin = yBrickMin / 2;
        
        #local R1=seed(seedWall);                        
        #switch (typeWall)
                #case (1)                     
                        #local Brick=box{-1,1}
                #break                        
                #case (2)
                        #local Brick=superellipsoid{<pEllipsoid-0.5*srd3+rand(R1)*srd3,pEllipsoid-0.5*srd3+rand(R1)*srd3>}
                #break                        
        #end                
        union{  
                #if (doMortar != 0)                     
                        box{<pEllipsoid*xBrickMax,0,pEllipsoid>,<xWall-pEllipsoid*xBrickMax,yWall-pEllipsoid*yBrickMax,zMortar-pEllipsoid> texture{txtMortar} translate -zMortar/2*z}  
                #else 
                         box{0,<.001,.001,.001> texture{txtMortar} translate -eWall/2*z}                       
                #end
                union{
                #local yFlag=0;       
                #local yMax=0;
                #local yPos=(dyBrickMin+dyBrickMax)*0.5+eMortar;   
                #local yBrick=0;
                #local nRow=0;
                #while (yPos<=yWall)
                #local nRow=nRow+1;
                //#warning concat("row ",str(nRow,0,0),"\n")
                #if (yFlag=0)
                        #local xPos=0;
                #else
                        #local xPos=0.0001;
                #end
                        #while (xPos<=xWall)
                                
                                #switch (patternWall)
                                #case (1) // rpartition gale
                                        #local spatternWall=1;
                                        #break            
                                #case (2) // gradient y croissant
                                        #local spatternWall=(yWall*.5+yPos*.5+0.5)/(yWall-0.2);
                                        #break            
                                #case (3) // gradient y dcroissant
                                        #local spatternWall=1-((yPos/3+0.2)/(yWall-0.2));
                                        #break            
                                #end
                                #local txtBrick= 
                                //texture {txtWall}
                                texture{
                                        pigment{
                                                #if (patternWall>0)
                                                        granite // replace if necessary
                                                        turbulence 0.5
                                                        #local colBrick1 = pigWall*(0.5+(1+srdcol*rand(R1)))*0.5*spatternWall;
                                                        //local colBrick2 = colBrick1 * (1 -srdCrand/2 + srdCrand *  rand(R1));
                                                        #local colBrick2 = colBrick1 * 0.7;
                                                        color_map{
                                                                [0 color colBrick1]
                                                                [1 color colBrick2]
                                                        }
                                                #else
                                                        color pigWall
                                                #end 
                          

                                                
                                        } 
                                                
                                          
                                          normal {
                                              bumps 0.08
                                              scale (xBrickMax+yBrickMax)/5
                                            }
 
                                          
                                          finish { 
                                            diffuse difamb.u
                                            ambient difamb.v
                                            brilliance 1.5
                                            specular 0.08    roughness 0.13
                                          }                                        
                                        //finish{ambient 0.04 diffuse 0.26 specular 0.05 roughness 0.05}
                                        //scale xBrickMax*0.01 
                                        translate xPos+yPos
                                }                                
                                
                                
                                #local xBrick=(dxBrickMin+dxBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local xBrick=max(min(xBrick,dxBrickMax),dxBrickMin);  
                                #if (xPos+2*xBrick>xWall)
                                        #local xBrick=(xWall-xPos)*0.5;
                                #end
                                #local yBrick=(dyBrickMin+dyBrickMax)*0.5*(rand(R1)*srd1+1);
                                #local yBrick=max(min(yBrick,dyBrickMax),dyBrickMin);
                                #local rBrick=<rand(R1)-0.5,rand(R1)-0.5,0>*20*srd2;
                                #if (yFlag=0 & xPos=0) 
                                        #local xPos=xBrick*0.5;
                                        object{Brick rotate rBrick scale <xBrick*0.5,yBrick+eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick*0.5 + eMortar*(1+rand(R1)*srd1);
                                #else  
                                        #local xPos=xPos+xBrick;
                                        object{Brick rotate rBrick scale <xBrick,yBrick + eMortar*(rand(R1)-0.5)*srd1*0.5,eWall/2> translate <xPos,yPos,0> texture{txtBrick}}
                                        #local xPos=xPos+xBrick + eMortar*(1+rand(R1)*srd1);
                                #end
                        #end    
                        #if (yPos+yBrick>yMax)
                                #local yMax=yPos+yBrick;
                        #end
                        #local yPos=yPos+(dyBrickMin+dyBrickMax)+eMortar*(1+rand(R1)*srd1);
                        #if (yFlag=0) #local yFlag=1; #else #local yFlag=0; #end
                #end                   
                scale <1,yWall/yMax,1>
                }
                 
                rotate -AngleDeg*y
                #declare angleWall = AngleDeg;  
                #declare lengthWall = xWall;
                translate <x1Wall,0,z1Wall>
                #declare txtLastBrick=txtBrick;
                
        }
#end    // MakeWallTex


#macro GetWallParam(x1Wall,z1Wall,x2Wall, z2Wall)


//-----------------------------------------  
       
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
        
        #declare angleWall = AngleDeg;  
        #declare lengthWall = xWall;
                
        
#end    // GetWallParam



#macro murMortier  (xMur,yMur,zMur, pMortier, fColMort)    
              box {<pMortier,0,-zMur/2+pMortier>,<xMur-pMortier,yMur,zMur/2-pMortier>
              
                   texture
                      {      
                         pigment
                         {
                            granite
                            color_map
                            {
                               [ 0.0     rgbft <0.739567, 0.739567, 0.739567, 0.0, 0.0> *  fColMort]
                               [ 0.25    rgbft <0.802067, 0.802067, 0.802067, 0.0, 0.0> * fColMort]
                               [ 0.5     rgbft <0.677067, 0.677067, 0.677067, 0.0, 0.0> * fColMort]
                               [ 0.75    rgbft <0.8229, 0.8229, 0.8229, 0.0, 0.0> * fColMort]
                               [ 1.0     rgbft <0.708333, 0.708333, 0.708333, 0.0, 0.0> * fColMort]
                            }
                            frequency 100.0
                            ramp_wave
                         }      
                         normal
                         {
                            crackle , .3
                            warp
                            {
                               turbulence <0.500164, 0.500364, 0.499804>
                
                               omega 0.500404
                               lambda 1.999712
                            }
                         }      
                         finish
                         {
                            ambient 0.266167
                            diffuse 0.549996
                            specular 0.100002
                            roughness 1.0
                         }      
                
                         //  This texture was originally designed by Charles Fusner.

                     } 
                }// box mortier        
#end //macroMortier




#macro murBrique  (xMur,yMur,zMur, xBriqueMin, xBriqueMax, yBriqueMin, yBriqueMax, eMortier, pMortier, alePos, aleRot, aleForme, aleCol, supAleX, supAleCol, supAleP, fColBas, fColHaut, fColMort, seedAle)    

        #local R1 = seed(seedAle);  
        #local R2 = seed(seedAle+100);    
        #local dxBrique  =  xBriqueMax - xBriqueMin;
        #local dyBrique  =  yBriqueMax - yBriqueMin;  
        
        #local mxBrique  =  (xBriqueMax + xBriqueMin) / 2;
        #local myBrique  =  (yBriqueMax + yBriqueMin) / 2;    
        
        #local dfCol = fColHaut-fColBas;
        
        
        #local dPosBrique = eMortier *  2 * alePos; 
        #local dPosZBrique = pMortier *  2 * alePos;
        #local nBriqueX = xMur / (mxBrique+eMortier); 
        #local nBriqueY = yMur / (myBrique+eMortier);  
        
        #local posY = 0;
        #local rangDecale = 0;  
        
        #local murProv = union{
        # while  (posY < yMur -yBriqueMax ) 
        
        
                #local posX = 0;
                #local posThX = 0;
                
                #if (rangDecale = 1)
                      #local demBrique = 1;
                      #local rangDecale = 0;
                #else 
                     #local rangDecale = 1;
                     #local demBrique = 0;
                #end        
                
                
                #local fCol = fColBas + dfCol * posY / yMur;
                # while  (posX < xMur - mxBrique )     //()   
                
                        
                        #local  aSupAleX = rand(R2) *supAleP ; 
                        #local  aSupAleCol = rand(R2) *supAleP ;  
                        
                        
                        #local xBrique = xBriqueMin +rand(R1) * dxBrique;
                        #if (aSupAleX <= 1)
                           #local xBrique = xBrique * (1 - supAleX/2 + rand(R1) * supAleX);
                        #end 
                        
                        //Rgulation de variation pour viter les briques superposes en fin de range
                        #if (abs((posX+xBrique)-(posThX+mxBrique)) > dxBrique)
                            #local xBrique = posThX+mxBrique - posX;  
                            //cylinder {<posX,posY,-zMur/1.5>,<posX,posY,zMur>,2 texture {pigment{rgb <1,1,1>} finish {ambient .6} }}
                             
                        #end    
                        
                        //Demi brique en dbut de mur
                        #if (demBrique = 1)
                                #local demBrique = 0;
                                #local xBrique = xBrique / 2; 
                                #local posThX  =  posThX - mxBrique /2;
                                
                                        
                        #end
                        #local yBrique = yBriqueMin+rand(R1)*dyBrique; 
                        
                        #local coefCol = 1;
                        #if (aSupAleCol <= 1)
                            #local coefCol = 1 - supAleCol/3 + rand(R1) * supAleCol;
                        #end  
                        
                        
                
                        #local texBrique  = texture
                              {      
                                 pigment
                                 {
                                    granite
                                    color_map
                                    {
                                       [ 0.0     rgbft <0.499564, 0.313733, 0.209567, 0.0, 0.0> * coefCol * fCol]
                                       [ 0.25    rgbft <0.649707, 0.511233, 0.376667, 0.0, 0.0> * coefCol  * fCol]
                                       [ 0.5     rgbft <0.499858, 0.313733, 0.251233, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                       [ 0.75    rgbft <0.699587, 0.4904, 0.251233, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                       [ 1.0     rgbft <0.499644, 0.3454, 0.157067, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                    }
                                    frequency 100.0
                                    ramp_wave
                                    scale  0.3
                                 }      
                                 normal
                                 {
                                    crackle , 0.03
                                    warp
                                    {
                                       turbulence <0.500164, 0.500364, 0.499804>
                        
                                       omega 0.500404
                                       lambda 1.999712
                                    }
                                    scale  0.3
                                 }      
                                 finish
                                 {
                                    ambient 0.1
                                    diffuse 0.549996
                                    specular 0.100002
                                    roughness 1.0
                                 }      
                        
                                 //  This texture was originally designed by Charles Fusner.
                        
                              }    
                              
                              #local brique =   superellipsoid { // sqBrique5
                                        <0.05+aleForme*rand(R1), 0.05>
                                        scale <xBrique/2,yBrique/2, zMur/2>
                                        texture  { texBrique }
                    
                                        translate  < xBrique/2-dPosBrique /2 + dPosBrique * rand(R1),  -dPosBrique /8 + dPosBrique/4 * rand(R1),  -dPosZBrique /2 + dPosZBrique * rand(R1)>
                                        rotate<aleRot/2-aleRot*rand(R1),.1*aleRot/2-.1*aleRot*rand(R1),aleRot/2-aleRot*rand(R1)>
                              }    
                              
                              object { 
                                        brique
                                        translate  <posX, posY, 0>  
                                        
                                     }
                                
                              #local posX  =  posX + xBrique +eMortier;
                              #local posThX  =  posThX + mxBrique +eMortier;
                        
                     #end // while x
                     #if  (posX < xMur-pMortier)
                             #local brique =   superellipsoid { // sqBrique5
                                        <0.07+aleForme*rand(R1), 0.05>
                                        scale <(xMur-posX)/2,yBrique/2, zMur/2>
                                        texture  { texBrique }
                    
                                        translate  < (xMur-posX)/2,  -dPosBrique /8 + dPosBrique * rand(R1) /4,  -dPosZBrique /2 + dPosZBrique * rand(R1)>
                                        rotate<aleRot/2-aleRot*rand(R1),.1*aleRot/2-.1*aleRot*rand(R1),aleRot/2-aleRot*rand(R1)>
                              }    
                              
                              object { 
                                        brique
                                        translate  <posX, posY, 0>  
                                        
                                     } 
                             #end // Brique de complment
                     #local posY  =  posY +myBrique +eMortier;
                        
              #end // y while y 
              }// union murProv
               union {
                     object {murProv scale<1,yMur/posY,1> translate y*yBrique/2}
                     murMortier  (xMur,yMur,zMur, pMortier, fColMort)
              }
              #declare txtLastBrick=texBrique;
#end //macro murBrique  

#macro murBriqueAlt  (xMur,yMur,zMur, xBriqueMin, xBriqueMax, yBriqueMin, yBriqueMax, eMortier, pMortier, alePos, aleRot, aleForme, aleCol, supAleX, supAleCol, supAleP, fColBas, fColHaut, fColMort, seedAle)
       
        #local R1 = seed(seedAle);      
        #local R2 = seed(seedAle+100);
        
        #local dxBrique  =  xBriqueMax - xBriqueMin;
        #local dyBrique  =  yBriqueMax - yBriqueMin;  
        
        #local mxBrique  =  (xBriqueMax + xBriqueMin) / 2;
        #local myBrique  =  (yBriqueMax + yBriqueMin) / 2;           
        
        #local dfCol = fColHaut-fColBas;
        
        #local dPosBrique = eMortier *  2 * alePos; 
        #local dPosZBrique = pMortier *  2 * alePos;
        #local nBriqueX = xMur / (mxBrique+eMortier);   
        #local nBriqueY = yMur / (myBrique+eMortier);  
        //#debug concat("Nombre de rangees prevues:",str(nBriqueY,5,0),"\n")
        #local posY = 0; 
        
        #local rangDecale = 0;
        
        #local murProv = union{
        # while  (posY < yMur -yBriqueMax ) 
                
                #local posX = 0;
                #local posThX = 0; 
                
                #if (rangDecale = 1)
                      #local demBrique = 1;
                      #local rangDecale = 0;
                #else 
                     #local rangDecale = 1;
                     #local demBrique = 0;
                #end   
                
                #local fCol = fColBas + dfCol * posY / yMur;
                //#debug concat("fCol en cours:",str(fCol,5,3),"\n")
                # while  (posX < xMur - mxBrique )     //()     
                        #local  aSupAleX = rand(R2) *supAleP ; 
                        #local  aSupAleCol = rand(R2) *supAleP ;  
                        
                        
                        #local xBrique = xBriqueMin +rand(R1) * dxBrique;
                        #if (aSupAleX <= 1)
                           #local xBrique = xBrique * (1 - supAleX/2 + rand(R1) * supAleX);
                        #end
                        
                        
                         
                        #if (demBrique = 1)
                                #local demBrique = 0;
                                #local xBrique = xBrique / 2; 
                                #local xBriqueTh = mxBrique/2;
                        #else 
                                
                                #local demBrique = 1;
                                #local xBriqueTh = mxBrique;
                                #if (posX = 0) 
                                        #local xBrique = xBrique * 3 / 4;
                                        #local xBriqueTh = mxBrique * 3 / 4; 
                                #end
                                    
                        #end
                        
                        //Rgulation de variation pour viter les briques superposes en fin de range
                        #if (abs((posX+xBrique)-(posThX+xBriqueTh)) > dxBrique)
                            #local xBrique = posThX+xBriqueTh - posX;  
                            //cylinder {<posX,posY,-zMur/1.5>,<posX,posY,zMur>,2 texture {pigment{rgb <1,1,1>} finish {ambient .6} }}
                             
                        #end
                        
                        #local yBrique = yBriqueMax +rand(R1) * dyBrique; 
                        
                        
                        #local coefCol = 1;
                        #if (aSupAleCol <= 1)
                            #local coefCol = 1 - supAleCol/3 + rand(R1) * supAleCol;
                        #end
                
                        #local texBrique  = texture
                              {      
                                 pigment
                                 {
                                    granite
                                    color_map
                                    {
                                       [ 0.0     rgbft <0.499564, 0.313733, 0.209567, 0.0, 0.0> * coefCol * fCol]
                                       [ 0.25    rgbft <0.649707, 0.511233, 0.326667, 0.0, 0.0> * coefCol  * fCol]
                                       [ 0.5     rgbft <0.499858, 0.313733, 0.211233, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                       [ 0.75    rgbft <0.699587, 0.4904, 0.211233, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                       [ 1.0     rgbft <0.499644, 0.3454, 0.127067, 0.0, 0.0>  * (1 + aleCol * rand(R1)) * coefCol  * fCol]
                                    }
                                    frequency 100.0
                                    ramp_wave
                                    scale  0.3
                                 }      
                                 normal
                                 {
                                    crackle , 0.03
                                    warp
                                    {
                                       turbulence <0.500164, 0.500364, 0.499804>
                        
                                       omega 0.500404
                                       lambda 1.999712
                                    }
                                    scale  0.3
                                 }      
                                 finish
                                 {
                                    ambient 0.1
                                    diffuse 0.549996
                                    specular 0.100002
                                    roughness 1.0
                                 }      
                        
                                 //  This texture was originally designed by Charles Fusner.
                        
                              }    
                              
                              #local brique =   superellipsoid { // sqBrique5
                                        <0.05+aleForme*rand(R1), 0.05>
                                        scale <xBrique/2,yBrique/2, zMur/2>
                                        texture  { texBrique }
                    
                                        translate  < xBrique/2-dPosBrique /2 + dPosBrique * rand(R1),  -dPosBrique /8 + dPosBrique * rand(R1) / 4,  -dPosZBrique /2 + dPosZBrique * rand(R1)>
                                        rotate<aleRot/2-aleRot*rand(R1),.1*aleRot/2-.1*aleRot*rand(R1),aleRot/2-aleRot*rand(R1)>
                              }    
                              
                              object { 
                                        brique
                                        translate  <posX, posY, 0>  
                                        
                                     }
                                
                              #local posX  =  posX + xBrique +eMortier; 
                              #local posThX  =  posThX + xBriqueTh +eMortier;
                              
                     #end // while x
                     #if  (posX < xMur-pMortier) 
                              #local brique =   superellipsoid { // sqBrique5
                                        <0.07+aleForme*rand(R1), 0.05>
                                        scale <(xMur-posX)/2,yBrique/2, zMur/2>
                                        texture  { texBrique }
                    
                                        translate  < (xMur-posX)/2,  -dPosBrique /8 + dPosBrique * rand(R1) /4,  -dPosZBrique /2 + dPosZBrique * rand(R1)>
                                        rotate<aleRot/2-aleRot*rand(R1),.1*aleRot/2-.1*aleRot*rand(R1),aleRot/2-aleRot*rand(R1)>
                              }    
                              
                              object { 
                                        brique
                                        translate  <posX, posY, 0>  
                                        
                                     }                                          
                     #end // Brique de complment 
                     #local posY  =  posY +myBrique +eMortier;
                     //#debug concat("posY:",str(posY,5,0),"\n")    
                     //#local supAleP = supAleCol + 1;
              #end // y while y 
              }// union murProv  
              union {
                     object {murProv scale<1,yMur/posY,1> translate y*yBrique/2}
                     murMortier  (xMur,yMur,zMur, pMortier, fColMort)
              }
              #declare txtLastBrick=texBrique;
#end //macro murBriqueAlt  
















#macro MakeWallImg(x1Wall,z1Wall,x2Wall, z2Wall,yWall,eWall,xBrick,yBrick,txtImgWall)


//-----------------------------------------  
       
        #local antizero = .0001;
        #local xWall = sqrt((x2Wall-x1Wall)*(x2Wall-x1Wall)+(z2Wall-z1Wall)*(z2Wall-z1Wall));
        #if (z2Wall >= z1Wall)
                #local AngleRad =  acos((x2Wall-x1Wall)/xWall);
        #else
                #local AngleRad =  acos(-(x2Wall-x1Wall)/xWall) + pi;
        #end
        #local AngleDeg = AngleRad * 180/pi;
                        
        box{0,<xWall,yWall,eWall> texture{txtImgWall scale <xBrick,yBrick,(xBrick+yBrick)/2>} translate -eWall/2*z}                       
                
                 
                rotate -AngleDeg*y
                #declare angleWall = AngleDeg;  
                #declare lengthWall = xWall;
                translate <x1Wall,0,z1Wall>
                #declare txtLastBrick=texture {txtImgWall scale <xBrick,yBrick,(xBrick+yBrick)/2>};
                
          
#end        //MakeWallImg(x1Wall,z1Wall,x2Wall, z2Wall,yWall,eWall,xBric,yBrick,txtImgWallMakeWallTex)


/////////// Macro for the clock /////// 
#macro makeClock(temps_heure24, temps_minuteH)

//#declare temps_heure24 = 14;
//#declare temps_minuteH = 40;

#declare temps_heure12 = mod(temps_heure24,12); 
#declare STD_clock = union {
        union {
            object{Obj_Aiguille04_Hre 
            pigment { BrightGold }
                 finish
                 {
                    ambient 0.15
                    diffuse 0.7
                    brilliance 6.0
                    phong 0.75
                    phong_size 10.0
                    reflection 0.25
                 } 
                 normal
                 {
                 bumps , .2
                 scale  <0.05, 0.05, .1>
                 }   
                 rotate -z * (90+(360 * temps_heure12 / 12)+(30 * temps_minuteH / 60))
             }  //
             object{Obj_Aiguille04_Min 
             pigment { BrightGold }
                     finish
                 {
                    ambient 0.15
                    diffuse 0.7
                    brilliance 6.0
                    phong 0.75
                    phong_size 10.0
                    reflection 0.25
                 }
                 normal
                 {
                 bumps , .2
                 scale  <0.05, 0.05, .1>
                 }
                 rotate -z * (90+(360 * temps_minuteH / 60))
            }
            object {cadran02}   
                         
            rotate y * 90
            translate -x*.25
        }//union horloge   
        union {
            object{Obj_Aiguille04_Hre 
            pigment { BrightGold }
                 finish
                 {
                    ambient 0.15
                    diffuse 0.7
                    brilliance 6.0
                    phong 0.75
                    phong_size 10.0
                    reflection 0.25
                 } 
                 normal
                 {
                 bumps , .2
                 scale  <0.05, 0.05, .1>
                 }   
                 rotate -z * (90+(360 * temps_heure12 / 12)+(30 * temps_minuteH / 60))
             }  //
             object{Obj_Aiguille04_Min 
             pigment { BrightGold }
                     finish
                 {
                    ambient 0.15
                    diffuse 0.7
                    brilliance 6.0
                    phong 0.75
                    phong_size 10.0
                    reflection 0.25
                 }
                 normal
                 {
                 bumps , .2
                 scale  <0.05, 0.05, .1>
                 }
                 rotate -z * (90+(360 * temps_minuteH / 60))
            }
            object {cadran02}   
                         
            rotate -y * 90
            translate x*.25
        }//union horloge

}

object {STD_clock translate 0*1}  
#end //makeClock(temps_heure24, temps_minuteH)





#macro ShopDoor(FWidth, FHeight, FDeepth, FThick ,DDeepth, DShift, AngleOpen, VsWidth, VmWidth,TeHeight, TmHeight, LckAlt, handlAng, lowPanelAlt, TexGloss, Tframe, dnpx, dnpy)
/*
 PARAMETERS EXAMPLES FOR THE MACRO
//User defined size  

//Outer frame size
#declare FWidth = 96;
#declare FHeight = 210; 
#declare AngleOpen = 115;

//Deepth of door frame (should fit with the wall thickness)
#declare FDeepth = 30;

//Deepth (or thickness) of door panel (z)
#declare DDeepth = 4; 

// how much the door goes deepin the frame from 0 to 1
#declare DShift = 0;


//thickness of door frame (x,y)
#declare FThick = 8; 

//width for side verticals
#declare VsWidth = 12;

//width for middle vertical
#declare VmWidth = 10;       

//Height of low and high transversals
#declare TeHeight = 15; 

//Height of middle low and high transversal
#declare TmHeight = 10;                
//Lock altitude above doors bottom will place the low transversal
//in such altitude the lock is at middle height of this transvrsal

//This transversal position will also determine the heights and altitudes of 
//low and middle panels  
#declare LckAlt = 105;
*/
// END OF EXAMPLE PARAMETERS 


        //For the transversals 
        #declare TexGlossTR  = texture {
          TexGloss
          normal {
            waves, 0.09 turbulence <.6,.6,0> translate y*1 scale<1, 0.1, 0.1>  
          }
          scale TeHeight / 6
        } 
        
        //For the verticals 
        #declare TexGlossVR  = texture {
          TexGloss
          normal {
            waves, 0.07 turbulence <.6,.6,0> scale< 0.15, 1, 0.15>
          }
          scale VsWidth/4
        }
        
        //For objects allong z like frame fronts 
        #declare TexGlossFR  = texture {
          TexGloss
          normal {
            waves, 0.07 turbulence <.6,.6,0> scale< 0.05, 0.05, 1>
          } 
          scale FThick / 3.5
        }  







        //////////////////////////////////////////////////////////////
        //getting all resulting sizes
        
        //Door size from frame size and thikness
        #declare DWidth = FWidth - 2 * FThick;    
        #declare DHeight = FHeight - FThick;  
        //#declare DS=DDeepth / 3;     // DS is space around the edge of a door to allow it to fit inside a door frame without touching
        #declare DS=1;
        
        //width for all transversals//
        #declare TWidth = DWidth - 2 * VsWidth;  
        
        //Altitude for lower transversal
        #declare TelAlt = DS;
        
        //Altitude for top transversal
        #declare TehAlt = DHeight - TeHeight; 
        //#debug concat("top Panel's alt is:",str(TehAlt,5,2),"\n")
        
        //Altitude for middle low transversal is dependent of lock's altitude (at it's middle)
        #declare TmlAlt = lowPanelAlt - TmHeight/2;         
        //#debug concat("mid low Panel's alt is:",str(TmlAlt,5,2),"\n")
        

        
        //panels dimensions
        //panels width        
        
        //************** Only one panel at bottom 
        #declare PWidth =  TWidth;
        //#debug concat("Panel's width is:",str(PWidth,5,2),"\n")  
        
        //panels height
        //Top panels are square, then...
        #declare PtHeight = PWidth;
        
        
        //Low panels height which are between bottom and low middle transversals  
        
        #declare PlHeight = TmlAlt - (TelAlt + TeHeight);
        //#debug concat("low Panel's height is:",str(PlHeight,5,2),"\n")
        
        
        
        //Objects for inner panels
        ///////////////////////////////////////////////////////  
        #declare DoorPanelWood = prism {
          linear_sweep linear_spline
          -(PWidth/2),(PWidth/2)
          9,
          <0,0>, <0,0.5*DDeepth/3>, <2*(PWidth/2)/4.5,0.5*DDeepth/3>, <2.1*(PWidth/2)/4.5,0.4*DDeepth/3>, 
          <3.5*(PWidth/2)/4.5,0.1*DDeepth/3>,<4*(PWidth/2)/4.5,0.1*DDeepth/3>, 
          <4.5*(PWidth/2)/4.5,0.5*DDeepth/3>, <4.5*(PWidth/2)/4.5,0>, <0,0>
          scale <1,1,-1>
        }
        
        #declare DoorPanelQuarter = intersection { 
        //Triangular piece of inner panel on top and bottom
        //Used also on side if the panel is square
          object { DoorPanelWood  }
          plane { y,0 rotate 45*z }
          plane { -y,0 rotate -45*z }
          //texture { WhiteGloss }
          texture { TexGlossVR scale <5,5,1>}
        }
        
        
        #declare DoorPanelLongPiece = intersection {     
        //Sides of long rectangular panel at bottom
          object { DoorPanelWood scale <1,2*PlHeight/PWidth,1> }
          plane { y,0 rotate 45*z }
          plane { -y,0 rotate -45*z translate -y*(PlHeight-PWidth) }
          //texture { WhiteGloss }   
          texture { TexGlossVR scale <5,5,1>}
        }
        
        
        #if (PlHeight >= PWidth)
         
                #declare DoorPanelLong = union {     
                //long rectangular panel at bottom
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelLongPiece }
                  object { DoorPanelLongPiece rotate 180*z translate -y*(PlHeight-PWidth) }
                  object { DoorPanelQuarter rotate 270*z translate -y*(PlHeight-PWidth) }
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PlHeight-PWidth/2,1*DDeepth/3>
                  scale<1.01,1.01,1>
                }
        #else
                  #declare DoorPanelLong  = union { 
                  //square panel on top
                  object { DoorPanelQuarter }
                  object { DoorPanelQuarter rotate 90*z }
                  object { DoorPanelQuarter rotate 180*z }
                  object { DoorPanelQuarter rotate 270*z }
                  scale<1.01,1.01,1>
                  translate <PWidth/2,PWidth/2,1*DDeepth/3>
                  scale <1,PlHeight/PWidth,1>
        } 
        #end
         
         
        
        
        
        
        //limits for vericals
        //near rotation
        #local sidevrx1 = DS;
        #local sidevrx2 = VsWidth;   
        
 
        
        //near lock
        #local sidevlx1 = VsWidth+PWidth;
        #local sidevlx2 = sidevlx1+VsWidth-DS;
        #declare DoorBox = union {
          box { <sidevrx1,DS,0>, <sidevrx2,DHeight-DS,DDeepth> texture { TexGlossVR }}        //vertical side near rotation axis
          //box { <sidevmx1,DS,0>, <sidevmx2,DHeight-DS,DDeepth> texture { TexGlossVR }}       //vertical in middle
          box { <sidevlx1,DS,0>, <sidevlx2,DHeight-DS,DDeepth> texture { TexGlossVR }}    //vertical side near lock 
          
          box { <sidevrx2,0,-0.005>, <sidevlx1,TeHeight-DS,DDeepth + 0.005> texture { TexGlossTR }  translate y*TelAlt}        //Tranversal low
          box { <sidevrx2,0,-0.005>, <sidevlx1,TmHeight,DDeepth + 0.005> texture { TexGlossTR } translate y*TmlAlt} //transversal between long and short panels
          //box { <sidevrx2,0,-0.005>, <sidevlx1,TmHeight,DDeepth + 0.005> texture { TexGlossTR } translate y*TmhAlt} //transversal between short and square panels
          box { <sidevrx2,0,-0.005>, <sidevlx1,TeHeight-DS,DDeepth + 0.005> texture { TexGlossTR } translate y*TehAlt} //Tranversal top
          //texture { Reperage }
        }

// Building the window panel

//Height is  TehAlt-(TmlAlt+TmHeight)
//Width is PWidth

#declare npx=dnpx;
#declare npy=dnpy;
#declare spx=0;
#declare spy=0;

#declare swx=PWidth;
#declare swy=TehAlt-(TmlAlt+TmHeight);
#declare thframe = DDeepth/1.2;

#declare thbp = 3.5;     

//#declare perfactor = 1;
//#declare Tframe = 1;
#declare typepatch = 1; 
#declare randseq = 25; 

#declare DoorPanelPatch = object {britwindowpanel(npx,npy,spx,spy,swx,swy,thframe,thbp,perfactor*0,Tframe,typepatch,randseq)
        translate <VsWidth,TmlAlt+TmHeight,DDeepth/2>
         
}

#declare DoorPatch = box {  <0,0,0><swx,swy,.5>
        
        texture {
                 pigment { 
                     //rgbt <0.45+rand(RP)/7, 0.50+rand(RP)/7, 0.5+rand(RP)/10, 0.95+rand(RP)/7>
                     //rgbt <0.25+rand(RP)/7, 0.30+rand(RP)/7, 0.3+rand(RP)/10, 0.95+rand(RP)/7>
                     //rgbt <0.10+rand(RP)/7, 0.12+rand(RP)/7, 0.13+rand(RP)/10, 0.98+rand(RP)/7>
                     rgbt <0.04, 0.06, 0.075, 0.98>        
                 } 
                 finish   { 
                     phong 0.07 phong_size 40  // A highlight
                     reflection { 0.22, rgb <1,0.8,0.9> * 0.77}  // Glass reflects a bit
                 }
                 
                 normal { 
                     bumps 0.02 scale <10,10,.3> 
                 }    
                 
                  
        }  
        
        //texture {Tframe}
        translate <VsWidth,TmlAlt+TmHeight,DDeepth/2>
}                                                


        
        
        //******** Only one panel used 
        #declare DoorSide = union { 
        //the six inner panels
          //object { DoorPanelSquare translate <VsWidth,TmhAlt+TmHeight,0> }
          //object { DoorPanelSquare translate <VsWidth+PWidth+VmWidth,TmhAlt+TmHeight,0> }
          //object { DoorPanelShort translate <VsWidth,TeHeight,0> }
          //object { DoorPanelShort translate <VsWidth+PWidth+VmWidth,TmlAlt+TmHeight,0> }
          object { DoorPanelLong translate <VsWidth,TeHeight+DS,0> }
          //object { DoorPanelLong translate <VsWidth+PWidth+VmWidth,TeHeight,0> } 
          object {DoorPanelPatch}
           object {DoorPatch}
        }
        











 //// Poignee ronde dans objfleet "copperknob"         
        
        
        
        #declare FBWidth = VsWidth - 4*DS; 
        
        #declare keyhole = union {
                cylinder {<-(2*DS+FBWidth/2),0,-DDeepth* 0.06>,<-(2*DS+FBWidth/2),0,DDeepth* 1.06>,1 }
                box      {<-.7,-FBWidth/2.5,-DDeepth* 0.06>,<.7,0,DDeepth* 1.06>
                          translate -x*(2*DS+FBWidth/2)}  
                translate -y*FBWidth/2
        }
         
         //face framing
         #declare FaceLockFrame= union {
         intersection {
                            torus {
                                FBWidth / 4, FBWidth / 30 
                            }
                            box { 
                                <-FBWidth/3, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <-FBWidth/2,TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <-FBWidth,TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<-FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <0,TmHeight*1.5,-DDeepth* 0.05>
                    } 
                    
                    
                    intersection {
                            torus {
                                FBWidth / 4, FBWidth / 30 
                            }
                            box { 
                                <-FBWidth/3, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*90
                            translate <-FBWidth/2,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <-FBWidth,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    intersection {
                            torus {
                                FBWidth / 5, FBWidth / 30 
                            }
                            box { 
                                <0, -FBWidth/30, 0>,<-FBWidth/3, FBWidth/30, FBWidth/3>
                            }
                            rotate x*-90
                            translate <0,-TmHeight*1.5,-DDeepth* 0.05>
                    }
                    cylinder { 
                        <-FBWidth, -(TmHeight*1.5-FBWidth/6), -DDeepth* 0.05>,<-FBWidth, TmHeight*1.5-FBWidth/6, -DDeepth* 0.05>,FBWidth/30 
                        translate  x*FBWidth/30   
                    }
                    cylinder { 
                        <0, -(TmHeight*1.5-FBWidth/6), -DDeepth* 0.05>,<0, TmHeight*1.5-FBWidth/6, -DDeepth* 0.05>,FBWidth/30 
                        translate  -x*FBWidth/30   
                    }
        } //object face lock framing           
         
        
        
        
        
        
        #declare clockbox = union {
         //inside lock
         box {<DS+.01,-TmHeight*.75,DDeepth* 0.1>,<-VsWidth*.7,TmHeight*.75,DDeepth*.9> texture{Steel_Texture} }
         //face lock  
        
         
         difference {
                 union { 
                    
                     
                    box {<0,-TmHeight*1.5,-DDeepth* 0.05>,<-FBWidth,TmHeight*1.5,DDeepth*1.05> }
                    cylinder {
                        <0,0,-DDeepth* 0.05>,<0,0,DDeepth* 1.05>,FBWidth / 3
                        translate <-FBWidth/2,-TmHeight*1.5,0> 
                    } 
                    cylinder {
                        <0,0,-DDeepth* 0.05>,<0,0,DDeepth* 1.05>,FBWidth / 3
                        translate <-FBWidth/2,TmHeight*1.5,0> 
                    }
                    
                       
                    
                    
                    object {FaceLockFrame}
                    object {FaceLockFrame translate z*DDeepth*1.1}
                    
                    
                    object {DoorHandleIr 
                            rotate z*handlAng
                            //scale FBWidth/2.5
                            translate <-FBWidth/2,0,0>}
                    
                    object {DoorHandleIr 
                            //scale FBWidth/2.5 
                            rotate x*180
                            translate <-FBWidth/2,0,DDeepth>}
                    
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <0,TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <-FBWidth,TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <0,-TmHeight*1.5,0> 
                 }
                 cylinder {
                        <0,0,-DDeepth* 0.1>,<0,0,DDeepth* 1.1>,FBWidth / 6
                        translate <-FBWidth,-TmHeight*1.5,0> 
                 }
                 //scale y*.65
                 texture {Copper_Texture scale 5*VsWidth/4}
         } 
         
         
         translate <-2*DS,TmHeight/2,0>
        
        }
        
        #declare gache = box {
                <-.01,-TmHeight*.75,DDeepth* 0.1>,<.9,TmHeight*.75,DDeepth*.9> 
                texture {Steel_Texture scale VsWidth/4}
                translate <DWidth-.1,LckAlt+TmHeight/2,0>
        }
        
        
        
        
        
        
        
        
        
        #declare DoorPanel =  difference {
        union {
          object { DoorBox }
          object { DoorSide }
          object { DoorSide scale <1,1,-1> translate z*DDeepth } 
          object {clockbox translate <DWidth, LckAlt,0>}
          
          
          
        }  
          object {keyhole translate <DWidth, LckAlt,0> }
        }
        
        // 29" x 6'6" door, frame out dim=3.5" wider
        
        // scale along the z axis before use
        
        #declare DoorFrameWood = union {
          cylinder { <0.5,3.5-0.75,0>, <0.5,3.5-0.75,1>, 0.5 }
          difference {
            box { <0,0,0>, <1,3.5,1> }
            box { <0.5,3.5-1.05,-0.01>, <1.01,3.51,1.01> }
            cylinder { <1.05,3.5-1.05,-0.01>, <1.05,3.5-1.05,1.01>, 0.5 } 
            
          }
          scale <FThick/3.5,FThick/3.5,1>
          texture { TexGlossFR}
        }
        
        
        #declare DoorFrameTop = intersection {
          object { DoorFrameWood scale <1,-1,FWidth> }
          plane { -y,0 rotate 45*x }
          plane { -y,0 rotate -45*x translate FWidth*z}  
          
        }
        
        #declare DoorFrameLeft = intersection {
          object { DoorFrameWood scale <1,-1,FHeight> }
          plane { -y,0 rotate 45*x }
          rotate 90*x
          translate FWidth*z
        }
        
        #declare DoorFrameRight = intersection {
          object { DoorFrameWood scale <1,-1,FHeight> }
          plane { -y,0 rotate 45*x }
          rotate 90*x
          scale <1,1,-1>
        }
        
        #declare DoorFrame1 = union {
          object { DoorFrameTop }
          object { DoorFrameLeft }
          object { DoorFrameRight }
          rotate 90*y translate FHeight*y
        }
        
        #declare DoorFrame = union {
          object { DoorFrame1 }
          object { DoorFrame1 scale <1,1,-1> translate FDeepth*z }
          difference {
            box { <0,0,0>, <FWidth-0, FHeight-0, FDeepth - 0.001> }
            box { <FThick,-0.01,-0.001>, <FWidth-FThick, FHeight-FThick, FDeepth + 0.001>}
            texture { TexGlossVR }
          }           
          
          // Inside frame
            difference {
            box { <FThick,0,DDeepth+(FDeepth-DDeepth)*DShift>, <FWidth-FThick, FHeight-FThick, FDeepth - 0.001> }
            box { <FThick+DS*1.5,-0.01,-0.001>, <FWidth-(FThick+DS*1.5), FHeight-(FThick+DS*1.5), FDeepth + 0.001>}
            texture { TexGlossVR }
          }
          
          
          
        }  
        
        
        
        
        
        
        // for bounding or CSG use
        #declare DoorSpace = box { <0,0,-0.01>, <FWidth, FHeight, 9.01> pigment { Black } translate -0.5*z }
        
        #declare Door = union {
          object { DoorFrame }
          object { DoorPanel rotate AngleOpen*y translate <FThick,0,(FDeepth-DDeepth)*DShift> } 
          object {gache translate <FThick,0,(FDeepth-DDeepth)*DShift>}
        }
        
        object { Door translate -FThick*x*0}
#end //macro  ShopDoor   


#macro curtain01(xcm,ycm,zplis,howclosed,nrd,textex,qMode)
        //Tringle
        #declare tringle = cylinder { // Cylndr001
          <0,0,0>, <1,0,0>, 1 
          material {
            Copper_Metal1
          }
          scale <xcm, 1, 1>
          translate  <0, -0.0, 0.0>
        }   
        
        
        
        
        #declare uniRidAn = union {
                union { //tores
                        torus { // Torus007
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <9.931574, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus006
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <5.73724, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus005
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <1.689392, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus004
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <-1.186577, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus003
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <-4.135789, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus002
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <-7.158244, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus001
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.35
                          rotate -90.0*y
                          translate  <-10.034213, -0.29297, 0.0>
                        }   
                        translate <11,0,0>
                        
                }// Union tores
                
                
                        union { // BezPtch001
                   #if (qMode = 1)
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.997723, -19.217677, 0.000000>, <-9.404680, -20.218987, -6.114650>, <-8.230900, -20.107731, 4.076433>, <-7.347488, -19.662704, 2.038217>, 
                              <-9.997723, -18.217677, 0.000000>, <-9.404680, -19.218987, -6.114650>, <-8.230900, -19.107731, 4.076433>, <-7.347488, -18.662704, 2.038217>, 
                              <-9.997723, -17.217677, 0.000000>, <-9.404680, -18.218987, -6.114650>, <-8.230900, -18.107731, 4.076433>, <-7.687191, -17.662704, 2.377919>, 
                              <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.814580, -16.662704, 2.547771>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.814580, -16.662704, 2.547771>, 
                              <-9.893648, -15.217677, 0.000000>, <-9.404680, -16.218987, -6.114650>, <-8.910305, -16.107731, 4.755839>, <-8.026894, -15.662704, 2.717622>, 
                              <-9.893648, -14.217677, 0.000000>, <-9.300605, -15.218987, -6.114650>, <-8.910305, -15.107731, 4.755839>, <-8.026894, -14.662704, 2.717622>, 
                              <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.835811, -13.662704, 2.547771>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.835811, -13.662704, 2.547771>, 
                              <-9.893648, -12.217677, 0.000000>, <-9.300605, -13.218987, -6.114650>, <-8.910305, -13.107731, 4.755839>, <-7.687191, -12.662704, 2.377919>, 
                              <-9.893648, -11.106421, 0.000000>, <-9.300605, -12.218987, -6.114650>, <-8.230900, -12.107731, 4.076433>, <-7.347488, -11.607076, 2.038217>, 
                              <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>, 
                              <-9.893648, -9.217677, 0.000000>, <-9.300605, -10.218987, -6.114650>, <-8.230900, -10.218987, 4.076433>, <-7.050248, -8.034535, 2.505308>, 
                              <-9.893648, -8.217677, 0.000000>, <-9.300605, -9.218987, -6.114650>, <-8.230900, -9.218987, 4.076433>, <-7.050248, -7.034535, 2.505308>, 
                              <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>, 
                              <-9.893648, -6.217677, 0.000000>, <-9.300605, -7.218987, -6.114650>, <-8.230900, -7.218987, 4.076433>, <-7.347488, -6.718332, 2.038217>, 
                              <-10.081791, 8.893017, 0.000000>, <-9.300605, -6.218987, -6.114650>, <-8.230900, -6.218987, 4.076433>, <-7.441560, 1.337015, 2.038217>, 
                              <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>, 
                              <-10.081791, 10.893017, 0.000000>, <-9.488748, 9.891708, -6.114650>, <-8.419043, 9.891708, 4.076433>, <-7.535631, 10.392362, 2.038217>, 
                              <-10.081791, 11.893017, 0.000000>, <-9.488748, 10.891708, -6.114650>, <-8.419043, 10.891708, 4.076433>, <-7.535631, 11.392362, 2.038217>, 
                              <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>, 
                              <-10.185866, 13.893017, 0.000000>, <-9.592823, 12.891708, -6.114650>, <-8.419043, 12.891708, 4.076433>, <-7.535631, 13.392362, 2.038217>, 
                              <-10.185866, 14.893017, 0.000000>, <-9.592823, 16.156779, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.524898, 2.038217>, 
                              <-10.394016, 19.753449, 0.000000>, <-9.592823, 17.156779, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.347488, -19.662704, 2.038217>, <-6.464077, -19.217677, 0.000000>, <-5.503996, -20.218987, -3.481953>, <-4.528825, -19.718332, -1.740977>, 
                              <-7.347488, -18.662704, 2.038217>, <-6.464077, -18.217677, 0.000000>, <-5.503996, -19.218987, -3.481953>, <-4.528825, -18.718332, -1.740977>, 
                              <-7.687191, -17.662704, 2.377919>, <-7.143482, -17.217677, 0.679406>, <-5.503996, -18.218987, -3.481953>, <-4.528825, -17.718332, -1.740977>, 
                              <-7.814580, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.814580, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>, 
                              <-8.026894, -15.662704, 2.717622>, <-7.143482, -15.217677, 0.679406>, <-5.816221, -16.218987, -3.481953>, <-4.684938, -15.718332, -1.740977>, 
                              <-8.026894, -14.662704, 2.717622>, <-7.143482, -14.217677, 0.679406>, <-5.816221, -15.218987, -3.481953>, <-4.684938, -14.718332, -1.740977>, 
                              <-7.835811, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.835811, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>, 
                              <-7.687191, -12.662704, 2.377919>, <-6.464077, -12.217677, 0.000000>, <-5.816221, -13.218987, -3.481953>, <-4.684938, -12.718332, -1.740977>, 
                              <-7.347488, -11.607076, 2.038217>, <-6.464077, -11.106421, 0.000000>, <-5.816221, -12.218987, -3.481953>, <-4.684938, -11.662704, -1.740977>, 
                              <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>, 
                              <-7.050248, -8.034535, 2.505308>, <-5.869597, -5.850082, 0.934183>, <-4.909516, -6.851392, -2.547771>, <-4.231585, -8.034535, -1.273885>, 
                              <-7.050248, -7.034535, 2.505308>, <-5.869597, -4.850082, 0.934183>, <-4.909516, -5.851392, -2.547771>, <-4.231585, -7.034535, -1.273885>, 
                              <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>, 
                              <-7.347488, -6.718332, 2.038217>, <-6.464077, -6.217677, 0.000000>, <-5.503996, -7.218987, -3.481953>, <-4.424750, -6.718332, -1.740977>, 
                              <-7.441560, 1.337015, 2.038217>, <-6.652219, 8.893017, 0.000000>, <-5.321964, -2.487328, -3.481953>, <-4.518821, 2.611240, -2.462845>, 
                              <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>, 
                              <-7.535631, 10.392362, 2.038217>, <-6.652219, 10.893017, 0.000000>, <-5.692139, 9.891708, -3.481953>, <-4.612893, 10.392362, -1.740977>, 
                              <-7.535631, 11.392362, 2.038217>, <-6.652219, 11.893017, 0.000000>, <-5.692139, 10.891708, -3.481953>, <-4.716968, 11.392362, -1.740977>, 
                              <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>, 
                              <-7.535631, 13.392362, 2.038217>, <-6.652219, 13.893017, 0.000000>, <-5.692139, 12.891708, -3.481953>, <-4.716968, 13.392362, -1.740977>, 
                              <-7.535631, 15.524898, 2.038217>, <-6.652219, 14.893017, 0.000000>, <-5.692139, 13.891708, -3.481953>, <-4.716968, 14.392362, -1.740977>, 
                              <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 14.891708, -3.481953>, <-4.957567, 18.792890, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.528825, -19.718332, -1.740977>, <-3.553654, -19.217677, 0.000000>, <-2.379874, -20.107731, 3.651805>, <-1.563590, -19.662704, 1.825902>, 
                              <-4.528825, -18.718332, -1.740977>, <-3.553654, -18.217677, 0.000000>, <-2.379874, -19.107731, 3.651805>, <-1.563590, -18.662704, 1.825902>, 
                              <-4.528825, -17.718332, -1.740977>, <-3.553654, -17.217677, 0.000000>, <-2.379874, -18.107731, 3.651805>, <-1.563590, -17.662704, 1.825902>, 
                              <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>, 
                              <-4.684938, -15.718332, -1.740977>, <-3.553654, -15.217677, 0.000000>, <-2.379874, -16.107731, 3.651805>, <-1.563590, -15.662704, 1.825902>, 
                              <-4.684938, -14.718332, -1.740977>, <-3.553654, -14.217677, 0.000000>, <-2.379874, -15.107731, 3.651805>, <-1.563590, -14.662704, 1.825902>, 
                              <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>, 
                              <-4.684938, -12.718332, -1.740977>, <-3.553654, -12.217677, 0.000000>, <-2.379874, -13.107731, 3.651805>, <-1.563590, -12.662704, 1.825902>, 
                              <-4.684938, -11.662704, -1.740977>, <-3.553654, -11.106421, 0.000000>, <-2.379874, -12.107731, 3.651805>, <-1.563590, -11.607076, 1.825902>, 
                              <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>, 
                              <-4.231585, -8.034535, -1.273885>, <-3.553654, -9.217677, 0.000000>, <-2.379874, -10.218987, 3.651805>, <-1.563590, -9.718332, 1.825902>, 
                              <-4.231585, -7.034535, -1.273885>, <-3.553654, -8.217677, 0.000000>, <-2.379874, -9.218987, 3.651805>, <-1.609098, -6.533946, 2.462845>, 
                              <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>, 
                              <-4.424750, -6.718332, -1.740977>, <-3.345504, -6.217677, 0.000000>, <-2.379874, -7.218987, 3.651805>, <-1.609098, -4.533946, 2.462845>, 
                              <-4.518821, 2.611240, -2.462845>, <-3.715679, 7.709808, -1.443737>, <-2.379874, -6.218987, 3.651805>, <-1.748678, 0.745411, 1.104034>, 
                              <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>, 
                              <-4.612893, 10.392362, -1.740977>, <-3.533647, 10.893017, 0.000000>, <-2.750049, 8.708498, 2.208068>, <-1.842749, 9.800758, 1.104034>, 
                              <-4.716968, 11.392362, -1.740977>, <-3.741797, 11.893017, 0.000000>, <-2.568017, 10.891708, 3.651805>, <-1.751733, 11.392362, 1.825902>, 
                              <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>, 
                              <-4.716968, 13.392362, -1.740977>, <-3.741797, 13.893017, 0.000000>, <-2.568017, 12.891708, 3.651805>, <-1.751733, 13.392362, 1.825902>, 
                              <-4.716968, 14.392362, -1.740977>, <-3.741797, 14.893017, 0.000000>, <-2.568017, 13.891708, 3.651805>, <-1.751733, 14.392362, 1.825902>, 
                              <-4.957567, 18.792890, -1.740977>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 14.891708, 3.651805>, <-1.855808, 18.747382, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -19.662704, 1.825902>, <-0.747307, -19.217677, 0.000000>, <0.188143, -20.218987, -3.397028>, <1.188143, -19.718332, -1.698514>, 
                              <-1.563590, -18.662704, 1.825902>, <-0.747307, -18.217677, 0.000000>, <0.188143, -19.218987, -3.397028>, <1.188143, -18.718332, -1.698514>, 
                              <-1.563590, -17.662704, 1.825902>, <-0.747307, -17.217677, 0.000000>, <0.188143, -18.218987, -3.397028>, <1.021258, -17.773961, -1.698514>, 
                              <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>, 
                              <-1.563590, -15.662704, 1.825902>, <-0.747307, -15.217677, 0.000000>, <0.188143, -16.218987, -3.397028>, <1.021258, -15.773961, -1.698514>, 
                              <-1.563590, -14.662704, 1.825902>, <-0.747307, -14.217677, 0.000000>, <0.188143, -15.218987, -3.397028>, <1.021258, -14.773961, -1.698514>, 
                              <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>, 
                              <-1.563590, -12.662704, 1.825902>, <-0.747307, -12.217677, 0.000000>, <0.188143, -13.218987, -3.397028>, <1.021258, -12.773961, -1.698514>, 
                              <-1.563590, -11.607076, 1.825902>, <-0.747307, -11.106421, 0.000000>, <0.188143, -12.218987, -3.397028>, <1.188143, -11.662704, -1.698514>, 
                              <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>, 
                              <-1.563590, -9.718332, 1.825902>, <-0.747307, -9.217677, 0.000000>, <0.188143, -10.218987, -3.397028>, <1.324667, -8.080043, -1.698514>, 
                              <-1.609098, -6.533946, 2.462845>, <-0.838323, -3.848905, 1.273885>, <0.188143, -9.218987, -3.397028>, <1.324667, -7.080043, -1.698514>, 
                              <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>, 
                              <-1.609098, -4.533946, 2.462845>, <-0.838323, -1.848905, 1.273885>, <0.097127, -2.850215, -2.123142>, <1.142635, -4.533946, -1.061571>, 
                              <-1.748678, 0.745411, 1.104034>, <-1.117481, 7.709808, -1.443737>, <0.097127, -1.850215, -2.123142>, <1.048563, 3.521401, -1.061571>, 
                              <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>, 
                              <-1.842749, 9.800758, 1.104034>, <-0.935449, 10.893017, 0.000000>, <-0.182032, 8.708498, -4.840764>, <0.908984, 9.800758, -2.420382>, 
                              <-1.751733, 11.392362, 1.825902>, <-0.935449, 11.893017, 0.000000>, <0.000000, 10.891708, -3.397028>, <1.000000, 11.392362, -1.698514>, 
                              <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>, 
                              <-1.751733, 13.392362, 1.825902>, <-0.935449, 13.893017, 0.000000>, <0.000000, 12.891708, -3.397028>, <1.000000, 13.392362, -1.698514>, 
                              <-1.751733, 14.392362, 1.825902>, <-0.935449, 14.893017, 0.000000>, <0.000000, 13.891708, -3.397028>, <1.000000, 14.392362, -1.698514>, 
                              <-1.855808, 18.747382, 1.825902>, <-1.143599, 22.603056, 0.000000>, <0.000000, 14.891708, -3.397028>, <0.888743, 18.747382, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.188143, -19.718332, -1.698514>, <2.188143, -19.217677, 0.000000>, <3.188143, -20.107731, 3.227176>, <4.188143, -19.662704, 1.528662>, 
                              <1.188143, -18.718332, -1.698514>, <2.188143, -18.217677, 0.000000>, <3.188143, -19.107731, 3.227176>, <4.188143, -18.662704, 1.528662>, 
                              <1.021258, -17.773961, -1.698514>, <1.854373, -17.328934, 0.000000>, <3.188143, -18.107731, 3.227176>, <4.188143, -17.662704, 1.528662>, 
                              <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>, 
                              <1.021258, -15.773961, -1.698514>, <1.854373, -15.328934, 0.000000>, <2.854373, -16.218987, 3.227176>, <4.021258, -15.718332, 1.528662>, 
                              <1.021258, -14.773961, -1.698514>, <1.854373, -14.328934, 0.000000>, <2.854373, -15.218987, 3.227176>, <4.021258, -14.718332, 1.528662>, 
                              <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>, 
                              <1.021258, -12.773961, -1.698514>, <1.854373, -12.328934, 0.000000>, <2.854373, -13.218987, 3.227176>, <4.132514, -12.718332, 1.528662>, 
                              <1.188143, -11.662704, -1.698514>, <2.188143, -11.106421, 0.000000>, <2.854373, -12.218987, 3.227176>, <4.132514, -11.662704, 1.528662>, 
                              <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>, 
                              <1.324667, -8.080043, -1.698514>, <2.461191, -5.941098, 0.000000>, <3.188143, -10.218987, 3.227176>, <4.299399, -9.718332, 1.528662>, 
                              <1.324667, -7.080043, -1.698514>, <2.461191, -4.941098, 0.000000>, <3.188143, -9.218987, 3.227176>, <4.299399, -8.718332, 1.528662>, 
                              <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>, 
                              <1.142635, -4.533946, -1.061571>, <2.188143, -6.217677, 0.000000>, <3.188143, -7.218987, 3.227176>, <4.299399, -6.718332, 1.528662>, 
                              <1.048563, 3.521401, -1.061571>, <2.000000, 8.893017, 0.000000>, <3.188143, -6.218987, 3.227176>, <4.205328, 1.337015, 1.528662>, 
                              <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>, 
                              <0.908984, 9.800758, -2.420382>, <2.000000, 10.893017, 0.000000>, <3.000000, 9.891708, 3.227176>, <4.000000, 10.392362, 1.528662>, 
                              <1.000000, 11.392362, -1.698514>, <2.000000, 11.893017, 0.000000>, <3.000000, 10.891708, 3.227176>, <4.000000, 11.392362, 1.528662>, 
                              <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>, 
                              <1.000000, 13.392362, -1.698514>, <2.000000, 13.893017, 0.000000>, <3.000000, 12.891708, 3.227176>, <4.000000, 13.392362, 1.528662>, 
                              <1.000000, 14.392362, -1.698514>, <2.000000, 14.893017, 0.000000>, <3.000000, 13.891708, 3.227176>, <4.000000, 14.392362, 1.528662>, 
                              <0.888743, 18.747382, -1.698514>, <1.777487, 22.603056, 0.000000>, <3.000000, 14.891708, 3.227176>, <4.516881, 18.682654, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.188143, -19.662704, 1.528662>, <5.188143, -19.217677, -0.169851>, <6.188143, -20.218987, -3.821656>, <7.315531, -20.035970, 0.127389>, 
                              <4.188143, -18.662704, 1.528662>, <5.188143, -18.217677, -0.169851>, <6.188143, -19.218987, -3.821656>, <7.315531, -19.035970, 0.127389>, 
                              <4.188143, -17.662704, 1.528662>, <5.188143, -17.217677, -0.169851>, <6.188143, -18.218987, -3.821656>, <7.315531, -18.035970, 0.127389>, 
                              <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.315531, -17.035970, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.315531, -17.035970, 0.127389>, 
                              <4.021258, -15.718332, 1.528662>, <5.188143, -15.217677, -0.169851>, <6.188143, -16.218987, -3.821656>, <7.315531, -16.035970, 0.127389>, 
                              <4.021258, -14.718332, 1.528662>, <5.188143, -14.217677, -0.169851>, <6.188143, -15.218987, -3.821656>, <7.315531, -15.035970, 0.127389>, 
                              <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.315531, -14.035970, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.315531, -14.035970, 0.127389>, 
                              <4.132514, -12.718332, 1.528662>, <5.410656, -12.217677, -0.169851>, <6.188143, -13.218987, -3.821656>, <7.315531, -13.035970, 0.127389>, 
                              <4.132514, -11.662704, 1.528662>, <5.410656, -11.106421, -0.169851>, <6.410656, -12.218987, -3.821656>, <7.426788, -12.035970, 0.127389>, 
                              <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -3.821656>, <7.426788, -11.063785, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -3.821656>, <7.426788, -11.063785, 0.127389>, 
                              <4.299399, -9.718332, 1.528662>, <5.410656, -9.217677, -0.169851>, <6.410656, -10.218987, -3.821656>, <7.426788, -10.091599, 0.127389>, 
                              <4.299399, -8.718332, 1.528662>, <5.410656, -8.217677, -0.169851>, <6.410656, -9.218987, -3.821656>, <7.426788, -9.091599, 0.127389>, 
                              <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -3.821656>, <7.426788, -8.091599, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -3.821656>, <7.426788, -8.091599, 0.127389>, 
                              <4.299399, -6.718332, 1.528662>, <5.410656, -6.217677, -0.169851>, <6.410656, -7.218987, -3.821656>, <7.426788, -7.091599, 0.127389>, 
                              <4.205328, 1.337015, 1.528662>, <5.222513, 8.893017, -0.169851>, <6.410656, -6.218987, -3.821656>, <7.426788, -6.091599, 0.127389>, 
                              <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -3.821656>, <7.277088, 1.963749, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -3.821656>, <7.277088, 1.963749, 0.127389>, 
                              <4.000000, 10.392362, 1.528662>, <5.000000, 10.893017, -0.169851>, <6.000000, 9.891708, -3.821656>, <7.127389, 10.019096, 0.127389>, 
                              <4.000000, 11.392362, 1.528662>, <5.000000, 11.893017, -0.169851>, <6.000000, 10.891708, -3.821656>, <7.127389, 11.019096, 0.127389>, 
                              <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, 0.127389>, 
                              <4.000000, 13.392362, 1.528662>, <5.000000, 13.893017, -0.169851>, <6.000000, 15.150663, -3.821656>, <7.127389, 15.278052, 0.127389>, 
                              <4.000000, 14.392362, 1.528662>, <5.000000, 14.893017, -0.169851>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, 0.127389>, 
                              <4.516881, 18.682654, 1.528662>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -20.035970, 0.127389>, <8.442920, -19.852954, 4.076433>, <9.188143, -19.217677, 0.000000>, <10.188143, -20.218987, 0.000000>, 
                              <7.315531, -19.035970, 0.127389>, <8.442920, -18.852954, 4.076433>, <9.188143, -18.217677, 0.000000>, <10.188143, -19.218987, 0.000000>, 
                              <7.315531, -18.035970, 0.127389>, <8.442920, -17.852954, 4.076433>, <9.188143, -17.217677, 0.000000>, <10.188143, -18.218987, 0.000000>, 
                              <7.315531, -17.035970, 0.127389>, <8.442920, -16.852954, 4.076433>, <9.188143, -16.217677, 0.000000>, <10.188143, -17.218987, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -17.035970, 0.127389>, <8.442920, -16.852954, 4.076433>, <9.188143, -16.217677, 0.000000>, <10.188143, -17.218987, 0.000000>, 
                              <7.315531, -16.035970, 0.127389>, <8.442920, -15.852954, 4.076433>, <9.188143, -15.217677, 0.000000>, <10.188143, -16.218987, 0.000000>, 
                              <7.315531, -15.035970, 0.127389>, <8.442920, -14.852954, 4.076433>, <8.965629, -14.662704, 0.000000>, <10.188143, -15.218987, 0.000000>, 
                              <7.315531, -14.035970, 0.127389>, <8.442920, -13.852954, 4.076433>, <8.965629, -13.662704, 0.000000>, <10.076886, -14.441501, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -14.035970, 0.127389>, <8.442920, -13.852954, 4.076433>, <8.965629, -13.662704, 0.000000>, <10.076886, -14.441501, 0.000000>, 
                              <7.315531, -13.035970, 0.127389>, <8.442920, -12.852954, 4.076433>, <8.965629, -12.662704, 0.000000>, <9.965629, -13.664014, 0.000000>, 
                              <7.426788, -12.035970, 0.127389>, <8.442920, -11.852954, 4.076433>, <8.965629, -11.551447, 0.000000>, <9.965629, -12.664014, 0.000000>, 
                              <7.426788, -11.063785, 0.127389>, <8.442920, -10.908582, 4.076433>, <8.965629, -10.607076, 0.000000>, <9.965629, -11.664014, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.426788, -11.063785, 0.127389>, <8.442920, -10.908582, 4.076433>, <8.965629, -10.607076, 0.000000>, <9.965629, -11.664014, 0.000000>, 
                              <7.426788, -10.091599, 0.127389>, <8.442920, -9.964210, 4.076433>, <8.965629, -9.662704, 0.000000>, <9.965629, -10.664014, 0.000000>, 
                              <7.426788, -9.091599, 0.127389>, <8.442920, -8.964210, 4.076433>, <8.965629, -8.662704, 0.000000>, <9.965629, -9.664014, 0.000000>, 
                              <7.426788, -8.091599, 0.127389>, <8.442920, -7.964210, 4.076433>, <8.965629, -7.662704, 0.000000>, <9.965629, -8.664014, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.426788, -8.091599, 0.127389>, <8.442920, -7.964210, 4.076433>, <8.965629, -7.662704, 0.000000>, <9.965629, -8.664014, 0.000000>, 
                              <7.426788, -7.091599, 0.127389>, <8.442920, -6.964210, 4.076433>, <8.965629, -6.662704, 0.000000>, <9.965629, -7.664014, 0.000000>, 
                              <7.426788, -6.091599, 0.127389>, <8.442920, -5.964210, 4.076433>, <8.777487, 8.447991, 0.000000>, <9.965629, -6.664014, 0.000000>, 
                              <7.277088, 1.963749, 0.127389>, <8.348848, 2.091137, 4.076433>, <8.777487, 9.447991, 0.000000>, <9.871558, 1.391333, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.277088, 1.963749, 0.127389>, <8.348848, 2.091137, 4.076433>, <8.777487, 9.447991, 0.000000>, <9.871558, 1.391333, 0.000000>, 
                              <7.127389, 10.019096, 0.127389>, <8.254777, 10.146485, 4.076433>, <8.777487, 10.447991, 0.000000>, <9.777487, 9.446681, 0.000000>, 
                              <7.127389, 11.019096, 0.127389>, <8.254777, 11.146485, 4.076433>, <8.777487, 11.447991, 0.000000>, <9.777487, 10.446681, 0.000000>, 
                              <7.127389, 13.148574, 0.127389>, <8.254777, 13.275962, 4.076433>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.127389, 13.148574, 0.127389>, <8.254777, 13.275962, 4.076433>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, 0.000000>, 
                              <7.127389, 15.278052, 0.127389>, <8.254777, 15.405440, 4.076433>, <9.000000, 13.893017, 0.000000>, <10.111257, 14.894327, 0.000000>, 
                              <7.127389, 16.278052, 0.127389>, <8.254777, 16.405440, 4.076433>, <9.000000, 14.893017, 0.000000>, <10.000000, 13.891708, 0.000000>, 
                              <7.127389, 17.278052, 0.127389>, <8.254777, 17.405440, 4.076433>, <10.797790, 24.684825, 0.000000>, <10.000000, 14.891708, 0.000000>
                            }
                          }
                  #else    
                        box {<-9.997723, -19.217677, 0.000000>,<10.000000, 14.891708, 0.000000>}
                    
                  #end                               
                  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.50*ycm/100,zplis>
                }
                translate <-1,0,0>
        scale 100/20 
        scale <xcm/100,1,1>
        scale <howclosed/nrd,1,1>
                
        
        
        }//Rideaux et anneaux
        
        union {
                object {tringle}
                object {uniRidAn}   
                
                #if (nrd=2)
                        object{
                                uniRidAn
                                scale<-1,1,1>
                                translate <xcm,0,0>
                        }
                #end
        }
#end // macro curtain01        




#macro RideauVar (xcm,ycm,zplis,howclosed,nrd,textex,qMode)
        //Tringle
        #declare tringle = union {
           cylinder { // Cylndr001
              <0,0,0>, <1,0,0>, 1 
              material {Copper_Metal1}
             scale <xcm, 1, 1>
             translate  <0, -0.0, 0.0> 
           }
           object {
                copperknob  
                rotate y*90
                scale 2.5 
                translate <-1,0,0.25>
           }
           object {
                copperknob  
                rotate -y*90
                scale 2.5 
                translate <xcm-1,0,-0.25>
           }
        }   
        
        
 #declare RideauCalme = union { // BezPtch001
                   #if (qMode = 1)
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.997723, -19.217677, 0.000000>, <-9.404680, -20.218987, -6.114650>, <-8.230900, -20.107731, 4.076433>, <-7.347488, -19.662704, 2.038217>, 
                              <-9.997723, -18.217677, 0.000000>, <-9.404680, -19.218987, -6.114650>, <-8.230900, -19.107731, 4.076433>, <-7.347488, -18.662704, 2.038217>, 
                              <-9.997723, -17.217677, 0.000000>, <-9.404680, -18.218987, -6.114650>, <-8.230900, -18.107731, 4.076433>, <-7.687191, -17.662704, 2.377919>, 
                              <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.814580, -16.662704, 2.547771>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.814580, -16.662704, 2.547771>, 
                              <-9.893648, -15.217677, 0.000000>, <-9.404680, -16.218987, -6.114650>, <-8.910305, -16.107731, 4.755839>, <-8.026894, -15.662704, 2.717622>, 
                              <-9.893648, -14.217677, 0.000000>, <-9.300605, -15.218987, -6.114650>, <-8.910305, -15.107731, 4.755839>, <-8.026894, -14.662704, 2.717622>, 
                              <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.835811, -13.662704, 2.547771>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.835811, -13.662704, 2.547771>, 
                              <-9.893648, -12.217677, 0.000000>, <-9.300605, -13.218987, -6.114650>, <-8.910305, -13.107731, 4.755839>, <-7.687191, -12.662704, 2.377919>, 
                              <-9.893648, -11.106421, 0.000000>, <-9.300605, -12.218987, -6.114650>, <-8.230900, -12.107731, 4.076433>, <-7.347488, -11.607076, 2.038217>, 
                              <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>, 
                              <-9.893648, -9.217677, 0.000000>, <-9.300605, -10.218987, -6.114650>, <-8.230900, -10.218987, 4.076433>, <-7.050248, -8.034535, 2.505308>, 
                              <-9.893648, -8.217677, 0.000000>, <-9.300605, -9.218987, -6.114650>, <-8.230900, -9.218987, 4.076433>, <-7.050248, -7.034535, 2.505308>, 
                              <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>, 
                              <-9.893648, -6.217677, 0.000000>, <-9.300605, -7.218987, -6.114650>, <-8.230900, -7.218987, 4.076433>, <-7.347488, -6.718332, 2.038217>, 
                              <-10.081791, 8.893017, 0.000000>, <-9.300605, -6.218987, -6.114650>, <-8.230900, -6.218987, 4.076433>, <-7.441560, 1.337015, 2.038217>, 
                              <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>, 
                              <-10.081791, 10.893017, 0.000000>, <-9.488748, 9.891708, -6.114650>, <-8.419043, 9.891708, 4.076433>, <-7.535631, 10.392362, 2.038217>, 
                              <-10.081791, 11.893017, 0.000000>, <-9.488748, 10.891708, -6.114650>, <-8.419043, 10.891708, 4.076433>, <-7.535631, 11.392362, 2.038217>, 
                              <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>, 
                              <-10.185866, 13.893017, 0.000000>, <-9.592823, 12.891708, -6.114650>, <-8.419043, 12.891708, 4.076433>, <-7.535631, 13.392362, 2.038217>, 
                              <-10.185866, 14.893017, 0.000000>, <-9.592823, 16.156779, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.524898, 2.038217>, 
                              <-10.394016, 19.753449, 0.000000>, <-9.592823, 17.156779, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.347488, -19.662704, 2.038217>, <-6.464077, -19.217677, 0.000000>, <-5.503996, -20.218987, -3.481953>, <-4.528825, -19.718332, -1.740977>, 
                              <-7.347488, -18.662704, 2.038217>, <-6.464077, -18.217677, 0.000000>, <-5.503996, -19.218987, -3.481953>, <-4.528825, -18.718332, -1.740977>, 
                              <-7.687191, -17.662704, 2.377919>, <-7.143482, -17.217677, 0.679406>, <-5.503996, -18.218987, -3.481953>, <-4.528825, -17.718332, -1.740977>, 
                              <-7.814580, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.814580, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>, 
                              <-8.026894, -15.662704, 2.717622>, <-7.143482, -15.217677, 0.679406>, <-5.816221, -16.218987, -3.481953>, <-4.684938, -15.718332, -1.740977>, 
                              <-8.026894, -14.662704, 2.717622>, <-7.143482, -14.217677, 0.679406>, <-5.816221, -15.218987, -3.481953>, <-4.684938, -14.718332, -1.740977>, 
                              <-7.835811, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.835811, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>, 
                              <-7.687191, -12.662704, 2.377919>, <-6.464077, -12.217677, 0.000000>, <-5.816221, -13.218987, -3.481953>, <-4.684938, -12.718332, -1.740977>, 
                              <-7.347488, -11.607076, 2.038217>, <-6.464077, -11.106421, 0.000000>, <-5.816221, -12.218987, -3.481953>, <-4.684938, -11.662704, -1.740977>, 
                              <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>, 
                              <-7.050248, -8.034535, 2.505308>, <-5.869597, -5.850082, 0.934183>, <-4.909516, -6.851392, -2.547771>, <-4.231585, -8.034535, -1.273885>, 
                              <-7.050248, -7.034535, 2.505308>, <-5.869597, -4.850082, 0.934183>, <-4.909516, -5.851392, -2.547771>, <-4.231585, -7.034535, -1.273885>, 
                              <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>, 
                              <-7.347488, -6.718332, 2.038217>, <-6.464077, -6.217677, 0.000000>, <-5.503996, -7.218987, -3.481953>, <-4.424750, -6.718332, -1.740977>, 
                              <-7.441560, 1.337015, 2.038217>, <-6.652219, 8.893017, 0.000000>, <-5.321964, -2.487328, -3.481953>, <-4.518821, 2.611240, -2.462845>, 
                              <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>, 
                              <-7.535631, 10.392362, 2.038217>, <-6.652219, 10.893017, 0.000000>, <-5.692139, 9.891708, -3.481953>, <-4.612893, 10.392362, -1.740977>, 
                              <-7.535631, 11.392362, 2.038217>, <-6.652219, 11.893017, 0.000000>, <-5.692139, 10.891708, -3.481953>, <-4.716968, 11.392362, -1.740977>, 
                              <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>, 
                              <-7.535631, 13.392362, 2.038217>, <-6.652219, 13.893017, 0.000000>, <-5.692139, 12.891708, -3.481953>, <-4.716968, 13.392362, -1.740977>, 
                              <-7.535631, 15.524898, 2.038217>, <-6.652219, 14.893017, 0.000000>, <-5.692139, 13.891708, -3.481953>, <-4.716968, 14.392362, -1.740977>, 
                              <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 14.891708, -3.481953>, <-4.957567, 18.792890, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.528825, -19.718332, -1.740977>, <-3.553654, -19.217677, 0.000000>, <-2.379874, -20.107731, 3.651805>, <-1.563590, -19.662704, 1.825902>, 
                              <-4.528825, -18.718332, -1.740977>, <-3.553654, -18.217677, 0.000000>, <-2.379874, -19.107731, 3.651805>, <-1.563590, -18.662704, 1.825902>, 
                              <-4.528825, -17.718332, -1.740977>, <-3.553654, -17.217677, 0.000000>, <-2.379874, -18.107731, 3.651805>, <-1.563590, -17.662704, 1.825902>, 
                              <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>, 
                              <-4.684938, -15.718332, -1.740977>, <-3.553654, -15.217677, 0.000000>, <-2.379874, -16.107731, 3.651805>, <-1.563590, -15.662704, 1.825902>, 
                              <-4.684938, -14.718332, -1.740977>, <-3.553654, -14.217677, 0.000000>, <-2.379874, -15.107731, 3.651805>, <-1.563590, -14.662704, 1.825902>, 
                              <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>, 
                              <-4.684938, -12.718332, -1.740977>, <-3.553654, -12.217677, 0.000000>, <-2.379874, -13.107731, 3.651805>, <-1.563590, -12.662704, 1.825902>, 
                              <-4.684938, -11.662704, -1.740977>, <-3.553654, -11.106421, 0.000000>, <-2.379874, -12.107731, 3.651805>, <-1.563590, -11.607076, 1.825902>, 
                              <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>, 
                              <-4.231585, -8.034535, -1.273885>, <-3.553654, -9.217677, 0.000000>, <-2.379874, -10.218987, 3.651805>, <-1.563590, -9.718332, 1.825902>, 
                              <-4.231585, -7.034535, -1.273885>, <-3.553654, -8.217677, 0.000000>, <-2.379874, -9.218987, 3.651805>, <-1.609098, -6.533946, 2.462845>, 
                              <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>, 
                              <-4.424750, -6.718332, -1.740977>, <-3.345504, -6.217677, 0.000000>, <-2.379874, -7.218987, 3.651805>, <-1.609098, -4.533946, 2.462845>, 
                              <-4.518821, 2.611240, -2.462845>, <-3.715679, 7.709808, -1.443737>, <-2.379874, -6.218987, 3.651805>, <-1.748678, 0.745411, 1.104034>, 
                              <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>, 
                              <-4.612893, 10.392362, -1.740977>, <-3.533647, 10.893017, 0.000000>, <-2.750049, 8.708498, 2.208068>, <-1.842749, 9.800758, 1.104034>, 
                              <-4.716968, 11.392362, -1.740977>, <-3.741797, 11.893017, 0.000000>, <-2.568017, 10.891708, 3.651805>, <-1.751733, 11.392362, 1.825902>, 
                              <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>, 
                              <-4.716968, 13.392362, -1.740977>, <-3.741797, 13.893017, 0.000000>, <-2.568017, 12.891708, 3.651805>, <-1.751733, 13.392362, 1.825902>, 
                              <-4.716968, 14.392362, -1.740977>, <-3.741797, 14.893017, 0.000000>, <-2.568017, 13.891708, 3.651805>, <-1.751733, 14.392362, 1.825902>, 
                              <-4.957567, 18.792890, -1.740977>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 14.891708, 3.651805>, <-1.855808, 18.747382, 1.825902>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -19.662704, 1.825902>, <-0.747307, -19.217677, 0.000000>, <0.188143, -20.218987, -3.397028>, <1.188143, -19.718332, -1.698514>, 
                              <-1.563590, -18.662704, 1.825902>, <-0.747307, -18.217677, 0.000000>, <0.188143, -19.218987, -3.397028>, <1.188143, -18.718332, -1.698514>, 
                              <-1.563590, -17.662704, 1.825902>, <-0.747307, -17.217677, 0.000000>, <0.188143, -18.218987, -3.397028>, <1.021258, -17.773961, -1.698514>, 
                              <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>, 
                              <-1.563590, -15.662704, 1.825902>, <-0.747307, -15.217677, 0.000000>, <0.188143, -16.218987, -3.397028>, <1.021258, -15.773961, -1.698514>, 
                              <-1.563590, -14.662704, 1.825902>, <-0.747307, -14.217677, 0.000000>, <0.188143, -15.218987, -3.397028>, <1.021258, -14.773961, -1.698514>, 
                              <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>, 
                              <-1.563590, -12.662704, 1.825902>, <-0.747307, -12.217677, 0.000000>, <0.188143, -13.218987, -3.397028>, <1.021258, -12.773961, -1.698514>, 
                              <-1.563590, -11.607076, 1.825902>, <-0.747307, -11.106421, 0.000000>, <0.188143, -12.218987, -3.397028>, <1.188143, -11.662704, -1.698514>, 
                              <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>, 
                              <-1.563590, -9.718332, 1.825902>, <-0.747307, -9.217677, 0.000000>, <0.188143, -10.218987, -3.397028>, <1.324667, -8.080043, -1.698514>, 
                              <-1.609098, -6.533946, 2.462845>, <-0.838323, -3.848905, 1.273885>, <0.188143, -9.218987, -3.397028>, <1.324667, -7.080043, -1.698514>, 
                              <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>, 
                              <-1.609098, -4.533946, 2.462845>, <-0.838323, -1.848905, 1.273885>, <0.097127, -2.850215, -2.123142>, <1.142635, -4.533946, -1.061571>, 
                              <-1.748678, 0.745411, 1.104034>, <-1.117481, 7.709808, -1.443737>, <0.097127, -1.850215, -2.123142>, <1.048563, 3.521401, -1.061571>, 
                              <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>, 
                              <-1.842749, 9.800758, 1.104034>, <-0.935449, 10.893017, 0.000000>, <-0.182032, 8.708498, -4.840764>, <0.908984, 9.800758, -2.420382>, 
                              <-1.751733, 11.392362, 1.825902>, <-0.935449, 11.893017, 0.000000>, <0.000000, 10.891708, -3.397028>, <1.000000, 11.392362, -1.698514>, 
                              <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>, 
                              <-1.751733, 13.392362, 1.825902>, <-0.935449, 13.893017, 0.000000>, <0.000000, 12.891708, -3.397028>, <1.000000, 13.392362, -1.698514>, 
                              <-1.751733, 14.392362, 1.825902>, <-0.935449, 14.893017, 0.000000>, <0.000000, 13.891708, -3.397028>, <1.000000, 14.392362, -1.698514>, 
                              <-1.855808, 18.747382, 1.825902>, <-1.143599, 22.603056, 0.000000>, <0.000000, 14.891708, -3.397028>, <0.888743, 18.747382, -1.698514>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.188143, -19.718332, -1.698514>, <2.188143, -19.217677, 0.000000>, <3.188143, -20.107731, 3.227176>, <4.188143, -19.662704, 1.528662>, 
                              <1.188143, -18.718332, -1.698514>, <2.188143, -18.217677, 0.000000>, <3.188143, -19.107731, 3.227176>, <4.188143, -18.662704, 1.528662>, 
                              <1.021258, -17.773961, -1.698514>, <1.854373, -17.328934, 0.000000>, <3.188143, -18.107731, 3.227176>, <4.188143, -17.662704, 1.528662>, 
                              <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>, 
                              <1.021258, -15.773961, -1.698514>, <1.854373, -15.328934, 0.000000>, <2.854373, -16.218987, 3.227176>, <4.021258, -15.718332, 1.528662>, 
                              <1.021258, -14.773961, -1.698514>, <1.854373, -14.328934, 0.000000>, <2.854373, -15.218987, 3.227176>, <4.021258, -14.718332, 1.528662>, 
                              <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>, 
                              <1.021258, -12.773961, -1.698514>, <1.854373, -12.328934, 0.000000>, <2.854373, -13.218987, 3.227176>, <4.132514, -12.718332, 1.528662>, 
                              <1.188143, -11.662704, -1.698514>, <2.188143, -11.106421, 0.000000>, <2.854373, -12.218987, 3.227176>, <4.132514, -11.662704, 1.528662>, 
                              <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>, 
                              <1.324667, -8.080043, -1.698514>, <2.461191, -5.941098, 0.000000>, <3.188143, -10.218987, 3.227176>, <4.299399, -9.718332, 1.528662>, 
                              <1.324667, -7.080043, -1.698514>, <2.461191, -4.941098, 0.000000>, <3.188143, -9.218987, 3.227176>, <4.299399, -8.718332, 1.528662>, 
                              <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>, 
                              <1.142635, -4.533946, -1.061571>, <2.188143, -6.217677, 0.000000>, <3.188143, -7.218987, 3.227176>, <4.299399, -6.718332, 1.528662>, 
                              <1.048563, 3.521401, -1.061571>, <2.000000, 8.893017, 0.000000>, <3.188143, -6.218987, 3.227176>, <4.205328, 1.337015, 1.528662>, 
                              <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>, 
                              <0.908984, 9.800758, -2.420382>, <2.000000, 10.893017, 0.000000>, <3.000000, 9.891708, 3.227176>, <4.000000, 10.392362, 1.528662>, 
                              <1.000000, 11.392362, -1.698514>, <2.000000, 11.893017, 0.000000>, <3.000000, 10.891708, 3.227176>, <4.000000, 11.392362, 1.528662>, 
                              <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>, 
                              <1.000000, 13.392362, -1.698514>, <2.000000, 13.893017, 0.000000>, <3.000000, 12.891708, 3.227176>, <4.000000, 13.392362, 1.528662>, 
                              <1.000000, 14.392362, -1.698514>, <2.000000, 14.893017, 0.000000>, <3.000000, 13.891708, 3.227176>, <4.000000, 14.392362, 1.528662>, 
                              <0.888743, 18.747382, -1.698514>, <1.777487, 22.603056, 0.000000>, <3.000000, 14.891708, 3.227176>, <4.516881, 18.682654, 1.528662>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.188143, -19.662704, 1.528662>, <5.188143, -19.217677, -0.169851>, <6.188143, -20.218987, -3.821656>, <7.315531, -20.035970, 0.127389>, 
                              <4.188143, -18.662704, 1.528662>, <5.188143, -18.217677, -0.169851>, <6.188143, -19.218987, -3.821656>, <7.315531, -19.035970, 0.127389>, 
                              <4.188143, -17.662704, 1.528662>, <5.188143, -17.217677, -0.169851>, <6.188143, -18.218987, -3.821656>, <7.315531, -18.035970, 0.127389>, 
                              <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.315531, -17.035970, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.315531, -17.035970, 0.127389>, 
                              <4.021258, -15.718332, 1.528662>, <5.188143, -15.217677, -0.169851>, <6.188143, -16.218987, -3.821656>, <7.315531, -16.035970, 0.127389>, 
                              <4.021258, -14.718332, 1.528662>, <5.188143, -14.217677, -0.169851>, <6.188143, -15.218987, -3.821656>, <7.315531, -15.035970, 0.127389>, 
                              <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.315531, -14.035970, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.315531, -14.035970, 0.127389>, 
                              <4.132514, -12.718332, 1.528662>, <5.410656, -12.217677, -0.169851>, <6.188143, -13.218987, -3.821656>, <7.315531, -13.035970, 0.127389>, 
                              <4.132514, -11.662704, 1.528662>, <5.410656, -11.106421, -0.169851>, <6.410656, -12.218987, -3.821656>, <7.426788, -12.035970, 0.127389>, 
                              <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -3.821656>, <7.426788, -11.063785, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -3.821656>, <7.426788, -11.063785, 0.127389>, 
                              <4.299399, -9.718332, 1.528662>, <5.410656, -9.217677, -0.169851>, <6.410656, -10.218987, -3.821656>, <7.426788, -10.091599, 0.127389>, 
                              <4.299399, -8.718332, 1.528662>, <5.410656, -8.217677, -0.169851>, <6.410656, -9.218987, -3.821656>, <7.426788, -9.091599, 0.127389>, 
                              <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -3.821656>, <7.426788, -8.091599, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -3.821656>, <7.426788, -8.091599, 0.127389>, 
                              <4.299399, -6.718332, 1.528662>, <5.410656, -6.217677, -0.169851>, <6.410656, -7.218987, -3.821656>, <7.426788, -7.091599, 0.127389>, 
                              <4.205328, 1.337015, 1.528662>, <5.222513, 8.893017, -0.169851>, <6.410656, -6.218987, -3.821656>, <7.426788, -6.091599, 0.127389>, 
                              <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -3.821656>, <7.277088, 1.963749, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -3.821656>, <7.277088, 1.963749, 0.127389>, 
                              <4.000000, 10.392362, 1.528662>, <5.000000, 10.893017, -0.169851>, <6.000000, 9.891708, -3.821656>, <7.127389, 10.019096, 0.127389>, 
                              <4.000000, 11.392362, 1.528662>, <5.000000, 11.893017, -0.169851>, <6.000000, 10.891708, -3.821656>, <7.127389, 11.019096, 0.127389>, 
                              <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, 0.127389>, 
                              <4.000000, 13.392362, 1.528662>, <5.000000, 13.893017, -0.169851>, <6.000000, 15.150663, -3.821656>, <7.127389, 15.278052, 0.127389>, 
                              <4.000000, 14.392362, 1.528662>, <5.000000, 14.893017, -0.169851>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, 0.127389>, 
                              <4.516881, 18.682654, 1.528662>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, 0.127389>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -20.035970, 0.127389>, <8.442920, -19.852954, 4.076433>, <9.188143, -19.217677, 0.000000>, <10.188143, -20.218987, 0.000000>, 
                              <7.315531, -19.035970, 0.127389>, <8.442920, -18.852954, 4.076433>, <9.188143, -18.217677, 0.000000>, <10.188143, -19.218987, 0.000000>, 
                              <7.315531, -18.035970, 0.127389>, <8.442920, -17.852954, 4.076433>, <9.188143, -17.217677, 0.000000>, <10.188143, -18.218987, 0.000000>, 
                              <7.315531, -17.035970, 0.127389>, <8.442920, -16.852954, 4.076433>, <9.188143, -16.217677, 0.000000>, <10.188143, -17.218987, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -17.035970, 0.127389>, <8.442920, -16.852954, 4.076433>, <9.188143, -16.217677, 0.000000>, <10.188143, -17.218987, 0.000000>, 
                              <7.315531, -16.035970, 0.127389>, <8.442920, -15.852954, 4.076433>, <9.188143, -15.217677, 0.000000>, <10.188143, -16.218987, 0.000000>, 
                              <7.315531, -15.035970, 0.127389>, <8.442920, -14.852954, 4.076433>, <8.965629, -14.662704, 0.000000>, <10.188143, -15.218987, 0.000000>, 
                              <7.315531, -14.035970, 0.127389>, <8.442920, -13.852954, 4.076433>, <8.965629, -13.662704, 0.000000>, <10.076886, -14.441501, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.315531, -14.035970, 0.127389>, <8.442920, -13.852954, 4.076433>, <8.965629, -13.662704, 0.000000>, <10.076886, -14.441501, 0.000000>, 
                              <7.315531, -13.035970, 0.127389>, <8.442920, -12.852954, 4.076433>, <8.965629, -12.662704, 0.000000>, <9.965629, -13.664014, 0.000000>, 
                              <7.426788, -12.035970, 0.127389>, <8.442920, -11.852954, 4.076433>, <8.965629, -11.551447, 0.000000>, <9.965629, -12.664014, 0.000000>, 
                              <7.426788, -11.063785, 0.127389>, <8.442920, -10.908582, 4.076433>, <8.965629, -10.607076, 0.000000>, <9.965629, -11.664014, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.426788, -11.063785, 0.127389>, <8.442920, -10.908582, 4.076433>, <8.965629, -10.607076, 0.000000>, <9.965629, -11.664014, 0.000000>, 
                              <7.426788, -10.091599, 0.127389>, <8.442920, -9.964210, 4.076433>, <8.965629, -9.662704, 0.000000>, <9.965629, -10.664014, 0.000000>, 
                              <7.426788, -9.091599, 0.127389>, <8.442920, -8.964210, 4.076433>, <8.965629, -8.662704, 0.000000>, <9.965629, -9.664014, 0.000000>, 
                              <7.426788, -8.091599, 0.127389>, <8.442920, -7.964210, 4.076433>, <8.965629, -7.662704, 0.000000>, <9.965629, -8.664014, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.426788, -8.091599, 0.127389>, <8.442920, -7.964210, 4.076433>, <8.965629, -7.662704, 0.000000>, <9.965629, -8.664014, 0.000000>, 
                              <7.426788, -7.091599, 0.127389>, <8.442920, -6.964210, 4.076433>, <8.965629, -6.662704, 0.000000>, <9.965629, -7.664014, 0.000000>, 
                              <7.426788, -6.091599, 0.127389>, <8.442920, -5.964210, 4.076433>, <8.777487, 8.447991, 0.000000>, <9.965629, -6.664014, 0.000000>, 
                              <7.277088, 1.963749, 0.127389>, <8.348848, 2.091137, 4.076433>, <8.777487, 9.447991, 0.000000>, <9.871558, 1.391333, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.277088, 1.963749, 0.127389>, <8.348848, 2.091137, 4.076433>, <8.777487, 9.447991, 0.000000>, <9.871558, 1.391333, 0.000000>, 
                              <7.127389, 10.019096, 0.127389>, <8.254777, 10.146485, 4.076433>, <8.777487, 10.447991, 0.000000>, <9.777487, 9.446681, 0.000000>, 
                              <7.127389, 11.019096, 0.127389>, <8.254777, 11.146485, 4.076433>, <8.777487, 11.447991, 0.000000>, <9.777487, 10.446681, 0.000000>, 
                              <7.127389, 13.148574, 0.127389>, <8.254777, 13.275962, 4.076433>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, 0.000000>
                            }
                          }
                          object {
                            bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
                              <7.127389, 13.148574, 0.127389>, <8.254777, 13.275962, 4.076433>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, 0.000000>, 
                              <7.127389, 15.278052, 0.127389>, <8.254777, 15.405440, 4.076433>, <9.000000, 13.893017, 0.000000>, <10.111257, 14.894327, 0.000000>, 
                              <7.127389, 16.278052, 0.127389>, <8.254777, 16.405440, 4.076433>, <9.000000, 14.893017, 0.000000>, <10.000000, 13.891708, 0.000000>, 
                              <7.127389, 17.278052, 0.127389>, <8.254777, 17.405440, 4.076433>, <10.797790, 24.684825, 0.000000>, <10.000000, 14.891708, 0.000000>
                            }
                          }
                  #else    
                        box {<-9.997723, -19.217677, 0.000000>,<10.000000, 14.891708, 0.000000>}
                    
                  #end                               
                  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.50*ycm/100,zplis>
                }   //Union RideauCalme
                
                
                #declare RideauVolant = union { // BezPtch001
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-15.595451, -26.992441, -10.112585>, <-11.935352, -23.227272, -11.966807>, <-9.290693, -21.248413, -8.876437>, <-7.440247, -20.772598, -9.494511>, 
      <-13.177575, -21.087505, -10.112585>, <-11.935352, -22.158089, -11.966807>, <-9.290693, -20.179230, -8.876437>, <-7.440247, -19.703415, -9.494511>, 
      <-14.903516, -13.592308, -10.831713>, <-11.935352, -21.088906, -11.966807>, <-9.290693, -19.110047, -8.876437>, <-9.091830, -16.351177, -9.751063>, 
      <-14.793934, -12.523124, -10.831713>, <-12.795010, -16.806715, -12.326371>, <-10.952145, -15.757809, -9.132989>, <-9.922556, -14.140467, -9.879339>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.793934, -12.523124, -10.831713>, <-12.795010, -16.806715, -12.326371>, <-10.952145, -15.757809, -9.132989>, <-9.922556, -14.140467, -9.879339>, 
      <-14.684352, -11.453941, -10.831713>, <-13.654667, -12.524525, -12.685935>, <-12.613598, -12.405571, -9.389541>, <-10.753282, -11.929756, -10.007615>, 
      <-14.684352, -10.384758, -10.831713>, <-13.435503, -11.455342, -12.685935>, <-12.613598, -11.336388, -9.389541>, <-10.753282, -10.860573, -10.007615>, 
      <-15.167192, -7.034150, -10.023461>, <-13.920960, -8.109883, -11.877683>, <-13.100777, -7.990357, -8.581289>, <-10.888180, -7.512253, -9.250869>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-15.167192, -7.034150, -10.023461>, <-13.920960, -8.109883, -11.877683>, <-13.100777, -7.990357, -8.581289>, <-10.888180, -7.512253, -9.250869>, 
      <-15.650032, -3.683542, -9.215209>, <-14.406417, -4.764423, -11.069431>, <-13.587956, -4.644325, -7.773036>, <-11.023078, -4.163934, -8.494123>, 
      <-15.650032, -2.483977, -9.215209>, <-14.406417, -3.684956, -11.069431>, <-12.163239, -3.564858, -7.979061>, <-10.310719, -3.024418, -8.597135>, 
      <-14.190991, -0.054629, -6.907407>, <-13.066935, -1.041302, -9.719610>, <-11.039412, -0.981253, -5.032605>, <-8.655647, 0.604566, -5.056396>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.190991, -0.054629, -6.907407>, <-13.066935, -1.041302, -9.719610>, <-11.039412, -0.981253, -5.032605>, <-8.655647, 0.604566, -5.056396>, 
      <-12.731951, 2.374718, -4.599604>, <-11.727453, 1.602353, -8.369788>, <-9.915586, 1.602353, -2.086149>, <-7.000575, 4.233549, -1.515657>, 
      <-12.731951, 3.146073, -4.599604>, <-11.727453, 2.373708, -8.369788>, <-9.915586, 2.373708, -2.086149>, <-7.979070, 5.074767, -0.575983>, 
      <-11.579954, 4.798474, -3.060385>, <-10.610352, 3.848609, -6.830569>, <-8.861425, 3.848609, -0.546929>, <-7.196986, 5.480980, -0.420210>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-11.579954, 4.798474, -3.060385>, <-10.610352, 3.848609, -6.830569>, <-8.861425, 3.848609, -0.546929>, <-7.196986, 5.480980, -0.420210>, 
      <-10.427958, 6.450874, -1.521166>, <-9.493250, 5.323510, -5.291349>, <-7.807265, 5.323510, 0.992290>, <-6.414901, 5.887192, -0.264438>, 
      <-10.458312, 8.773199, -0.838727>, <-9.493250, 6.449399, -5.291349>, <-7.807265, 6.449399, 0.992290>, <-6.907709, 7.611299, 0.076782>, 
      <-10.458312, 9.773199, -0.838727>, <-9.591019, 8.110644, -6.122363>, <-8.054010, 8.110644, 2.114998>, <-7.031081, 8.941922, 0.638136>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.458312, 9.773199, -0.838727>, <-9.591019, 8.110644, -6.122363>, <-8.054010, 8.110644, 2.114998>, <-7.031081, 8.941922, 0.638136>, 
      <-10.458312, 10.773199, -0.838727>, <-9.688788, 9.771889, -6.953376>, <-8.300755, 9.771889, 3.237707>, <-7.154453, 10.272544, 1.199490>, 
      <-10.081791, 11.893017, 0.000000>, <-9.688788, 10.771889, -6.953376>, <-8.300755, 10.771889, 3.237707>, <-7.476487, 11.332453, 1.618853>, 
      <-10.133828, 12.893017, 0.000000>, <-9.640805, 11.831798, -6.534013>, <-8.359899, 11.831798, 3.657070>, <-7.506059, 12.362408, 1.828535>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.133828, 12.893017, 0.000000>, <-9.640805, 11.831798, -6.534013>, <-8.359899, 11.831798, 3.657070>, <-7.506059, 12.362408, 1.828535>, 
      <-10.185866, 13.893017, 0.000000>, <-9.592823, 12.891708, -6.114650>, <-8.419043, 12.891708, 4.076433>, <-7.535631, 13.392362, 2.038217>, 
      <-10.185866, 14.893017, 0.000000>, <-9.592823, 16.156779, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.524898, 2.038217>, 
      <-10.394016, 19.753449, 0.000000>, <-9.592823, 17.156779, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.440247, -20.772598, -9.494511>, <-5.589802, -20.296783, -10.112585>, <-3.578761, -21.367367, -11.168461>, <-1.536111, -22.691980, -10.640523>, 
      <-7.440247, -19.703415, -9.494511>, <-5.589802, -19.227600, -10.112585>, <-3.578761, -20.298184, -11.168461>, <-1.536111, -21.622797, -10.640523>, 
      <-9.091830, -16.351177, -9.751063>, <-8.892966, -13.592308, -10.625689>, <-3.578761, -19.229001, -11.168461>, <-2.456078, -16.410654, -11.000087>, 
      <-9.922556, -14.140467, -9.879339>, <-8.892966, -12.523124, -10.625689>, <-4.838370, -15.876763, -11.528026>, <-3.085882, -14.199944, -11.179869>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.922556, -14.140467, -9.879339>, <-8.892966, -12.523124, -10.625689>, <-4.838370, -15.876763, -11.528026>, <-3.085882, -14.199944, -11.179869>, 
      <-10.753282, -11.929756, -10.007615>, <-8.892966, -11.453941, -10.625689>, <-6.097978, -12.524525, -11.887590>, <-3.715687, -11.989233, -11.359652>, 
      <-10.753282, -10.860573, -10.007615>, <-8.892966, -10.384758, -10.625689>, <-6.097978, -11.455342, -11.887590>, <-3.715687, -10.920050, -11.359652>, 
      <-10.888180, -7.512253, -9.250869>, <-8.675583, -7.034150, -9.920449>, <-6.598811, -8.109883, -11.079338>, <-4.221511, -7.572016, -10.551399>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.888180, -7.512253, -9.250869>, <-8.675583, -7.034150, -9.920449>, <-6.598811, -8.109883, -11.079338>, <-4.221511, -7.572016, -10.551399>, 
      <-11.023078, -4.163934, -8.494123>, <-8.458200, -3.683542, -9.215209>, <-7.099643, -4.764423, -10.271085>, <-4.727335, -4.223983, -9.743147>, 
      <-10.310719, -3.024418, -8.597135>, <-8.458200, -2.483977, -9.215209>, <-7.099643, -3.684956, -10.271085>, <-4.727335, -3.084467, -9.743147>, 
      <-8.655647, 0.604566, -5.056396>, <-6.271882, 2.190384, -5.080187>, <-4.836002, 1.026213, -6.681580>, <-3.505073, 0.485792, -6.794494>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-8.655647, 0.604566, -5.056396>, <-6.271882, 2.190384, -5.080187>, <-4.836002, 1.026213, -6.681580>, <-3.505073, 0.485792, -6.794494>, 
      <-7.000575, 4.233549, -1.515657>, <-4.085565, 6.864746, -0.945165>, <-2.572362, 5.737382, -3.092076>, <-2.282812, 4.056050, -3.845840>, 
      <-7.979070, 5.074767, -0.575983>, <-6.042554, 7.775826, 0.934183>, <-2.572362, 6.863271, -3.092076>, <-2.282812, 5.004672, -3.845840>, 
      <-7.196986, 5.480980, -0.420210>, <-5.532546, 7.113350, -0.293492>, <-3.040848, 6.093391, -3.380076>, <-2.045562, 5.445932, -3.220230>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.196986, 5.480980, -0.420210>, <-5.532546, 7.113350, -0.293492>, <-3.040848, 6.093391, -3.380076>, <-2.045562, 5.445932, -3.220230>, 
      <-6.414901, 5.887192, -0.264438>, <-5.022537, 6.450874, -1.521166>, <-3.509334, 5.323510, -3.668076>, <-1.808312, 5.887192, -2.594621>, 
      <-6.907709, 7.611299, 0.076782>, <-6.008152, 8.773199, -0.838727>, <-4.695471, 1.696090, -6.746515>, <-4.205575, 4.702949, -4.095126>, 
      <-7.031081, 8.941922, 0.638136>, <-6.008152, 9.773199, -0.838727>, <-4.728919, 5.733990, -5.533597>, <-3.783764, 7.487747, -3.337414>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.031081, 8.941922, 0.638136>, <-6.008152, 9.773199, -0.838727>, <-4.728919, 5.733990, -5.533597>, <-3.783764, 7.487747, -3.337414>, 
      <-7.154453, 10.272544, 1.199490>, <-6.008152, 10.773199, -0.838727>, <-4.762366, 9.771889, -4.320680>, <-3.361953, 10.272544, -2.579703>, 
      <-7.476487, 11.332453, 1.618853>, <-6.652219, 11.893017, 0.000000>, <-4.762366, 10.771889, -4.320680>, <-4.252081, 11.332453, -2.160340>, 
      <-7.506059, 12.362408, 1.828535>, <-6.652219, 12.893017, 0.000000>, <-5.227252, 11.831798, -3.901317>, <-4.484525, 12.362408, -1.950658>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.506059, 12.362408, 1.828535>, <-6.652219, 12.893017, 0.000000>, <-5.227252, 11.831798, -3.901317>, <-4.484525, 12.362408, -1.950658>, 
      <-7.535631, 13.392362, 2.038217>, <-6.652219, 13.893017, 0.000000>, <-5.692139, 12.891708, -3.481953>, <-4.716968, 13.392362, -1.740977>, 
      <-7.535631, 15.524898, 2.038217>, <-6.652219, 14.893017, 0.000000>, <-5.692139, 13.891708, -3.481953>, <-4.716968, 14.392362, -1.740977>, 
      <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 14.891708, -3.481953>, <-4.957567, 18.792890, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.536111, -22.691980, -10.640523>, <0.506539, -24.016593, -10.112585>, <2.965208, -24.968223, -9.005203>, <4.675043, -24.492408, -9.558894>, 
      <-1.536111, -21.622797, -10.640523>, <0.506539, -22.947410, -10.112585>, <2.965208, -23.899040, -9.005203>, <4.675043, -23.423225, -9.558894>, 
      <-2.456078, -16.410654, -11.000087>, <-1.333395, -13.592308, -10.831713>, <2.965208, -22.829857, -9.005203>, <3.770754, -18.211082, -9.918458>, 
      <-3.085882, -14.199944, -11.179869>, <-1.333395, -12.523124, -10.831713>, <2.051798, -17.617714, -9.364767>, <3.314049, -15.070419, -10.098240>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.085882, -14.199944, -11.179869>, <-1.333395, -12.523124, -10.831713>, <2.051798, -17.617714, -9.364767>, <3.314049, -15.070419, -10.098240>, 
      <-3.715687, -11.989233, -11.359652>, <-1.333395, -11.453941, -10.831713>, <1.138388, -12.405571, -9.724331>, <2.857344, -11.929756, -10.278022>, 
      <-3.715687, -10.920050, -11.359652>, <-1.333395, -10.384758, -10.831713>, <1.138388, -11.336388, -9.724331>, <2.857344, -10.860573, -10.278022>, 
      <-4.221511, -7.572016, -10.551399>, <-1.844211, -7.034150, -10.023461>, <0.622392, -7.990357, -8.916079>, <2.337746, -7.512253, -9.469770>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.221511, -7.572016, -10.551399>, <-1.844211, -7.034150, -10.023461>, <0.622392, -7.990357, -8.916079>, <2.337746, -7.512253, -9.469770>, 
      <-4.727335, -4.223983, -9.743147>, <-2.355027, -3.683542, -9.215209>, <0.106397, -4.644325, -8.107826>, <1.818148, -4.163934, -8.661518>, 
      <-4.727335, -3.084467, -9.743147>, <-2.355027, -2.483977, -9.215209>, <0.106397, -3.564858, -8.107826>, <1.818148, -3.024418, -8.661518>, 
      <-3.505073, 0.485792, -6.794494>, <-2.174144, -0.054629, -6.907407>, <0.050642, -0.981253, -5.227897>, <2.248796, -0.517941, -6.067652>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.505073, 0.485792, -6.794494>, <-2.174144, -0.054629, -6.907407>, <0.050642, -0.981253, -5.227897>, <2.248796, -0.517941, -6.067652>, 
      <-2.282812, 4.056050, -3.845840>, <-1.993262, 2.374718, -4.599604>, <-0.005112, 1.602353, -2.347967>, <2.679444, 1.988535, -3.473786>, 
      <-2.282812, 5.004672, -3.845840>, <-1.993262, 3.146073, -4.599604>, <-0.005112, 2.373708, -2.347967>, <-0.508196, 5.575355, -0.537041>, 
      <-2.045562, 5.445932, -3.220230>, <-1.050275, 4.798474, -3.060385>, <0.704775, 3.848609, -0.808748>, <1.475265, 4.665690, -1.039440>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.045562, 5.445932, -3.220230>, <-1.050275, 4.798474, -3.060385>, <0.704775, 3.848609, -0.808748>, <1.475265, 4.665690, -1.039440>, 
      <-1.808312, 5.887192, -2.594621>, <-0.107289, 6.450874, -1.521166>, <1.414661, 5.323510, 0.730472>, <3.458727, 3.756026, -1.541839>, 
      <-4.205575, 4.702949, -4.095126>, <-3.715679, 7.709808, -1.443737>, <1.414661, 6.449399, 0.730472>, <0.148590, 7.079604, -0.356632>, 
      <-3.783764, 7.487747, -3.337414>, <-2.838609, 9.241504, -1.141232>, <-0.667694, 7.578949, 1.469270>, <-0.260757, 8.410226, 0.164019>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.783764, 7.487747, -3.337414>, <-2.838609, 9.241504, -1.141232>, <-0.667694, 7.578949, 1.469270>, <-0.260757, 8.410226, 0.164019>, 
      <-3.361953, 10.272544, -2.579703>, <-1.961540, 10.773199, -0.838727>, <-2.750049, 8.708498, 2.208068>, <-0.670103, 9.740849, 0.684671>, 
      <-4.252081, 11.332453, -2.160340>, <-3.741797, 11.893017, 0.000000>, <-0.708553, 10.771889, 2.813078>, <-0.822001, 11.332453, 1.406539>, 
      <-4.484525, 12.362408, -1.950658>, <-3.741797, 12.893017, 0.000000>, <-1.638285, 11.831798, 3.232441>, <-1.286867, 12.362408, 1.616221>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.484525, 12.362408, -1.950658>, <-3.741797, 12.893017, 0.000000>, <-1.638285, 11.831798, 3.232441>, <-1.286867, 12.362408, 1.616221>, 
      <-4.716968, 13.392362, -1.740977>, <-3.741797, 13.893017, 0.000000>, <-2.568017, 12.891708, 3.651805>, <-1.751733, 13.392362, 1.825902>, 
      <-4.716968, 14.392362, -1.740977>, <-3.741797, 14.893017, 0.000000>, <-2.568017, 13.891708, 3.651805>, <-1.751733, 14.392362, 1.825902>, 
      <-4.957567, 18.792890, -1.740977>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 14.891708, 3.651805>, <-1.855808, 18.747382, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.675043, -24.492408, -9.558894>, <6.384879, -24.016593, -10.112585>, <8.344325, -25.087177, -11.142708>, <10.438984, -24.551885, -10.627647>, 
      <4.675043, -23.423225, -9.558894>, <6.384879, -22.947410, -10.112585>, <8.344325, -24.017994, -11.142708>, <10.438984, -23.482702, -10.627647>, 
      <3.770754, -18.211082, -9.918458>, <4.576299, -13.592308, -10.831713>, <8.344325, -22.948811, -11.142708>, <9.199661, -18.330036, -10.987211>, 
      <3.314049, -15.070419, -10.098240>, <4.576299, -12.523124, -10.831713>, <7.445261, -17.736668, -11.502273>, <8.750129, -15.189373, -11.166993>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <3.314049, -15.070419, -10.098240>, <4.576299, -12.523124, -10.831713>, <7.445261, -17.736668, -11.502273>, <8.750129, -15.189373, -11.166993>, 
      <2.857344, -11.929756, -10.278022>, <4.576299, -11.453941, -10.831713>, <6.546197, -12.524525, -11.861837>, <8.300597, -12.048710, -11.346775>, 
      <2.857344, -10.860573, -10.278022>, <4.576299, -10.384758, -10.831713>, <6.546197, -11.455342, -11.861837>, <8.300597, -10.979527, -11.346775>, 
      <2.337746, -7.512253, -9.469770>, <4.053100, -7.034150, -10.023461>, <6.018870, -8.109883, -11.053584>, <7.769593, -7.631779, -10.538523>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <2.337746, -7.512253, -9.469770>, <4.053100, -7.034150, -10.023461>, <6.018870, -8.109883, -11.053584>, <7.769593, -7.631779, -10.538523>, 
      <1.818148, -4.163934, -8.661518>, <3.529900, -3.683542, -9.215209>, <5.491542, -4.764423, -10.245332>, <7.238589, -4.284032, -9.730271>, 
      <1.818148, -3.024418, -8.661518>, <3.529900, -2.483977, -9.215209>, <5.491542, -3.684956, -10.245332>, <7.588548, -3.084467, -9.730271>, 
      <2.248796, -0.517941, -6.067652>, <4.446950, -0.054629, -6.907407>, <6.220003, -1.041302, -8.469742>, <7.792582, 0.548923, -6.918964>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <2.248796, -0.517941, -6.067652>, <4.446950, -0.054629, -6.907407>, <6.220003, -1.041302, -8.469742>, <7.792582, 0.548923, -6.918964>, 
      <2.679444, 1.988535, -3.473786>, <5.363999, 2.374718, -4.599604>, <6.948464, 1.602353, -6.694151>, <7.996615, 4.182312, -4.107658>, 
      <-0.508196, 5.575355, -0.537041>, <-1.011280, 8.777003, 1.273885>, <6.948464, 2.373708, -6.694151>, <4.618349, 5.029259, -3.347075>, 
      <1.475265, 4.665690, -1.039440>, <2.245756, 5.482772, -1.270132>, <7.017860, 1.894942, -6.301423>, <6.234591, 4.481392, -3.531003>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.475265, 4.665690, -1.039440>, <2.245756, 5.482772, -1.270132>, <7.017860, 1.894942, -6.301423>, <6.234591, 4.481392, -3.531003>, 
      <3.458727, 3.756026, -1.541839>, <5.502792, 2.188541, -3.814149>, <7.087256, 1.416175, -5.908696>, <7.850833, 3.933525, -3.714931>, 
      <0.148590, 7.079604, -0.356632>, <-1.117481, 7.709808, -1.443737>, <7.087256, 2.187530, -5.908696>, <6.153046, 5.480365, -3.373711>, 
      <-0.260757, 8.410226, 0.164019>, <0.146180, 9.241504, -1.141232>, <3.452612, 5.448014, -5.374730>, <4.335724, 7.610607, -3.106728>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-0.260757, 8.410226, 0.164019>, <0.146180, 9.241504, -1.141232>, <3.452612, 5.448014, -5.374730>, <4.335724, 7.610607, -3.106728>, 
      <-0.670103, 9.740849, 0.684671>, <1.409842, 10.773199, -0.838727>, <-0.182032, 8.708498, -4.840764>, <2.518402, 9.740849, -2.839745>, 
      <-0.822001, 11.332453, 1.406539>, <-0.935449, 11.893017, 0.000000>, <2.623666, 10.771889, -4.235754>, <2.311833, 11.332453, -2.117877>, 
      <-1.286867, 12.362408, 1.616221>, <-0.935449, 12.893017, 0.000000>, <1.311833, 11.831798, -3.816391>, <1.655917, 12.362408, -1.908195>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.286867, 12.362408, 1.616221>, <-0.935449, 12.893017, 0.000000>, <1.311833, 11.831798, -3.816391>, <1.655917, 12.362408, -1.908195>, 
      <-1.751733, 13.392362, 1.825902>, <-0.935449, 13.893017, 0.000000>, <0.000000, 12.891708, -3.397028>, <1.000000, 13.392362, -1.698514>, 
      <-1.751733, 14.392362, 1.825902>, <-0.935449, 14.893017, 0.000000>, <0.000000, 13.891708, -3.397028>, <1.000000, 14.392362, -1.698514>, 
      <-1.855808, 18.747382, 1.825902>, <-1.143599, 22.603056, 0.000000>, <0.000000, 14.891708, -3.397028>, <0.888743, 18.747382, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.438984, -24.551885, -10.627647>, <12.533642, -24.016593, -10.112585>, <14.628301, -21.248413, -9.133968>, <16.722959, -20.772598, -9.649030>, 
      <10.438984, -23.482702, -10.627647>, <12.533642, -22.947410, -10.112585>, <14.628301, -20.179230, -9.133968>, <16.722959, -19.703415, -9.649030>, 
      <9.199661, -18.330036, -10.987211>, <10.054996, -13.711261, -10.831713>, <14.628301, -19.110047, -9.133968>, <15.851827, -16.351177, -10.008594>, 
      <8.750129, -15.189373, -11.166993>, <10.054996, -12.642078, -10.831713>, <13.394564, -15.817286, -9.493532>, <15.234958, -14.170205, -10.188376>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.750129, -15.189373, -11.166993>, <10.054996, -12.642078, -10.831713>, <13.394564, -15.817286, -9.493532>, <15.234958, -14.170205, -10.188376>, 
      <8.300597, -12.048710, -11.346775>, <10.054996, -11.572895, -10.831713>, <12.160827, -12.524525, -9.853096>, <14.618090, -11.989233, -10.368158>, 
      <8.300597, -10.979527, -11.346775>, <10.054996, -10.503712, -10.831713>, <12.160827, -11.455342, -9.853096>, <14.618090, -10.920050, -10.368158>, 
      <7.769593, -7.631779, -10.538523>, <9.520316, -7.153676, -10.023461>, <11.621735, -8.109883, -9.044844>, <14.190501, -7.572016, -9.559906>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.769593, -7.631779, -10.538523>, <9.520316, -7.153676, -10.023461>, <11.621735, -8.109883, -9.044844>, <14.190501, -7.572016, -9.559906>, 
      <7.238589, -4.284032, -9.730271>, <8.985636, -3.803640, -9.215209>, <11.082642, -4.764423, -8.236592>, <13.762913, -4.223983, -8.751654>, 
      <7.588548, -3.084467, -9.730271>, <9.685554, -2.483977, -9.215209>, <11.082642, -3.684956, -8.236592>, <13.762913, -3.084467, -8.751654>, 
      <7.792582, 0.548923, -6.918964>, <9.365160, 2.139147, -5.368187>, <11.556255, -1.041302, -5.423189>, <13.837514, -0.547966, -6.204356>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.792582, 0.548923, -6.918964>, <9.365160, 2.139147, -5.368187>, <11.556255, -1.041302, -5.423189>, <13.837514, -0.547966, -6.204356>, 
      <7.996615, 4.182312, -4.107658>, <9.044767, 6.762272, -1.521166>, <12.029867, 1.602353, -2.609785>, <13.912114, 1.988535, -3.657058>, 
      <4.618349, 5.029259, -3.347075>, <2.288233, 7.684810, 0.000000>, <12.029867, 2.373708, -2.609785>, <13.912114, 2.759890, -3.657058>, 
      <6.234591, 4.481392, -3.531003>, <5.451321, 7.067842, -0.760583>, <11.110199, 3.848609, -1.070566>, <12.927060, 4.323541, -2.117839>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <6.234591, 4.481392, -3.531003>, <5.451321, 7.067842, -0.760583>, <11.110199, 3.848609, -1.070566>, <12.927060, 4.323541, -2.117839>, 
      <7.850833, 3.933525, -3.714931>, <8.614409, 6.450874, -1.521166>, <10.190531, 5.323510, 0.468654>, <11.942006, 5.887192, -0.578620>, 
      <6.153046, 5.480365, -3.373711>, <5.218836, 8.773199, -0.838727>, <10.190531, 6.449399, 0.468654>, <9.795425, 7.611299, -0.269962>, 
      <4.335724, 7.610607, -3.106728>, <5.218836, 9.773199, -0.838727>, <8.353476, 8.110644, 1.428552>, <8.804715, 8.941922, 0.209987>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.335724, 7.610607, -3.106728>, <5.218836, 9.773199, -0.838727>, <8.353476, 8.110644, 1.428552>, <8.804715, 8.941922, 0.209987>, 
      <2.518402, 9.740849, -2.839745>, <5.218836, 10.773199, -0.838727>, <6.516421, 9.771889, 2.388450>, <7.814006, 10.272544, 0.689936>, 
      <2.311833, 11.332453, -2.117877>, <2.000000, 11.893017, 0.000000>, <6.516421, 10.771889, 2.388450>, <5.758210, 11.332453, 1.109299>, 
      <1.655917, 12.362408, -1.908195>, <2.000000, 12.893017, 0.000000>, <4.758210, 11.831798, 2.807813>, <4.879105, 12.362408, 1.318981>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.655917, 12.362408, -1.908195>, <2.000000, 12.893017, 0.000000>, <4.758210, 11.831798, 2.807813>, <4.879105, 12.362408, 1.318981>, 
      <1.000000, 13.392362, -1.698514>, <2.000000, 13.893017, 0.000000>, <3.000000, 12.891708, 3.227176>, <4.000000, 13.392362, 1.528662>, 
      <1.000000, 14.392362, -1.698514>, <2.000000, 14.893017, 0.000000>, <3.000000, 13.891708, 3.227176>, <4.000000, 14.392362, 1.528662>, 
      <0.888743, 18.747382, -1.698514>, <1.777487, 22.603056, 0.000000>, <3.000000, 14.891708, 3.227176>, <4.516881, 18.682654, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <16.722959, -20.772598, -9.649030>, <18.817618, -20.296783, -10.164091>, <20.912276, -21.367367, -11.271474>, <23.273770, -21.171689, -10.073955>, 
      <16.722959, -19.703415, -9.649030>, <18.817618, -19.227600, -10.164091>, <20.912276, -20.298184, -11.271474>, <23.273770, -20.102505, -10.073955>, 
      <15.851827, -16.351177, -10.008594>, <17.075352, -13.592308, -10.883220>, <20.912276, -19.229001, -11.271474>, <23.273770, -19.033322, -10.073955>, 
      <15.234958, -14.170205, -10.188376>, <17.075352, -12.523124, -10.883220>, <20.046730, -15.876763, -11.631038>, <22.414522, -15.681084, -10.433520>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <15.234958, -14.170205, -10.188376>, <17.075352, -12.523124, -10.883220>, <20.046730, -15.876763, -11.631038>, <22.414522, -15.681084, -10.433520>, 
      <14.618090, -11.989233, -10.368158>, <17.075352, -11.453941, -10.883220>, <19.181184, -12.524525, -11.990602>, <21.555273, -12.328846, -10.793084>, 
      <14.618090, -10.920050, -10.368158>, <17.075352, -10.384758, -10.883220>, <19.181184, -11.455342, -11.990602>, <21.555273, -11.259663, -10.793084>, 
      <14.190501, -7.572016, -9.559906>, <16.759268, -7.034150, -10.074967>, <18.627380, -8.109883, -11.182350>, <20.996495, -7.913263, -9.984832>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <14.190501, -7.572016, -9.559906>, <16.759268, -7.034150, -10.074967>, <18.627380, -8.109883, -11.182350>, <20.996495, -7.913263, -9.984832>, 
      <13.762913, -4.223983, -8.751654>, <16.443183, -3.683542, -9.266715>, <18.073577, -4.764423, -10.374098>, <20.437717, -4.566862, -9.176579>, 
      <13.762913, -3.084467, -8.751654>, <16.443183, -2.483977, -9.266715>, <18.540189, -3.684956, -10.374098>, <20.671023, -3.487395, -9.176579>, 
      <13.837514, -0.547966, -6.204356>, <16.118773, -0.054629, -6.985523>, <18.014176, -1.041302, -8.665033>, <19.940156, -0.893390, -6.848819>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <13.837514, -0.547966, -6.204356>, <16.118773, -0.054629, -6.985523>, <18.014176, -1.041302, -8.665033>, <19.940156, -0.893390, -6.848819>, 
      <13.912114, 1.988535, -3.657058>, <15.794362, 2.374718, -4.704332>, <17.488163, 1.602353, -6.955969>, <19.209288, 1.700615, -4.521059>, 
      <13.912114, 2.759890, -3.657058>, <15.794362, 3.146073, -4.704332>, <17.488163, 2.373708, -6.955969>, <19.209288, 2.471969, -4.521059>, 
      <12.927060, 4.323541, -2.117839>, <14.743922, 4.798474, -3.165112>, <16.378883, 3.848609, -5.416750>, <18.040219, 3.969453, -2.981840>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <12.927060, 4.323541, -2.117839>, <14.743922, 4.798474, -3.165112>, <16.378883, 3.848609, -5.416750>, <18.040219, 3.969453, -2.981840>, 
      <11.942006, 5.887192, -0.578620>, <13.693481, 6.450874, -1.625893>, <15.269603, 5.323510, -3.877530>, <16.871150, 5.466936, -1.442620>, 
      <9.795425, 7.611299, -0.269962>, <9.400320, 8.773199, -1.008578>, <15.269603, 6.449399, -3.877530>, <16.871150, 6.592825, -1.442620>, 
      <8.804715, 8.941922, 0.209987>, <9.255955, 9.773199, -1.008578>, <12.839389, 8.110644, -4.268957>, <14.371603, 8.246051, -1.076979>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.804715, 8.941922, 0.209987>, <9.255955, 9.773199, -1.008578>, <12.839389, 8.110644, -4.268957>, <14.371603, 8.246051, -1.076979>, 
      <7.814006, 10.272544, 0.689936>, <9.111590, 10.773199, -1.008578>, <10.409175, 9.771889, -4.660383>, <11.872057, 9.899278, -0.711338>, 
      <5.758210, 11.332453, 1.109299>, <5.000000, 11.893017, -0.169851>, <10.409175, 10.771889, -4.660383>, <11.872057, 10.899278, -0.711338>, 
      <4.879105, 12.362408, 1.318981>, <5.000000, 12.893017, -0.169851>, <8.204588, 12.961276, -4.241019>, <9.499723, 13.088665, -0.291975>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.879105, 12.362408, 1.318981>, <5.000000, 12.893017, -0.169851>, <8.204588, 12.961276, -4.241019>, <9.499723, 13.088665, -0.291975>, 
      <4.000000, 13.392362, 1.528662>, <5.000000, 13.893017, -0.169851>, <6.000000, 15.150663, -3.821656>, <7.127389, 15.278052, 0.127389>, 
      <4.000000, 14.392362, 1.528662>, <5.000000, 14.893017, -0.169851>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, 0.127389>, 
      <4.516881, 18.682654, 1.528662>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, 0.127389>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <23.273770, -21.171689, -10.073955>, <25.635264, -20.976010, -8.876437>, <27.196252, -20.296783, -10.112585>, <29.290910, -21.367367, -10.112585>, 
      <23.273770, -20.102505, -10.073955>, <25.635264, -19.906827, -8.876437>, <27.196252, -19.227600, -10.112585>, <29.290910, -20.298184, -10.112585>, 
      <23.273770, -19.033322, -10.073955>, <25.635264, -18.837644, -8.876437>, <25.498677, -13.592308, -10.831713>, <29.290910, -19.229001, -10.112585>, 
      <22.414522, -15.681084, -10.433520>, <24.782314, -15.485406, -9.236001>, <25.498677, -12.523124, -10.831713>, <28.447709, -15.876763, -10.472149>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <22.414522, -15.681084, -10.433520>, <24.782314, -15.485406, -9.236001>, <25.498677, -12.523124, -10.831713>, <28.447709, -15.876763, -10.472149>, 
      <21.555273, -12.328846, -10.793084>, <23.929363, -12.133168, -9.595565>, <25.498677, -11.453941, -10.831713>, <27.604508, -12.524525, -10.831713>, 
      <21.555273, -11.259663, -10.793084>, <23.929363, -11.063985, -9.595565>, <25.030101, -10.860573, -10.831713>, <27.604508, -11.455342, -10.831713>, 
      <20.996495, -7.913263, -9.984832>, <23.365611, -7.716643, -8.787313>, <24.464042, -7.512253, -10.023461>, <27.370220, -10.624066, -10.831713>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <20.996495, -7.913263, -9.984832>, <23.365611, -7.716643, -8.787313>, <24.464042, -7.512253, -10.023461>, <27.370220, -10.624066, -10.831713>, 
      <20.437717, -4.566862, -9.176579>, <22.801858, -4.369302, -7.979061>, <23.897983, -4.163934, -9.215209>, <27.135932, -9.792791, -10.831713>, 
      <20.671023, -3.487395, -9.176579>, <22.801858, -3.289835, -7.979061>, <23.897983, -2.964369, -9.215209>, <25.994989, -4.165348, -9.215209>, 
      <19.940156, -0.893390, -6.848819>, <21.866136, -0.745479, -5.032605>, <22.856881, -0.466462, -6.907407>, <25.994989, -3.085881, -9.215209>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <19.940156, -0.893390, -6.848819>, <21.866136, -0.745479, -5.032605>, <22.856881, -0.466462, -6.907407>, <25.994989, -3.085881, -9.215209>, 
      <19.209288, 1.700615, -4.521059>, <20.930413, 1.798876, -2.086149>, <21.815780, 2.031445, -4.599604>, <25.994989, -2.006413, -9.215209>, 
      <19.209288, 2.471969, -4.521059>, <20.930413, 2.570231, -2.086149>, <21.815780, 2.802799, -4.599604>, <23.509581, 2.030434, -4.599604>, 
      <18.040219, 3.969453, -2.981840>, <19.701555, 4.090296, -0.546929>, <20.556165, 4.376311, -3.060385>, <22.191126, 3.426447, -3.060385>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <18.040219, 3.969453, -2.981840>, <19.701555, 4.090296, -0.546929>, <20.556165, 4.376311, -3.060385>, <22.191126, 3.426447, -3.060385>, 
      <16.871150, 5.466936, -1.442620>, <18.472697, 5.610361, 0.992290>, <19.296550, 5.949824, -1.521166>, <20.872672, 4.822460, -1.521166>, 
      <16.871150, 6.592825, -1.442620>, <18.472697, 6.736250, 0.992290>, <8.777487, 8.447991, 0.000000>, <20.872672, 5.948349, -1.521166>, 
      <14.371603, 8.246051, -1.076979>, <15.903818, 8.381458, 2.114998>, <11.395343, 9.388082, -0.419363>, <18.091728, 7.637606, -1.179946>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <14.371603, 8.246051, -1.076979>, <15.903818, 8.381458, 2.114998>, <11.395343, 9.388082, -0.419363>, <18.091728, 7.637606, -1.179946>, 
      <11.872057, 9.899278, -0.711338>, <13.334939, 10.026667, 3.237707>, <14.013199, 10.328173, -0.838727>, <15.310784, 9.326863, -0.838727>, 
      <11.872057, 10.899278, -0.711338>, <13.334939, 11.026667, 3.237707>, <14.013199, 11.328173, -0.838727>, <15.310784, 10.326863, -0.838727>, 
      <9.499723, 13.088665, -0.291975>, <10.794858, 13.216053, 3.657070>, <11.506600, 12.610595, -0.419363>, <12.711020, 12.610595, -0.419363>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.499723, 13.088665, -0.291975>, <10.794858, 13.216053, 3.657070>, <11.506600, 12.610595, -0.419363>, <12.711020, 12.610595, -0.419363>, 
      <7.127389, 15.278052, 0.127389>, <8.254777, 15.405440, 4.076433>, <9.000000, 13.893017, 0.000000>, <10.111257, 14.894327, 0.000000>, 
      <7.127389, 16.278052, 0.127389>, <8.254777, 16.405440, 4.076433>, <9.000000, 14.893017, 0.000000>, <10.000000, 13.891708, 0.000000>, 
      <7.127389, 17.278052, 0.127389>, <8.254777, 17.405440, 4.076433>, <10.797790, 24.684825, 0.000000>, <10.000000, 14.891708, 0.000000>
    }
  }
  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.50*ycm/100,zplis/2>
  //translate  <0.185073, -20.280892, 0.0>
} 



#declare RideauFremissant = union { // BezPtch001
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.997723, -19.217677, 0.000000>, <-9.404680, -20.218987, -6.114650>, <-8.230900, -20.107731, 4.076433>, <-7.347488, -19.662704, 2.038217>, 
      <-9.997723, -18.217677, 0.000000>, <-9.404680, -19.218987, -6.114650>, <-8.230900, -19.107731, 4.076433>, <-7.347488, -18.662704, 2.038217>, 
      <-9.997723, -17.217677, 0.000000>, <-9.404680, -18.218987, -6.114650>, <-8.230900, -18.107731, 4.076433>, <-7.687191, -17.662704, 2.377919>, 
      <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.857042, -16.662704, 2.547771>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.945686, -16.217677, 0.000000>, <-9.404680, -17.218987, -6.114650>, <-8.570603, -17.107731, 4.416136>, <-7.857042, -16.662704, 2.547771>, 
      <-9.893648, -15.217677, 0.000000>, <-9.404680, -16.218987, -6.114650>, <-8.910305, -16.107731, 4.755839>, <-8.026894, -15.662704, 2.717622>, 
      <-9.893648, -14.217677, 0.000000>, <-9.300605, -15.218987, -6.114650>, <-8.910305, -15.107731, 4.755839>, <-8.026894, -14.662704, 2.717622>, 
      <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.857042, -13.662704, 2.547771>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.893648, -13.217677, 0.000000>, <-9.300605, -14.218987, -6.114650>, <-8.910305, -14.107731, 4.755839>, <-7.857042, -13.662704, 2.547771>, 
      <-9.893648, -12.217677, 0.000000>, <-9.300605, -13.218987, -6.114650>, <-8.910305, -13.107731, 4.755839>, <-7.687191, -12.662704, 2.377919>, 
      <-9.893648, -11.106421, 0.000000>, <-9.300605, -12.218987, -6.114650>, <-8.230900, -12.107731, 4.076433>, <-7.347488, -11.607076, 2.038217>, 
      <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.893648, -10.162049, 0.000000>, <-9.300605, -11.218987, -6.114650>, <-8.230900, -11.163359, 4.076433>, <-7.198868, -9.820805, 2.271762>, 
      <-9.893648, -9.217677, 0.000000>, <-9.300605, -10.218987, -6.114650>, <-8.230900, -10.218987, 4.076433>, <-7.050248, -8.034535, 2.505308>, 
      <-9.893648, -8.217677, 0.000000>, <-9.300605, -9.218987, -6.114650>, <-8.230900, -9.218987, 4.076433>, <-7.050248, -7.034535, 2.505308>, 
      <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.893648, -7.217677, 0.000000>, <-9.300605, -8.218987, -6.114650>, <-8.230900, -8.218987, 4.076433>, <-7.198868, -6.876433, 2.271762>, 
      <-9.893648, -6.217677, 0.000000>, <-9.300605, -7.218987, -6.114650>, <-8.230900, -7.218987, 4.076433>, <-7.347488, -6.718332, 2.038217>, 
      <-10.081791, 8.893017, 0.000000>, <-9.300605, -6.218987, -6.114650>, <-8.230900, -6.218987, 4.076433>, <-7.441560, 1.337015, 2.038217>, 
      <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.081791, 9.893017, 0.000000>, <-9.394676, 1.836360, -6.114650>, <-8.324971, 1.836360, 4.076433>, <-7.488595, 5.864689, 2.038217>, 
      <-10.081791, 10.893017, 0.000000>, <-9.488748, 9.891708, -6.114650>, <-8.419043, 9.891708, 4.076433>, <-7.535631, 10.392362, 2.038217>, 
      <-10.081791, 11.893017, 0.000000>, <-9.488748, 10.891708, -6.114650>, <-8.419043, 10.891708, 4.076433>, <-7.535631, 11.392362, 2.038217>, 
      <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.133828, 12.893017, 0.000000>, <-9.540785, 11.891708, -6.114650>, <-8.419043, 11.891708, 4.076433>, <-7.535631, 12.392362, 2.038217>, 
      <-10.185866, 13.893017, 0.000000>, <-9.592823, 12.891708, -6.114650>, <-8.419043, 12.891708, 4.076433>, <-7.535631, 13.392362, 2.038217>, 
      <-10.185866, 14.893017, 0.000000>, <-9.592823, 16.156779, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.524898, 2.038217>, 
      <-10.394016, 19.753449, 0.000000>, <-9.592823, 17.156779, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.347488, -19.662704, 2.038217>, <-6.464077, -19.217677, 0.000000>, <-5.503996, -20.218987, -3.481953>, <-4.528825, -19.718332, -1.740977>, 
      <-7.347488, -18.662704, 2.038217>, <-6.464077, -18.217677, 0.000000>, <-5.503996, -19.218987, -3.481953>, <-4.528825, -18.718332, -1.740977>, 
      <-7.687191, -17.662704, 2.377919>, <-7.143482, -17.217677, 0.679406>, <-5.503996, -18.218987, -3.481953>, <-4.528825, -17.718332, -1.740977>, 
      <-7.857042, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.857042, -16.662704, 2.547771>, <-7.143482, -16.217677, 0.679406>, <-5.660109, -17.218987, -3.481953>, <-4.606881, -16.718332, -1.740977>, 
      <-8.026894, -15.662704, 2.717622>, <-7.143482, -15.217677, 0.679406>, <-5.816221, -16.218987, -3.481953>, <-4.684938, -15.718332, -1.740977>, 
      <-8.026894, -14.662704, 2.717622>, <-7.143482, -14.217677, 0.679406>, <-5.816221, -15.218987, -3.481953>, <-4.684938, -14.718332, -1.740977>, 
      <-7.857042, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.857042, -13.662704, 2.547771>, <-6.803779, -13.217677, 0.339703>, <-5.816221, -14.218987, -3.481953>, <-4.684938, -13.718332, -1.740977>, 
      <-7.687191, -12.662704, 2.377919>, <-6.464077, -12.217677, 0.000000>, <-5.816221, -13.218987, -3.481953>, <-4.684938, -12.718332, -1.740977>, 
      <-7.347488, -11.607076, 2.038217>, <-6.464077, -11.106421, 0.000000>, <-5.816221, -12.218987, -3.481953>, <-4.684938, -11.662704, -1.740977>, 
      <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.198868, -9.820805, 2.271762>, <-6.166837, -8.478251, 0.467091>, <-5.362869, -9.535190, -3.014862>, <-4.458261, -9.848619, -1.507431>, 
      <-7.050248, -8.034535, 2.505308>, <-5.869597, -5.850082, 0.934183>, <-4.909516, -6.851392, -2.547771>, <-4.231585, -8.034535, -1.273885>, 
      <-7.050248, -7.034535, 2.505308>, <-5.869597, -4.850082, 0.934183>, <-4.909516, -5.851392, -2.547771>, <-4.231585, -7.034535, -1.273885>, 
      <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.198868, -6.876433, 2.271762>, <-6.166837, -5.533880, 0.467091>, <-5.206756, -6.535190, -3.014862>, <-4.328168, -6.876433, -1.507431>, 
      <-7.347488, -6.718332, 2.038217>, <-6.464077, -6.217677, 0.000000>, <-5.503996, -7.218987, -3.481953>, <-4.424750, -6.718332, -1.740977>, 
      <-7.441560, 1.337015, 2.038217>, <-6.652219, 8.893017, 0.000000>, <-5.321964, -2.487328, -3.481953>, <-4.518821, 2.611240, -2.462845>, 
      <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.488595, 5.864689, 2.038217>, <-6.652219, 9.893017, 0.000000>, <-5.507051, 3.702190, -3.481953>, <-4.565857, 6.501801, -2.101911>, 
      <-7.535631, 10.392362, 2.038217>, <-6.652219, 10.893017, 0.000000>, <-5.692139, 9.891708, -3.481953>, <-4.612893, 10.392362, -1.740977>, 
      <-7.535631, 11.392362, 2.038217>, <-6.652219, 11.893017, 0.000000>, <-5.692139, 10.891708, -3.481953>, <-4.716968, 11.392362, -1.740977>, 
      <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.535631, 12.392362, 2.038217>, <-6.652219, 12.893017, 0.000000>, <-5.692139, 11.891708, -3.481953>, <-4.716968, 12.392362, -1.740977>, 
      <-7.535631, 13.392362, 2.038217>, <-6.652219, 13.893017, 0.000000>, <-5.692139, 12.891708, -3.481953>, <-4.716968, 13.392362, -1.740977>, 
      <-7.535631, 15.524898, 2.038217>, <-6.652219, 14.893017, 0.000000>, <-5.692139, 13.891708, -3.481953>, <-4.716968, 14.392362, -1.740977>, 
      <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 14.891708, -3.481953>, <-4.957567, 18.792890, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.528825, -19.718332, -1.740977>, <-3.553654, -19.217677, 0.000000>, <-2.379874, -20.107731, 3.651805>, <-1.563590, -19.662704, 1.825902>, 
      <-4.528825, -18.718332, -1.740977>, <-3.553654, -18.217677, 0.000000>, <-2.379874, -19.107731, 3.651805>, <-1.563590, -18.662704, 1.825902>, 
      <-4.528825, -17.718332, -1.740977>, <-3.553654, -17.217677, 0.000000>, <-2.379874, -18.107731, 3.651805>, <-1.563590, -17.662704, 1.825902>, 
      <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.606881, -16.718332, -1.740977>, <-3.553654, -16.217677, 0.000000>, <-2.379874, -17.107731, 3.651805>, <-1.563590, -16.662704, 1.825902>, 
      <-4.684938, -15.718332, -1.740977>, <-3.553654, -15.217677, 0.000000>, <-2.379874, -16.107731, 3.651805>, <-1.563590, -15.662704, 1.825902>, 
      <-4.684938, -14.718332, -1.740977>, <-3.553654, -14.217677, 0.000000>, <-2.379874, -15.107731, 3.651805>, <-1.563590, -14.662704, 1.825902>, 
      <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.684938, -13.718332, -1.740977>, <-3.553654, -13.217677, 0.000000>, <-2.379874, -14.107731, 3.651805>, <-1.563590, -13.662704, 1.825902>, 
      <-4.684938, -12.718332, -1.740977>, <-3.553654, -12.217677, 0.000000>, <-2.379874, -13.107731, 3.651805>, <-1.563590, -12.662704, 1.825902>, 
      <-4.684938, -11.662704, -1.740977>, <-3.553654, -11.106421, 0.000000>, <-2.379874, -12.107731, 3.651805>, <-1.563590, -11.607076, 1.825902>, 
      <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.458261, -9.848619, -1.507431>, <-3.553654, -10.162049, 0.000000>, <-2.379874, -11.163359, 3.651805>, <-1.563590, -10.662704, 1.825902>, 
      <-4.231585, -8.034535, -1.273885>, <-3.553654, -9.217677, 0.000000>, <-2.379874, -10.218987, 3.651805>, <-1.563590, -9.718332, 1.825902>, 
      <-4.231585, -7.034535, -1.273885>, <-3.553654, -8.217677, 0.000000>, <-2.379874, -9.218987, 3.651805>, <-1.609098, -6.533946, 2.462845>, 
      <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.328168, -6.876433, -1.507431>, <-3.449579, -7.217677, 0.000000>, <-2.379874, -8.218987, 3.651805>, <-1.609098, -5.533946, 2.462845>, 
      <-4.424750, -6.718332, -1.740977>, <-3.345504, -6.217677, 0.000000>, <-2.379874, -7.218987, 3.651805>, <-1.609098, -4.533946, 2.462845>, 
      <-4.518821, 2.611240, -2.462845>, <-3.715679, 7.709808, -1.443737>, <-2.379874, -6.218987, 3.651805>, <-1.748678, 0.745411, 1.104034>, 
      <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.565857, 6.501801, -2.101911>, <-3.624663, 9.301413, -0.721868>, <-2.564961, 1.244756, 2.929936>, <-1.795713, 5.273084, 1.104034>, 
      <-4.612893, 10.392362, -1.740977>, <-3.533647, 10.893017, 0.000000>, <-2.750049, 8.708498, 2.208068>, <-1.842749, 9.800758, 1.104034>, 
      <-4.716968, 11.392362, -1.740977>, <-3.741797, 11.893017, 0.000000>, <-2.568017, 10.891708, 3.651805>, <-1.751733, 11.392362, 1.825902>, 
      <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.716968, 12.392362, -1.740977>, <-3.741797, 12.893017, 0.000000>, <-2.568017, 11.891708, 3.651805>, <-1.751733, 12.392362, 1.825902>, 
      <-4.716968, 13.392362, -1.740977>, <-3.741797, 13.893017, 0.000000>, <-2.568017, 12.891708, 3.651805>, <-1.751733, 13.392362, 1.825902>, 
      <-4.716968, 14.392362, -1.740977>, <-3.741797, 14.893017, 0.000000>, <-2.568017, 13.891708, 3.651805>, <-1.751733, 14.392362, 1.825902>, 
      <-4.957567, 18.792890, -1.740977>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 14.891708, 3.651805>, <-1.855808, 18.747382, 1.825902>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.563590, -19.662704, 1.825902>, <-0.747307, -19.217677, 0.000000>, <0.188143, -20.218987, -3.397028>, <1.188143, -19.718332, -1.698514>, 
      <-1.563590, -18.662704, 1.825902>, <-0.747307, -18.217677, 0.000000>, <0.188143, -19.218987, -3.397028>, <1.188143, -18.718332, -1.698514>, 
      <-1.563590, -17.662704, 1.825902>, <-0.747307, -17.217677, 0.000000>, <0.188143, -18.218987, -3.397028>, <1.021258, -17.773961, -1.698514>, 
      <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.563590, -16.662704, 1.825902>, <-0.747307, -16.217677, 0.000000>, <0.188143, -17.218987, -3.397028>, <1.021258, -16.773961, -1.698514>, 
      <-1.563590, -15.662704, 1.825902>, <-0.747307, -15.217677, 0.000000>, <0.188143, -16.218987, -3.397028>, <1.021258, -15.773961, -1.698514>, 
      <-1.563590, -14.662704, 1.825902>, <-0.747307, -14.217677, 0.000000>, <0.188143, -15.218987, -3.397028>, <1.021258, -14.773961, -1.698514>, 
      <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.563590, -13.662704, 1.825902>, <-0.747307, -13.217677, 0.000000>, <0.188143, -14.218987, -3.397028>, <1.021258, -13.773961, -1.698514>, 
      <-1.563590, -12.662704, 1.825902>, <-0.747307, -12.217677, 0.000000>, <0.188143, -13.218987, -3.397028>, <1.021258, -12.773961, -1.698514>, 
      <-1.563590, -11.607076, 1.825902>, <-0.747307, -11.106421, 0.000000>, <0.188143, -12.218987, -3.397028>, <1.188143, -11.662704, -1.698514>, 
      <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.563590, -10.662704, 1.825902>, <-0.747307, -10.162049, 0.000000>, <0.188143, -11.218987, -3.397028>, <1.256405, -9.871373, -1.698514>, 
      <-1.563590, -9.718332, 1.825902>, <-0.747307, -9.217677, 0.000000>, <0.188143, -10.218987, -3.397028>, <1.324667, -8.080043, -1.698514>, 
      <-1.609098, -6.533946, 2.462845>, <-0.838323, -3.848905, 1.273885>, <0.188143, -9.218987, -3.397028>, <1.324667, -7.080043, -1.698514>, 
      <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.609098, -5.533946, 2.462845>, <-0.838323, -2.848905, 1.273885>, <0.142635, -6.034601, -2.760085>, <1.233651, -5.806994, -1.380042>, 
      <-1.609098, -4.533946, 2.462845>, <-0.838323, -1.848905, 1.273885>, <0.097127, -2.850215, -2.123142>, <1.142635, -4.533946, -1.061571>, 
      <-1.748678, 0.745411, 1.104034>, <-1.117481, 7.709808, -1.443737>, <0.097127, -1.850215, -2.123142>, <1.048563, 3.521401, -1.061571>, 
      <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.795713, 5.273084, 1.104034>, <-1.026465, 9.301413, -0.721868>, <-0.042453, 3.429142, -3.481953>, <0.978774, 6.661080, -1.740977>, 
      <-1.842749, 9.800758, 1.104034>, <-0.935449, 10.893017, 0.000000>, <-0.182032, 8.708498, -4.840764>, <0.908984, 9.800758, -2.420382>, 
      <-1.751733, 11.392362, 1.825902>, <-0.935449, 11.893017, 0.000000>, <0.000000, 10.891708, -3.397028>, <1.000000, 11.392362, -1.698514>, 
      <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.751733, 12.392362, 1.825902>, <-0.935449, 12.893017, 0.000000>, <0.000000, 11.891708, -3.397028>, <1.000000, 12.392362, -1.698514>, 
      <-1.751733, 13.392362, 1.825902>, <-0.935449, 13.893017, 0.000000>, <0.000000, 12.891708, -3.397028>, <1.000000, 13.392362, -1.698514>, 
      <-1.751733, 14.392362, 1.825902>, <-0.935449, 14.893017, 0.000000>, <0.000000, 13.891708, -3.397028>, <1.000000, 14.392362, -1.698514>, 
      <-1.855808, 18.747382, 1.825902>, <-1.143599, 22.603056, 0.000000>, <0.000000, 14.891708, -3.397028>, <0.888743, 18.747382, -1.698514>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.188143, -19.718332, -1.698514>, <2.188143, -19.217677, 0.000000>, <3.188143, -20.107731, 3.227176>, <4.188143, -19.662704, 1.528662>, 
      <1.188143, -18.718332, -1.698514>, <2.188143, -18.217677, 0.000000>, <3.188143, -19.107731, 3.227176>, <4.188143, -18.662704, 1.528662>, 
      <1.021258, -17.773961, -1.698514>, <1.854373, -17.328934, 0.000000>, <3.188143, -18.107731, 3.227176>, <4.188143, -17.662704, 1.528662>, 
      <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.021258, -16.773961, -1.698514>, <1.854373, -16.328934, 0.000000>, <3.021258, -17.163359, 3.227176>, <4.104700, -16.690518, 1.528662>, 
      <1.021258, -15.773961, -1.698514>, <1.854373, -15.328934, 0.000000>, <2.854373, -16.218987, 3.227176>, <4.021258, -15.718332, 1.528662>, 
      <1.021258, -14.773961, -1.698514>, <1.854373, -14.328934, 0.000000>, <2.854373, -15.218987, 3.227176>, <4.021258, -14.718332, 1.528662>, 
      <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.021258, -13.773961, -1.698514>, <1.854373, -13.328934, 0.000000>, <2.854373, -14.218987, 3.227176>, <4.076886, -13.718332, 1.528662>, 
      <1.021258, -12.773961, -1.698514>, <1.854373, -12.328934, 0.000000>, <2.854373, -13.218987, 3.227176>, <4.132514, -12.718332, 1.528662>, 
      <1.188143, -11.662704, -1.698514>, <2.188143, -11.106421, 0.000000>, <2.854373, -12.218987, 3.227176>, <4.132514, -11.662704, 1.528662>, 
      <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.256405, -9.871373, -1.698514>, <2.324667, -8.523759, 0.000000>, <3.021258, -11.218987, 3.227176>, <4.215957, -10.690518, 1.528662>, 
      <1.324667, -8.080043, -1.698514>, <2.461191, -5.941098, 0.000000>, <3.188143, -10.218987, 3.227176>, <4.299399, -9.718332, 1.528662>, 
      <1.324667, -7.080043, -1.698514>, <2.461191, -4.941098, 0.000000>, <3.188143, -9.218987, 3.227176>, <4.299399, -8.718332, 1.528662>, 
      <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.233651, -5.806994, -1.380042>, <2.324667, -5.579388, 0.000000>, <3.188143, -8.218987, 3.227176>, <4.299399, -7.718332, 1.528662>, 
      <1.142635, -4.533946, -1.061571>, <2.188143, -6.217677, 0.000000>, <3.188143, -7.218987, 3.227176>, <4.299399, -6.718332, 1.528662>, 
      <1.048563, 3.521401, -1.061571>, <2.000000, 8.893017, 0.000000>, <3.188143, -6.218987, 3.227176>, <4.205328, 1.337015, 1.528662>, 
      <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <0.978774, 6.661080, -1.740977>, <2.000000, 9.893017, 0.000000>, <3.094071, 1.836360, 3.227176>, <4.102664, 5.864689, 1.528662>, 
      <0.908984, 9.800758, -2.420382>, <2.000000, 10.893017, 0.000000>, <3.000000, 9.891708, 3.227176>, <4.000000, 10.392362, 1.528662>, 
      <1.000000, 11.392362, -1.698514>, <2.000000, 11.893017, 0.000000>, <3.000000, 10.891708, 3.227176>, <4.000000, 11.392362, 1.528662>, 
      <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.000000, 12.392362, -1.698514>, <2.000000, 12.893017, 0.000000>, <3.000000, 11.891708, 3.227176>, <4.000000, 12.392362, 1.528662>, 
      <1.000000, 13.392362, -1.698514>, <2.000000, 13.893017, 0.000000>, <3.000000, 12.891708, 3.227176>, <4.000000, 13.392362, 1.528662>, 
      <1.000000, 14.392362, -1.698514>, <2.000000, 14.893017, 0.000000>, <3.000000, 13.891708, 3.227176>, <4.000000, 14.392362, 1.528662>, 
      <0.888743, 18.747382, -1.698514>, <1.777487, 22.603056, 0.000000>, <3.000000, 14.891708, 3.227176>, <4.516881, 18.682654, 1.528662>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.188143, -19.662704, 1.528662>, <5.188143, -19.217677, -0.169851>, <6.188143, -20.218987, -3.821656>, <7.368452, -20.035970, -1.830685>, 
      <4.188143, -18.662704, 1.528662>, <5.188143, -18.217677, -0.169851>, <6.188143, -19.218987, -3.821656>, <7.368452, -19.035970, -1.830685>, 
      <4.188143, -17.662704, 1.528662>, <5.188143, -17.217677, -0.169851>, <6.188143, -18.218987, -3.821656>, <7.368452, -18.035970, -1.830685>, 
      <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.368452, -17.035970, -1.830685>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.104700, -16.690518, 1.528662>, <5.188143, -16.217677, -0.169851>, <6.188143, -17.218987, -3.821656>, <7.368452, -17.035970, -1.830685>, 
      <4.021258, -15.718332, 1.528662>, <5.188143, -15.217677, -0.169851>, <6.188143, -16.218987, -3.821656>, <7.368452, -16.035970, -1.830685>, 
      <4.021258, -14.718332, 1.528662>, <5.188143, -14.217677, -0.169851>, <6.188143, -15.218987, -3.821656>, <7.368452, -15.035970, -1.830685>, 
      <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.341992, -14.035970, -1.380857>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.076886, -13.718332, 1.528662>, <5.299399, -13.217677, -0.169851>, <6.188143, -14.218987, -3.821656>, <7.341992, -14.035970, -1.380857>, 
      <4.132514, -12.718332, 1.528662>, <5.410656, -12.217677, -0.169851>, <6.188143, -13.218987, -3.821656>, <7.315531, -13.035970, -0.931030>, 
      <4.132514, -11.662704, 1.528662>, <5.410656, -11.106421, -0.169851>, <6.410656, -12.218987, -3.821656>, <7.426788, -12.035970, -0.931030>, 
      <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -5.462204>, <7.426788, -11.063785, -2.571578>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.215957, -10.690518, 1.528662>, <5.410656, -10.162049, -0.169851>, <6.410656, -11.218987, -5.462204>, <7.426788, -11.063785, -2.571578>, 
      <4.299399, -9.718332, 1.528662>, <5.410656, -9.217677, -0.169851>, <6.410656, -10.218987, -7.102752>, <7.426788, -10.091599, -4.212126>, 
      <4.299399, -8.718332, 1.528662>, <5.410656, -8.217677, -0.169851>, <6.410656, -9.218987, -7.102752>, <7.426788, -9.091599, -4.212126>, 
      <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -7.102752>, <7.426788, -8.091599, -3.391852>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.299399, -7.718332, 1.528662>, <5.410656, -7.217677, -0.169851>, <6.410656, -8.218987, -7.102752>, <7.426788, -8.091599, -3.391852>, 
      <4.299399, -6.718332, 1.528662>, <5.410656, -6.217677, -0.169851>, <6.410656, -7.218987, -7.102752>, <7.426788, -7.091599, -2.571578>, 
      <4.205328, 1.337015, 1.528662>, <5.222513, 8.893017, -0.169851>, <6.410656, -6.218987, -7.102752>, <7.426788, -6.091599, -2.571578>, 
      <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -5.462204>, <7.277088, 1.963749, -1.751304>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.102664, 5.864689, 1.528662>, <5.111257, 9.893017, -0.169851>, <6.205328, 1.836360, -5.462204>, <7.277088, 1.963749, -1.751304>, 
      <4.000000, 10.392362, 1.528662>, <5.000000, 10.893017, -0.169851>, <6.000000, 9.891708, -3.821656>, <7.127389, 10.019096, -0.931030>, 
      <4.000000, 11.392362, 1.528662>, <5.000000, 11.893017, -0.169851>, <6.000000, 10.891708, -3.821656>, <7.127389, 11.019096, -0.931030>, 
      <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, -0.931030>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.000000, 12.392362, 1.528662>, <5.000000, 12.893017, -0.169851>, <6.000000, 13.021185, -3.821656>, <7.127389, 13.148574, -0.931030>, 
      <4.000000, 13.392362, 1.528662>, <5.000000, 13.893017, -0.169851>, <6.000000, 15.150663, -3.821656>, <7.127389, 15.278052, -0.931030>, 
      <4.000000, 14.392362, 1.528662>, <5.000000, 14.893017, -0.169851>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, -0.931030>, 
      <4.516881, 18.682654, 1.528662>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, -0.931030>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.368452, -20.035970, -1.830685>, <8.548761, -19.852954, 0.160286>, <9.293984, -19.217677, -1.799311>, <10.293984, -20.218987, -3.175254>, 
      <7.368452, -19.035970, -1.830685>, <8.548761, -18.852954, 0.160286>, <9.293984, -18.217677, -1.799311>, <10.293984, -19.218987, -3.175254>, 
      <7.368452, -18.035970, -1.830685>, <8.548761, -17.852954, 0.160286>, <9.293984, -17.217677, -1.799311>, <10.293984, -18.218987, -3.175254>, 
      <7.368452, -17.035970, -1.830685>, <8.548761, -16.852954, 0.160286>, <9.293984, -16.217677, -1.799311>, <10.293984, -17.218987, -3.175254>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.368452, -17.035970, -1.830685>, <8.548761, -16.852954, 0.160286>, <9.293984, -16.217677, -1.799311>, <10.293984, -17.218987, -3.175254>, 
      <7.368452, -16.035970, -1.830685>, <8.548761, -15.852954, 0.160286>, <9.293984, -15.217677, -1.799311>, <10.293984, -16.218987, -3.175254>, 
      <7.368452, -15.035970, -1.830685>, <8.548761, -14.852954, 0.160286>, <9.071471, -14.662704, -1.799311>, <10.293984, -15.218987, -3.175254>, 
      <7.341992, -14.035970, -1.380857>, <8.495841, -13.852954, 1.059941>, <9.018550, -13.662704, -0.899655>, <10.182728, -14.441501, -3.175254>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.341992, -14.035970, -1.380857>, <8.495841, -13.852954, 1.059941>, <9.018550, -13.662704, -0.899655>, <10.182728, -14.441501, -3.175254>, 
      <7.315531, -13.035970, -0.931030>, <8.442920, -12.852954, 1.959597>, <8.965629, -12.662704, 0.000000>, <10.071471, -13.664014, -3.175254>, 
      <7.426788, -12.035970, -0.931030>, <8.442920, -11.852954, 1.959597>, <8.965629, -11.551447, 0.000000>, <9.965629, -12.664014, -1.375944>, 
      <7.426788, -11.063785, -2.571578>, <8.442920, -10.908582, 0.319049>, <8.965629, -10.607076, -1.640548>, <9.965629, -11.664014, -3.016492>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.426788, -11.063785, -2.571578>, <8.442920, -10.908582, 0.319049>, <8.965629, -10.607076, -1.640548>, <9.965629, -11.664014, -3.016492>, 
      <7.426788, -10.091599, -4.212126>, <8.442920, -9.964210, -1.321499>, <8.965629, -9.662704, -3.281096>, <9.965629, -10.664014, -4.657040>, 
      <7.426788, -9.091599, -4.212126>, <8.442920, -8.964210, -1.321499>, <8.965629, -8.662704, 0.000000>, <9.965629, -9.664014, -4.657040>, 
      <7.426788, -8.091599, -3.391852>, <8.442920, -7.964210, 0.319049>, <9.071471, -5.259842, -1.428864>, <9.965629, -8.664014, -3.016492>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.426788, -8.091599, -3.391852>, <8.442920, -7.964210, 0.319049>, <9.071471, -5.259842, -1.428864>, <9.965629, -8.664014, -3.016492>, 
      <7.426788, -7.091599, -2.571578>, <8.442920, -6.964210, 1.959597>, <9.177313, -1.856980, -2.857729>, <9.965629, -7.664014, -1.375944>, 
      <7.426788, -6.091599, -2.571578>, <8.442920, -5.964210, 1.959597>, <9.235618, 4.381609, -6.032983>, <10.177313, -1.858290, -4.233673>, 
      <7.277088, 1.963749, -1.751304>, <8.348848, 2.091137, 1.959597>, <9.006552, 7.414800, -3.016492>, <9.977400, 3.794195, -4.445356>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.277088, 1.963749, -1.751304>, <8.348848, 2.091137, 1.959597>, <9.006552, 7.414800, -3.016492>, <9.977400, 3.794195, -4.445356>, 
      <7.127389, 10.019096, -0.931030>, <8.254777, 10.146485, 1.959597>, <8.777487, 10.447991, 0.000000>, <9.777487, 9.446681, -4.657040>, 
      <7.127389, 11.019096, -0.931030>, <8.254777, 11.146485, 1.959597>, <8.777487, 11.447991, 0.000000>, <9.777487, 10.446681, -1.375944>, 
      <7.127389, 13.148574, -0.931030>, <8.254777, 13.275962, 1.959597>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, -1.375944>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.127389, 13.148574, -0.931030>, <8.254777, 13.275962, 1.959597>, <8.888743, 12.670504, 0.000000>, <9.944372, 12.670504, -1.375944>, 
      <7.127389, 15.278052, -0.931030>, <8.254777, 15.405440, 1.959597>, <9.000000, 13.893017, 0.000000>, <10.111257, 14.894327, -1.375944>, 
      <7.127389, 16.278052, -0.931030>, <8.254777, 16.405440, 1.959597>, <9.000000, 14.893017, 0.000000>, <10.000000, 13.891708, -1.375944>, 
      <7.127389, 17.278052, -0.931030>, <8.254777, 17.405440, 1.959597>, <10.797790, 24.684825, 0.000000>, <10.000000, 14.891708, -1.375944>
    }
  }
  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.50*ycm/100,zplis/2>
  //translate  <0.185073, -20.280892, 0.0>
}   


//////////////////////////////////////////////////////////////////////////////////////
#declare RideauVolant2 = union { // BezPtch001
object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-15.595451, -17.063048, -10.786472>, <-11.935352, -14.109815, -12.640694>, <-9.546425, -14.219945, -9.550324>, <-7.695980, -13.846737, -10.168398>, 
      <-13.177575, -12.431476, -10.786472>, <-11.935352, -13.271195, -12.640694>, <-9.546425, -13.381325, -9.550324>, <-7.568113, -12.176986, -10.168398>, 
      <-14.903516, -6.552571, -11.505600>, <-11.935352, -12.432574, -12.640694>, <-9.290693, -10.880444, -9.550324>, <-9.091830, -8.716508, -10.424950>, 
      <-14.793934, -5.713951, -11.505600>, <-12.795010, -9.073812, -13.000258>, <-10.952145, -8.251096, -9.806876>, <-9.922556, -6.982523, -10.553226>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.793934, -5.713951, -11.505600>, <-12.795010, -9.073812, -13.000258>, <-10.952145, -8.251096, -9.806876>, <-9.922556, -6.982523, -10.553226>, 
      <-14.684352, -4.875331, -11.505600>, <-13.654667, -5.715049, -13.359822>, <-12.613598, -5.621747, -10.063428>, <-10.753282, -5.248539, -10.681502>, 
      <-14.684352, -4.036710, -11.505600>, <-13.435503, -4.876429, -13.359822>, <-12.613598, -4.783127, -10.063428>, <-10.753282, -4.409919, -10.681502>, 
      <-15.167192, -1.408640, -10.697348>, <-13.920960, -2.252397, -12.551570>, <-13.100777, -2.158647, -9.255176>, <-10.888180, -1.783643, -9.924756>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-15.167192, -1.408640, -10.697348>, <-13.920960, -2.252397, -12.551570>, <-13.100777, -2.158647, -9.255176>, <-10.888180, -1.783643, -9.924756>, 
      <-15.650032, 1.219430, -9.889096>, <-14.406417, 0.371634, -11.743318>, <-13.587956, 0.465834, -8.446923>, <-11.023078, 0.842632, -9.168010>, 
      <-15.170680, 3.119020, -9.889096>, <-13.927065, 2.177025, -11.743318>, <-12.163239, 1.312521, -8.652948>, <-10.310719, 1.736418, -9.271022>, 
      <-14.807301, 4.305466, -7.581294>, <-12.827259, 3.771240, -10.393496>, <-11.039412, 3.338988, -5.706492>, <-8.655647, 4.582834, -5.730283>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.807301, 4.305466, -7.581294>, <-12.827259, 3.771240, -10.393496>, <-11.039412, 3.338988, -5.706492>, <-8.655647, 4.582834, -5.730283>, 
      <-14.443922, 5.491912, -5.273491>, <-11.727453, 5.365454, -9.043675>, <-9.915586, 5.365454, -2.760036>, <-7.000575, 7.429250, -2.189544>, 
      <-13.690654, 6.644760, -5.273491>, <-11.727453, 5.970471, -9.043675>, <-9.915586, 5.970471, -2.760036>, <-7.979070, 8.089064, -1.249870>, 
      <-13.291926, 7.940830, -3.734272>, <-10.610352, 7.127319, -7.504456>, <-8.861425, 7.127319, -1.220816>, <-7.196986, 8.407679, -1.094097>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.291926, 7.940830, -3.734272>, <-10.610352, 7.127319, -7.504456>, <-8.861425, 7.127319, -1.220816>, <-7.196986, 8.407679, -1.094097>, 
      <-12.893197, 9.236901, -2.195053>, <-9.493250, 8.284167, -5.965236>, <-7.807265, 8.284167, 0.318403>, <-6.414901, 8.726295, -0.938325>, 
      <-12.238762, 10.921473, -1.512614>, <-9.493250, 9.167265, -5.965236>, <-7.807265, 9.167265, 0.318403>, <-6.907709, 10.078609, -0.597105>, 
      <-11.930607, 11.675937, -1.849304>, <-9.591019, 10.470273, -6.796250>, <-8.054010, 10.470273, 1.441111>, <-7.031081, 11.090225, -0.204096>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-11.930607, 11.675937, -1.849304>, <-9.591019, 10.470273, -6.796250>, <-8.054010, 10.470273, 1.441111>, <-7.031081, 11.090225, -0.204096>, 
      <-11.622452, 12.430402, -2.185995>, <-9.688788, 11.773281, -7.627263>, <-8.300755, 11.773281, 2.563820>, <-7.154453, 12.101841, 0.188912>, 
      <-11.108974, 13.308738, -1.347268>, <-9.688788, 12.429374, -8.300644>, <-8.300755, 12.429374, 1.890439>, <-7.476487, 12.869056, 0.271585>, 
      <-10.647420, 14.093094, -1.347268>, <-10.154397, 13.260720, -7.881281>, <-8.359899, 13.260720, 2.309802>, <-7.506059, 13.676907, 0.481267>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.647420, 14.093094, -1.347268>, <-10.154397, 13.260720, -7.881281>, <-8.359899, 13.260720, 2.309802>, <-7.506059, 13.676907, 0.481267>, 
      <-10.185866, 14.877450, -1.347268>, <-10.620005, 14.092066, -7.461918>, <-8.419043, 14.092066, 2.729165>, <-7.535631, 14.484758, 0.690949>, 
      <-10.185866, 15.790069, -0.673887>, <-9.592823, 16.781309, -6.788537>, <-8.419043, 16.781309, 3.402546>, <-7.535631, 16.285689, 1.364330>, 
      <-10.394016, 19.602379, -0.673887>, <-9.592823, 17.565665, -6.788537>, <-8.419043, 17.565665, 3.402546>, <-7.958262, 19.443180, 1.364330>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.695980, -13.846737, -10.168398>, <-5.845534, -13.473528, -10.786472>, <-3.834493, -14.313247, -11.842348>, <-1.663977, -14.521086, -11.314410>, 
      <-7.568113, -12.176986, -10.168398>, <-5.589802, -10.972648, -10.786472>, <-3.834493, -13.474627, -11.842348>, <-1.663977, -13.682465, -11.314410>, 
      <-9.091830, -8.716508, -10.424950>, <-8.892966, -6.552571, -11.299576>, <-3.578761, -10.973747, -11.842348>, <-2.456078, -8.763159, -11.673974>, 
      <-9.922556, -6.982523, -10.553226>, <-8.892966, -5.713951, -11.299576>, <-4.838370, -8.344398, -12.201913>, <-3.085882, -7.029174, -11.853756>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.922556, -6.982523, -10.553226>, <-8.892966, -5.713951, -11.299576>, <-4.838370, -8.344398, -12.201913>, <-3.085882, -7.029174, -11.853756>, 
      <-10.753282, -5.248539, -10.681502>, <-8.892966, -4.875331, -11.299576>, <-6.097978, -5.715049, -12.561477>, <-3.715687, -5.295190, -12.033538>, 
      <-10.753282, -4.409919, -10.681502>, <-8.892966, -4.036710, -11.299576>, <-6.097978, -4.876429, -12.561477>, <-3.715687, -4.456570, -12.033538>, 
      <-10.888180, -1.783643, -9.924756>, <-8.675583, -1.408640, -10.594336>, <-6.598811, -2.252397, -11.753225>, <-4.221511, -1.830519, -11.225286>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.888180, -1.783643, -9.924756>, <-8.675583, -1.408640, -10.594336>, <-6.598811, -2.252397, -11.753225>, <-4.221511, -1.830519, -11.225286>, 
      <-11.023078, 0.842632, -9.168010>, <-8.458200, 1.219430, -9.889096>, <-7.099643, 0.371634, -10.944972>, <-4.727335, 0.795532, -10.417034>, 
      <-10.310719, 1.736418, -9.271022>, <-8.458200, 2.160316, -9.889096>, <-7.099643, 1.218321, -10.944972>, <-4.727335, 1.689319, -10.417034>, 
      <-8.655647, 4.582834, -5.730283>, <-6.271882, 5.826681, -5.754074>, <-4.836002, 4.913556, -7.355467>, <-3.505073, 4.489673, -7.468381>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-8.655647, 4.582834, -5.730283>, <-6.271882, 5.826681, -5.754074>, <-4.836002, 4.913556, -7.355467>, <-3.505073, 4.489673, -7.468381>, 
      <-7.000575, 7.429250, -2.189544>, <-4.085565, 9.493045, -1.619052>, <-2.572362, 8.608790, -3.765962>, <-2.282812, 7.290027, -4.519727>, 
      <-7.979070, 8.089064, -1.249870>, <-6.042554, 10.207656, 0.260296>, <-2.572362, 9.491888, -3.765962>, <-2.282812, 8.034084, -4.519727>, 
      <-7.196986, 8.407679, -1.094097>, <-5.532546, 9.688039, -0.967378>, <-3.040848, 8.888028, -4.053963>, <-2.045562, 8.380190, -3.894117>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.196986, 8.407679, -1.094097>, <-5.532546, 9.688039, -0.967378>, <-3.040848, 8.888028, -4.053963>, <-2.045562, 8.380190, -3.894117>, 
      <-6.414901, 8.726295, -0.938325>, <-5.022537, 9.168422, -2.195053>, <-3.509334, 8.284167, -4.341963>, <-1.808312, 8.726295, -3.268508>, 
      <-6.907709, 10.078609, -0.597105>, <-6.008152, 10.989952, -1.512614>, <-4.695471, 5.438978, -7.420402>, <-4.205575, 7.797426, -4.769013>, 
      <-7.031081, 11.090225, -0.204096>, <-6.008152, 11.710177, -1.849304>, <-4.728919, 8.606129, -6.207484>, <-3.783764, 9.949634, -4.179647>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.031081, 11.090225, -0.204096>, <-6.008152, 11.710177, -1.849304>, <-4.728919, 8.606129, -6.207484>, <-3.783764, 9.949634, -4.179647>, 
      <-7.154453, 12.101841, 0.188912>, <-6.008152, 12.430402, -2.185995>, <-4.762366, 11.773281, -4.994567>, <-3.361953, 12.101841, -3.590281>, 
      <-7.476487, 12.869056, 0.271585>, <-6.652219, 13.308738, -1.347268>, <-4.762366, 12.429374, -5.667948>, <-4.252081, 12.869056, -3.507608>, 
      <-7.506059, 13.676907, 0.481267>, <-6.652219, 14.093094, -1.347268>, <-5.227252, 13.260720, -5.248585>, <-4.484525, 13.676907, -3.297926>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.506059, 13.676907, 0.481267>, <-6.652219, 14.093094, -1.347268>, <-5.227252, 13.260720, -5.248585>, <-4.484525, 13.676907, -3.297926>, 
      <-7.535631, 14.484758, 0.690949>, <-6.652219, 14.877450, -1.347268>, <-5.692139, 14.092066, -4.829221>, <-4.716968, 14.484758, -3.088245>, 
      <-7.535631, 16.285689, 1.364330>, <-6.652219, 15.790069, -0.673887>, <-5.692139, 14.876423, -4.829221>, <-4.716968, 15.333246, -2.751554>, 
      <-7.958262, 19.443180, 1.364330>, <-7.497482, 21.320696, -0.673887>, <-5.692139, 15.789042, -4.155840>, <-4.957567, 18.848958, -2.414864>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.663977, -14.521086, -11.314410>, <0.506539, -14.728924, -10.786472>, <2.965208, -15.475341, -9.679089>, <4.675043, -15.102132, -10.232781>, 
      <-1.663977, -13.682465, -11.314410>, <0.506539, -13.890304, -10.786472>, <2.965208, -14.636720, -9.679089>, <4.675043, -14.263512, -10.232781>, 
      <-2.456078, -8.763159, -11.673974>, <-1.333395, -6.552571, -11.505600>, <2.965208, -13.798100, -9.679089>, <3.770754, -10.175336, -10.592345>, 
      <-3.085882, -7.029174, -11.853756>, <-1.333395, -5.713951, -11.505600>, <2.051798, -9.709924, -10.038654>, <3.314049, -7.711937, -10.772127>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.085882, -7.029174, -11.853756>, <-1.333395, -5.713951, -11.505600>, <2.051798, -9.709924, -10.038654>, <3.314049, -7.711937, -10.772127>, 
      <-3.715687, -5.295190, -12.033538>, <-1.333395, -4.875331, -11.505600>, <1.138388, -5.621747, -10.398218>, <2.857344, -5.248539, -10.951909>, 
      <-3.715687, -4.456570, -12.033538>, <-1.333395, -4.036710, -11.505600>, <1.138388, -4.783127, -10.398218>, <2.857344, -4.409919, -10.951909>, 
      <-4.221511, -1.830519, -11.225286>, <-1.844211, -1.408640, -10.697348>, <0.622392, -2.158647, -9.589966>, <2.337746, -1.783643, -10.143657>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.221511, -1.830519, -11.225286>, <-1.844211, -1.408640, -10.697348>, <0.622392, -2.158647, -9.589966>, <2.337746, -1.783643, -10.143657>, 
      <-4.727335, 0.795532, -10.417034>, <-2.355027, 1.219430, -9.889096>, <0.106397, 0.465834, -8.781713>, <1.818148, 0.842632, -9.335405>, 
      <-4.727335, 1.689319, -10.417034>, <-2.355027, 2.160316, -9.889096>, <0.106397, 1.312521, -8.781713>, <1.818148, 1.736418, -9.335405>, 
      <-3.505073, 4.489673, -7.468381>, <-2.174144, 4.065790, -7.581294>, <0.050642, 3.338988, -5.901784>, <2.248796, 3.702389, -6.741539>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.505073, 4.489673, -7.468381>, <-2.174144, 4.065790, -7.581294>, <0.050642, 3.338988, -5.901784>, <2.248796, 3.702389, -6.741539>, 
      <-2.282812, 7.290027, -4.519727>, <-1.993262, 5.971264, -5.273491>, <-0.005112, 5.365454, -3.021854>, <2.679444, 5.668359, -4.147673>, 
      <-2.282812, 8.034084, -4.519727>, <-1.993262, 6.576281, -5.273491>, <-0.005112, 5.970471, -3.021854>, <-0.508196, 8.481704, -1.210928>, 
      <-2.045562, 8.380190, -3.894117>, <-1.050275, 7.872351, -3.734272>, <0.704775, 7.127319, -1.482634>, <1.475265, 7.768202, -1.713327>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.045562, 8.380190, -3.894117>, <-1.050275, 7.872351, -3.734272>, <0.704775, 7.127319, -1.482634>, <1.475265, 7.768202, -1.713327>, 
      <-1.808312, 8.726295, -3.268508>, <-0.107289, 9.168422, -2.195053>, <1.414661, 8.284167, 0.056585>, <3.458727, 7.054701, -2.215726>, 
      <-4.205575, 7.797426, -4.769013>, <-3.715679, 10.155875, -2.117624>, <1.414661, 9.167265, 0.056585>, <0.148590, 9.661570, -1.030519>, 
      <-3.783764, 9.949634, -4.179647>, <-2.838609, 11.293138, -2.151809>, <-0.667694, 10.053234, 0.795383>, <-0.260757, 10.673186, -0.678213>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.783764, 9.949634, -4.179647>, <-2.838609, 11.293138, -2.151809>, <-0.667694, 10.053234, 0.795383>, <-0.260757, 10.673186, -0.678213>, 
      <-3.361953, 12.101841, -3.590281>, <-1.961540, 12.430402, -2.185995>, <-2.750049, 10.939204, 1.534181>, <-0.670103, 11.684803, -0.325907>, 
      <-4.252081, 12.869056, -3.507608>, <-3.741797, 13.308738, -1.347268>, <-0.708553, 12.429374, 1.465810>, <-0.822001, 12.869056, 0.059271>, 
      <-4.484525, 13.676907, -3.297926>, <-3.741797, 14.093094, -1.347268>, <-1.638285, 13.260720, 1.885173>, <-1.286867, 13.676907, 0.268953>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-4.484525, 13.676907, -3.297926>, <-3.741797, 14.093094, -1.347268>, <-1.638285, 13.260720, 1.885173>, <-1.286867, 13.676907, 0.268953>, 
      <-4.716968, 14.484758, -3.088245>, <-3.741797, 14.877450, -1.347268>, <-2.568017, 14.092066, 2.304537>, <-1.751733, 14.484758, 0.478634>, 
      <-4.716968, 15.333246, -2.751554>, <-3.741797, 15.790069, -0.673887>, <-2.568017, 14.876423, 2.304537>, <-1.751733, 15.333246, 0.815325>, 
      <-4.957567, 18.848958, -2.414864>, <-4.222995, 21.908874, -0.673887>, <-2.568017, 15.789042, 2.977918>, <-1.855808, 18.813264, 1.152015>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.675043, -15.102132, -10.232781>, <6.384879, -14.728924, -10.786472>, <8.344325, -15.568643, -11.816595>, <10.438984, -15.148783, -11.301534>, 
      <4.675043, -14.263512, -10.232781>, <6.384879, -13.890304, -10.786472>, <8.344325, -14.730022, -11.816595>, <10.438984, -14.310163, -11.301534>, 
      <3.770754, -10.175336, -10.592345>, <4.576299, -6.552571, -11.505600>, <8.344325, -13.891402, -11.816595>, <9.199661, -10.268638, -11.661098>, 
      <3.314049, -7.711937, -10.772127>, <4.576299, -5.713951, -11.505600>, <7.445261, -9.803226, -12.176159>, <8.750129, -7.805239, -11.840880>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <3.314049, -7.711937, -10.772127>, <4.576299, -5.713951, -11.505600>, <7.445261, -9.803226, -12.176159>, <8.750129, -7.805239, -11.840880>, 
      <2.857344, -5.248539, -10.951909>, <4.576299, -4.875331, -11.505600>, <6.546197, -5.715049, -12.535724>, <8.300597, -5.341841, -12.020662>, 
      <2.857344, -4.409919, -10.951909>, <4.576299, -4.036710, -11.505600>, <6.546197, -4.876429, -12.535724>, <8.300597, -4.503221, -12.020662>, 
      <2.337746, -1.783643, -10.143657>, <4.053100, -1.408640, -10.697348>, <6.018870, -2.252397, -11.727471>, <7.769593, -1.877394, -11.212410>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <2.337746, -1.783643, -10.143657>, <4.053100, -1.408640, -10.697348>, <6.018870, -2.252397, -11.727471>, <7.769593, -1.877394, -11.212410>, 
      <1.818148, 0.842632, -9.335405>, <3.529900, 1.219430, -9.889096>, <5.491542, 0.371634, -10.919219>, <7.238589, 0.748433, -10.404158>, 
      <1.818148, 1.736418, -9.335405>, <3.529900, 2.160316, -9.889096>, <5.491542, 1.218321, -10.919219>, <7.588548, 1.689319, -10.404158>, 
      <2.248796, 3.702389, -6.741539>, <4.446950, 4.065790, -7.581294>, <6.220003, 3.291888, -9.143629>, <7.792582, 4.539190, -7.592851>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <2.248796, 3.702389, -6.741539>, <4.446950, 4.065790, -7.581294>, <6.220003, 3.291888, -9.143629>, <7.792582, 4.539190, -7.592851>, 
      <2.679444, 5.668359, -4.147673>, <5.363999, 5.971264, -5.273491>, <6.948464, 5.365454, -7.368038>, <7.996615, 7.389062, -4.781545>, 
      <-0.508196, 8.481704, -1.210928>, <-1.011280, 10.992936, 0.599998>, <6.948464, 5.970471, -7.368038>, <4.618349, 8.053369, -4.020962>, 
      <1.475265, 7.768202, -1.713327>, <2.245756, 8.409085, -1.944019>, <7.017860, 5.594948, -6.975310>, <6.234591, 7.623647, -4.204890>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.475265, 7.768202, -1.713327>, <2.245756, 8.409085, -1.944019>, <7.017860, 5.594948, -6.975310>, <6.234591, 7.623647, -4.204890>, 
      <3.458727, 7.054701, -2.215726>, <5.502792, 5.825234, -4.488036>, <7.087256, 5.219425, -6.582583>, <7.850833, 7.193924, -4.388818>, 
      <0.148590, 9.661570, -1.030519>, <-1.117481, 10.155875, -2.117624>, <7.087256, 5.824442, -6.582583>, <6.153046, 8.407197, -4.047598>, 
      <-0.260757, 10.673186, -0.678213>, <0.146180, 11.293138, -2.151809>, <3.452612, 8.381823, -6.048617>, <4.335724, 10.078066, -3.780615>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-0.260757, 10.673186, -0.678213>, <0.146180, 11.293138, -2.151809>, <3.452612, 8.381823, -6.048617>, <4.335724, 10.078066, -3.780615>, 
      <-0.670103, 11.684803, -0.325907>, <1.409842, 12.430402, -2.185995>, <-0.182032, 10.939204, -5.514651>, <2.518402, 11.748934, -3.513632>, 
      <-0.822001, 12.869056, 0.059271>, <-0.935449, 13.308738, -1.347268>, <2.623666, 12.429374, -5.583022>, <2.311833, 12.869056, -3.465145>, 
      <-1.286867, 13.676907, 0.268953>, <-0.935449, 14.093094, -1.347268>, <1.311833, 13.260720, -5.163659>, <1.655917, 13.676907, -3.255463>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.286867, 13.676907, 0.268953>, <-0.935449, 14.093094, -1.347268>, <1.311833, 13.260720, -5.163659>, <1.655917, 13.676907, -3.255463>, 
      <-1.751733, 14.484758, 0.478634>, <-0.935449, 14.877450, -1.347268>, <0.000000, 14.092066, -4.744296>, <1.000000, 14.484758, -3.045782>, 
      <-1.751733, 15.333246, 0.815325>, <-0.935449, 15.790069, -0.673887>, <0.000000, 14.876423, -4.744296>, <1.000000, 15.333246, -2.709091>, 
      <-1.855808, 18.813264, 1.152015>, <-1.143599, 21.837485, -0.673887>, <0.000000, 15.789042, -4.070915>, <0.888743, 18.813264, -2.372401>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.438984, -15.148783, -11.301534>, <12.533642, -14.728924, -10.786472>, <14.372569, -13.708480, -9.807855>, <16.467227, -13.335272, -10.322917>, 
      <10.438984, -14.310163, -11.301534>, <12.533642, -13.890304, -10.786472>, <14.628301, -11.719065, -9.807855>, <16.722959, -11.345856, -10.322917>, 
      <9.199661, -10.268638, -11.661098>, <10.054996, -6.645873, -11.505600>, <14.628301, -10.880444, -9.807855>, <15.851827, -8.716508, -10.682481>, 
      <8.750129, -7.805239, -11.840880>, <10.054996, -5.807253, -11.505600>, <13.394564, -8.297747, -10.167419>, <15.234958, -7.005849, -10.862263>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.750129, -7.805239, -11.840880>, <10.054996, -5.807253, -11.505600>, <13.394564, -8.297747, -10.167419>, <15.234958, -7.005849, -10.862263>, 
      <8.300597, -5.341841, -12.020662>, <10.054996, -4.968633, -11.505600>, <12.160827, -5.715049, -10.526983>, <14.618090, -5.295190, -11.042045>, 
      <8.300597, -4.503221, -12.020662>, <10.054996, -4.130012, -11.505600>, <12.160827, -4.876429, -10.526983>, <14.618090, -4.456570, -11.042045>, 
      <7.769593, -1.877394, -11.212410>, <9.520316, -1.502391, -10.697348>, <11.621735, -2.252397, -9.718731>, <14.190501, -1.830519, -10.233793>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.769593, -1.877394, -11.212410>, <9.520316, -1.502391, -10.697348>, <11.621735, -2.252397, -9.718731>, <14.190501, -1.830519, -10.233793>, 
      <7.238589, 0.748433, -10.404158>, <8.985636, 1.125231, -9.889096>, <11.082642, 0.371634, -8.910479>, <13.762913, 0.795532, -9.425540>, 
      <7.588548, 1.689319, -10.404158>, <9.685554, 2.160316, -9.889096>, <11.082642, 1.218321, -8.910479>, <13.762913, 1.689319, -9.425540>, 
      <7.792582, 4.539190, -7.592851>, <9.365160, 5.786493, -6.042074>, <11.556255, 3.291888, -6.097075>, <13.837514, 3.678839, -6.878243>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <7.792582, 4.539190, -7.592851>, <9.365160, 5.786493, -6.042074>, <11.556255, 3.291888, -6.097075>, <13.837514, 3.678839, -6.878243>, 
      <7.996615, 7.389062, -4.781545>, <9.044767, 9.412669, -2.195053>, <12.029867, 5.365454, -3.283672>, <13.912114, 5.668359, -4.330945>, 
      <4.618349, 8.053369, -4.020962>, <2.288233, 10.136267, -0.673887>, <12.029867, 5.970471, -3.283672>, <13.912114, 6.273376, -4.330945>, 
      <6.234591, 7.623647, -4.204890>, <5.451321, 9.652345, -1.434470>, <11.110199, 7.127319, -1.744453>, <12.927060, 7.499835, -2.791726>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <6.234591, 7.623647, -4.204890>, <5.451321, 9.652345, -1.434470>, <11.110199, 7.127319, -1.744453>, <12.927060, 7.499835, -2.791726>, 
      <7.850833, 7.193924, -4.388818>, <8.614409, 9.168422, -2.195053>, <10.190531, 8.284167, -0.205233>, <11.942006, 8.726295, -1.252507>, 
      <6.153046, 8.407197, -4.047598>, <5.218836, 10.989952, -1.512614>, <10.190531, 9.167265, -0.205233>, <9.795425, 10.078609, -0.943849>, 
      <4.335724, 10.078066, -3.780615>, <5.218836, 11.774308, -1.512614>, <8.353476, 10.470273, 0.754665>, <8.804715, 11.122291, -0.463900>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.335724, 10.078066, -3.780615>, <5.218836, 11.774308, -1.512614>, <8.353476, 10.470273, 0.754665>, <8.804715, 11.122291, -0.463900>, 
      <2.518402, 11.748934, -3.513632>, <5.218836, 12.558665, -1.512614>, <6.516421, 11.773281, 1.714563>, <7.814006, 12.165973, 0.016049>, 
      <2.311833, 12.869056, -3.465145>, <2.000000, 13.308738, -1.347268>, <6.516421, 12.557637, 1.714563>, <5.758210, 12.997319, 0.435412>, 
      <1.655917, 13.676907, -3.255463>, <2.000000, 14.093094, -1.347268>, <4.758210, 13.324852, 1.797235>, <4.879105, 13.773104, 0.476749>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.655917, 13.676907, -3.255463>, <2.000000, 14.093094, -1.347268>, <4.758210, 13.324852, 1.797235>, <4.879105, 13.773104, 0.476749>, 
      <1.000000, 14.484758, -3.045782>, <2.000000, 14.877450, -1.347268>, <3.000000, 14.092066, 1.879908>, <4.000000, 14.548890, 0.518085>, 
      <1.000000, 15.333246, -2.709091>, <2.000000, 15.790069, -0.673887>, <3.000000, 14.876423, 1.879908>, <4.000000, 15.333246, 0.518085>, 
      <0.888743, 18.813264, -2.372401>, <1.777487, 21.837485, -0.673887>, <3.000000, 15.789042, 2.553289>, <4.516881, 18.762494, 0.854775>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <16.467227, -13.335272, -10.322917>, <18.561885, -12.962064, -10.837978>, <20.912276, -14.568979, -11.945361>, <23.273770, -14.415498, -10.747842>, 
      <16.722959, -11.345856, -10.322917>, <18.817618, -10.972648, -10.837978>, <20.912276, -11.812367, -11.945361>, <23.273770, -11.658885, -10.747842>, 
      <15.851827, -8.716508, -10.682481>, <17.075352, -6.552571, -11.557106>, <20.912276, -10.973747, -11.945361>, <23.273770, -10.820265, -10.747842>, 
      <15.234958, -7.005849, -10.862263>, <17.075352, -5.713951, -11.557106>, <20.046730, -8.344398, -12.304925>, <22.414522, -8.190916, -11.107407>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <15.234958, -7.005849, -10.862263>, <17.075352, -5.713951, -11.557106>, <20.046730, -8.344398, -12.304925>, <22.414522, -8.190916, -11.107407>, 
      <14.618090, -5.295190, -11.042045>, <17.075352, -4.875331, -11.557106>, <19.181184, -5.715049, -12.664489>, <21.555273, -5.561568, -11.466971>, 
      <14.618090, -4.456570, -11.042045>, <17.075352, -4.036710, -11.557106>, <19.181184, -4.876429, -12.664489>, <21.555273, -4.722947, -11.466971>, 
      <14.190501, -1.830519, -10.233793>, <16.759268, -1.408640, -10.748854>, <18.627380, -2.252397, -11.856237>, <20.996495, -2.098178, -10.658719>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <14.190501, -1.830519, -10.233793>, <16.759268, -1.408640, -10.748854>, <18.627380, -2.252397, -11.856237>, <20.996495, -2.098178, -10.658719>, 
      <13.762913, 0.795532, -9.425540>, <16.443183, 1.219430, -9.940602>, <18.073577, 0.371634, -11.047985>, <20.437717, 0.526592, -9.850466>, 
      <13.762913, 1.689319, -9.425540>, <16.443183, 2.160316, -9.940602>, <18.540189, 1.218321, -11.047985>, <20.671023, 1.373279, -9.850466>, 
      <13.837514, 3.678839, -6.878243>, <16.118773, 4.065790, -7.659410>, <18.014176, 3.291888, -9.338920>, <19.940156, 3.407903, -7.522706>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <13.837514, 3.678839, -6.878243>, <16.118773, 4.065790, -7.659410>, <18.014176, 3.291888, -9.338920>, <19.940156, 3.407903, -7.522706>, 
      <13.912114, 5.668359, -4.330945>, <15.794362, 5.971264, -5.378219>, <17.488163, 5.365454, -7.629856>, <19.209288, 5.442527, -5.194946>, 
      <13.912114, 6.273376, -4.330945>, <15.794362, 6.576281, -5.378219>, <17.488163, 5.970471, -7.629856>, <19.209288, 6.047544, -5.194946>, 
      <12.927060, 7.499835, -2.791726>, <14.743922, 7.872351, -3.838999>, <16.378883, 7.127319, -6.090637>, <18.040219, 7.222104, -3.655726>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <12.927060, 7.499835, -2.791726>, <14.743922, 7.872351, -3.838999>, <16.378883, 7.127319, -6.090637>, <18.040219, 7.222104, -3.655726>, 
      <11.942006, 8.726295, -1.252507>, <13.693481, 9.168422, -2.299780>, <15.269603, 8.284167, -4.551417>, <16.871150, 8.396664, -2.116507>, 
      <9.795425, 10.078609, -0.943849>, <9.400320, 10.989952, -1.682465>, <15.269603, 9.167265, -4.551417>, <16.871150, 9.279762, -2.116507>, 
      <8.804715, 11.122291, -0.463900>, <9.255955, 11.774308, -1.682465>, <12.839389, 10.470273, -4.942844>, <14.371603, 10.576480, -1.750866>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.804715, 11.122291, -0.463900>, <9.255955, 11.774308, -1.682465>, <12.839389, 10.470273, -4.942844>, <14.371603, 10.576480, -1.750866>, 
      <7.814006, 12.165973, 0.016049>, <9.111590, 12.558665, -1.682465>, <10.409175, 11.773281, -5.334270>, <11.872057, 11.873199, -1.385225>, 
      <5.758210, 12.997319, 0.435412>, <5.000000, 13.437001, -0.843738>, <10.409175, 12.557637, -5.334270>, <11.872057, 12.657555, -1.385225>, 
      <4.879105, 13.773104, 0.476749>, <5.000000, 14.221357, -0.843738>, <8.204588, 14.274896, -4.914906>, <9.499723, 14.374814, -0.965862>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.879105, 13.773104, 0.476749>, <5.000000, 14.221357, -0.843738>, <8.204588, 14.274896, -4.914906>, <9.499723, 14.374814, -0.965862>, 
      <4.000000, 14.548890, 0.518085>, <5.000000, 15.005713, -0.843738>, <6.000000, 15.992155, -4.495543>, <7.127389, 16.092073, -0.546498>, 
      <4.000000, 15.333246, 0.518085>, <5.000000, 15.790069, -0.843738>, <6.000000, 16.776511, -4.495543>, <7.127389, 16.876429, -0.546498>, 
      <4.516881, 18.762494, 0.854775>, <6.033763, 21.735947, -0.843738>, <6.000000, 17.560868, -4.495543>, <7.127389, 17.660786, -0.546498>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <23.273770, -14.415498, -10.747842>, <25.635264, -14.262016, -9.550324>, <27.196252, -11.811268, -10.786472>, <29.290910, -14.568979, -10.786472>, 
      <23.273770, -11.658885, -10.747842>, <25.635264, -11.505404, -9.550324>, <27.196252, -10.972648, -10.786472>, <29.290910, -11.812367, -10.786472>, 
      <23.273770, -10.820265, -10.747842>, <25.635264, -10.666783, -9.550324>, <25.498677, -6.552571, -11.505600>, <29.290910, -10.973747, -10.786472>, 
      <22.414522, -8.190916, -11.107407>, <24.782314, -8.037435, -9.909888>, <25.498677, -5.713951, -11.505600>, <28.447709, -8.344398, -11.146036>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <22.414522, -8.190916, -11.107407>, <24.782314, -8.037435, -9.909888>, <25.498677, -5.713951, -11.505600>, <28.447709, -8.344398, -11.146036>, 
      <21.555273, -5.561568, -11.466971>, <23.929363, -5.408086, -10.269452>, <25.498677, -4.875331, -11.505600>, <27.604508, -5.715049, -11.505600>, 
      <21.555273, -4.722947, -11.466971>, <23.929363, -4.569466, -10.269452>, <25.030101, -4.409919, -11.505600>, <27.604508, -4.876429, -11.505600>, 
      <20.996495, -2.098178, -10.658719>, <23.365611, -1.943958, -9.461200>, <24.464042, -1.783643, -10.697348>, <27.370220, -4.224413, -11.505600>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <20.996495, -2.098178, -10.658719>, <23.365611, -1.943958, -9.461200>, <24.464042, -1.783643, -10.697348>, <27.370220, -4.224413, -11.505600>, 
      <20.437717, 0.526592, -9.850466>, <22.801858, 0.681550, -8.652948>, <23.897983, 0.842632, -9.889096>, <27.135932, -3.572397, -11.505600>, 
      <20.671023, 1.373279, -9.850466>, <22.801858, 1.528237, -8.652948>, <23.897983, 1.783518, -9.889096>, <25.994989, 0.841523, -9.889096>, 
      <19.940156, 3.407903, -7.522706>, <21.866136, 3.523918, -5.706492>, <22.856881, 3.742767, -7.581294>, <25.994989, 1.688210, -9.889096>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <19.940156, 3.407903, -7.522706>, <21.866136, 3.523918, -5.706492>, <22.856881, 3.742767, -7.581294>, <25.994989, 1.688210, -9.889096>, 
      <19.209288, 5.442527, -5.194946>, <20.930413, 5.519599, -2.760036>, <21.815780, 5.702015, -5.273491>, <25.994989, 2.534896, -9.889096>, 
      <19.209288, 6.047544, -5.194946>, <20.930413, 6.124616, -2.760036>, <21.815780, 6.307032, -5.273491>, <23.509581, 5.701223, -5.273491>, 
      <18.040219, 7.222104, -3.655726>, <19.701555, 7.316888, -1.220816>, <20.556165, 7.541226, -3.734272>, <22.191126, 6.796194, -3.734272>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <18.040219, 7.222104, -3.655726>, <19.701555, 7.316888, -1.220816>, <20.556165, 7.541226, -3.734272>, <22.191126, 6.796194, -3.734272>, 
      <16.871150, 8.396664, -2.116507>, <18.472697, 8.509160, 0.318403>, <19.296550, 8.775420, -2.195053>, <20.872672, 7.891165, -2.195053>, 
      <16.871150, 9.279762, -2.116507>, <18.472697, 9.392258, 0.318403>, <8.777487, 10.734873, -0.673887>, <20.872672, 8.774263, -2.195053>, 
      <14.371603, 10.576480, -1.750866>, <15.903818, 10.682688, 1.441111>, <11.395343, 11.472239, -1.093250>, <18.091728, 10.099242, -1.853833>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <14.371603, 10.576480, -1.750866>, <15.903818, 10.682688, 1.441111>, <11.395343, 11.472239, -1.093250>, <18.091728, 10.099242, -1.853833>, 
      <11.872057, 11.873199, -1.385225>, <13.334939, 11.973117, 2.563820>, <14.013199, 12.209605, -1.512614>, <15.310784, 11.424222, -1.512614>, 
      <11.872057, 12.657555, -1.385225>, <13.334939, 12.757473, 2.563820>, <14.013199, 12.993961, -1.512614>, <15.310784, 12.208578, -1.512614>, 
      <9.499723, 14.374814, -0.965862>, <10.794858, 14.474732, 2.983183>, <12.254514, 14.049698, -1.093250>, <13.957544, 14.097797, -1.205480>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.499723, 14.374814, -0.965862>, <10.794858, 14.474732, 2.983183>, <12.254514, 14.049698, -1.093250>, <13.957544, 14.097797, -1.205480>, 
      <7.127389, 16.092073, -0.546498>, <8.254777, 16.191991, 3.402546>, <10.495829, 15.105435, -0.673887>, <12.604305, 15.987016, -0.898347>, 
      <7.127389, 16.876429, -0.546498>, <8.254777, 16.976347, 3.402546>, <11.493048, 15.985989, -0.898347>, <11.495829, 15.104408, -0.673887>, 
      <7.127389, 17.660786, -0.546498>, <8.254777, 17.760704, 3.402546>, <10.797790, 23.470334, -0.673887>, <12.493048, 15.984961, -0.898347>
    }
  }
  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.47*ycm/100,zplis/2>
  //translate  <0.185073, -20.280892, 0.0>
//  translate  <0.185073, -20.280892, 0.0>
}



//////////////////////////////////////////////////////////////////////////////////////
#declare RideauVolant4d = union { // BezPtch001
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.226068, -18.109363, -2.495085>, <-14.682241, -19.532475, -8.958188>, <-10.496574, -18.662021, -1.779419>, <-10.215260, -18.385692, -3.657234>, 
      <-14.255743, -17.145440, -2.536983>, <-15.841223, -18.568553, -6.302752>, <-10.526249, -17.698098, -1.821318>, <-10.244935, -17.421769, -3.699133>, 
      <-14.266327, -14.128858, -2.726384>, <-15.870898, -17.604630, -6.344651>, <-10.555925, -16.734175, -1.863217>, <-10.547931, -15.406076, -3.339343>, 
      <-14.073140, -11.850595, -2.587633>, <-15.759103, -13.895383, -6.274036>, <-11.113411, -14.111295, -1.362812>, <-10.761604, -12.978018, -2.997269>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.073140, -11.850595, -2.587633>, <-15.759103, -13.895383, -6.274036>, <-11.113411, -14.111295, -1.362812>, <-10.761604, -12.978018, -2.997269>, 
      <-13.879954, -9.572331, -2.448882>, <-15.647308, -10.186136, -6.203421>, <-11.670897, -11.488414, -0.862408>, <-10.975278, -10.549960, -2.655195>, 
      <-13.915309, -4.704024, -6.268637>, <-15.498046, -9.221030, -6.260697>, <-10.864275, -9.740438, -0.723398>, <-10.441552, -7.241818, -3.233506>, 
      <-13.963299, -2.675567, -5.637408>, <-14.334551, -5.369634, -8.133224>, <-11.741174, -6.238899, -1.604839>, <-10.663348, -4.467027, -3.489868>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.963299, -2.675567, -5.637408>, <-14.334551, -5.369634, -8.133224>, <-11.741174, -6.238899, -1.604839>, <-10.663348, -4.467027, -3.489868>, 
      <-14.011289, -0.647110, -5.006179>, <-13.171056, -1.518239, -10.005751>, <-12.618073, -2.737359, -2.486279>, <-10.885144, -1.692235, -3.746229>, 
      <-14.011289, 0.402282, -4.821673>, <-13.171056, 0.619581, -9.629875>, <-11.655480, -1.388570, -1.905605>, <-10.403848, -0.493144, -3.363639>, 
      <-14.011289, 1.280329, -4.667293>, <-12.846424, 1.550160, -9.645066>, <-11.655480, -0.510523, -1.751225>, <-10.135995, 1.424853, -2.764754>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.011289, 1.280329, -4.667293>, <-12.846424, 1.550160, -9.645066>, <-11.655480, -0.510523, -1.751225>, <-10.135995, 1.424853, -2.764754>, 
      <-14.011289, 2.158377, -4.512913>, <-12.521793, 2.480739, -9.660257>, <-11.655480, 0.367525, -1.596845>, <-9.868141, 3.342850, -2.165868>, 
      <-13.901707, 3.263066, -4.179099>, <-12.521793, 3.425068, -9.476620>, <-11.655480, 1.311854, -1.430811>, <-9.868141, 4.163565, -1.694505>, 
      <-14.091491, 4.713910, -3.881373>, <-12.614891, 5.046121, -8.897201>, <-11.460412, 2.842879, -0.894619>, <-9.971042, 4.716447, -1.832771>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.091491, 4.713910, -3.881373>, <-12.614891, 5.046121, -8.897201>, <-11.460412, 2.842879, -0.894619>, <-9.971042, 4.716447, -1.832771>, 
      <-14.281275, 6.164755, -3.583647>, <-12.707989, 6.667175, -8.317782>, <-11.265345, 4.373903, -0.358428>, <-10.073943, 5.269329, -1.971037>, 
      <-13.575329, 8.358394, -2.452873>, <-12.707989, 7.597470, -8.084639>, <-11.265345, 5.318232, -0.174791>, <-10.107712, 6.838313, -1.313832>, 
      <-13.575329, 9.288690, -2.219731>, <-11.098368, 9.485464, -7.883288>, <-11.299115, 6.766269, 0.481803>, <-10.124597, 8.027480, -0.868964>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.575329, 9.288690, -2.219731>, <-11.098368, 9.485464, -7.883288>, <-11.299115, 6.766269, 0.481803>, <-10.124597, 8.027480, -0.868964>, 
      <-13.575329, 10.218985, -1.986588>, <-9.488748, 11.373458, -7.681936>, <-11.332884, 8.214306, 1.138396>, <-10.141482, 9.216646, -0.424096>, 
      <-12.894214, 12.048822, -1.753445>, <-9.488748, 12.335673, -7.409643>, <-11.332884, 9.144601, 1.371539>, <-9.507950, 10.389385, -0.190953>, 
      <-12.535209, 13.384224, -1.231124>, <-9.540785, 13.297887, -7.137349>, <-11.332884, 10.074897, 1.604682>, <-9.250251, 11.335640, 0.186779>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-12.535209, 13.384224, -1.231124>, <-9.540785, 13.297887, -7.137349>, <-11.332884, 10.074897, 1.604682>, <-9.250251, 11.335640, 0.186779>, 
      <-12.176203, 14.719626, -0.708803>, <-9.592823, 14.260101, -6.865056>, <-11.332884, 11.005192, 1.837824>, <-8.992552, 12.281894, 0.564511>, 
      <-10.932242, 15.930633, -0.436509>, <-10.173338, 15.990918, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.338795, 1.819962>, 
      <-10.394016, 19.753449, 0.000000>, <-9.509892, 17.322641, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.215260, -18.385692, -3.657234>, <-9.933946, -18.109363, -5.535049>, <-10.068030, -19.335312, -8.196805>, <-8.233425, -18.722338, -8.117832>, 
      <-10.244935, -17.421769, -3.699133>, <-9.963621, -17.145440, -5.576947>, <-10.097706, -18.371389, -8.238704>, <-8.263100, -17.758415, -8.159731>, 
      <-10.547931, -15.406076, -3.339343>, <-10.539937, -14.077978, -4.815469>, <-10.127381, -17.407467, -8.280603>, <-8.283230, -15.768163, -8.275380>, 
      <-10.761604, -12.978018, -2.997269>, <-10.409798, -11.844741, -4.631726>, <-10.456846, -14.567978, -7.931046>, <-8.382973, -13.209286, -8.008843>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.761604, -12.978018, -2.997269>, <-10.409798, -11.844741, -4.631726>, <-10.456846, -14.567978, -7.931046>, <-8.382973, -13.209286, -8.008843>, 
      <-10.975278, -10.549960, -2.655195>, <-10.279659, -9.611505, -4.447983>, <-10.786312, -11.728489, -7.581489>, <-8.482715, -10.650410, -7.742305>, 
      <-10.441552, -7.241818, -3.233506>, <-10.018828, -4.743198, -5.743614>, <-10.258950, -9.372829, -7.836766>, <-7.595825, -7.038426, -7.052702>, 
      <-10.663348, -4.467027, -3.489868>, <-9.585522, -2.695154, -5.374897>, <-9.246637, -5.718491, -7.925927>, <-7.113664, -4.197029, -6.781667>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.663348, -4.467027, -3.489868>, <-9.585522, -2.695154, -5.374897>, <-9.246637, -5.718491, -7.925927>, <-7.113664, -4.197029, -6.781667>, 
      <-10.885144, -1.692235, -3.746229>, <-9.152216, -0.647110, -5.006179>, <-8.234323, -2.064152, -8.015087>, <-6.631502, -1.355631, -6.510633>, 
      <-10.403848, -0.493144, -3.363639>, <-9.152216, 0.402282, -4.821673>, <-8.234323, 0.073667, -7.639211>, <-6.631502, 0.237975, -6.230442>, 
      <-10.135995, 1.424853, -2.764754>, <-8.616509, 3.360228, -3.778282>, <-7.510163, 3.084145, -6.734958>, <-6.269422, 2.182237, -5.701125>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.135995, 1.424853, -2.764754>, <-8.616509, 3.360228, -3.778282>, <-7.510163, 3.084145, -6.734958>, <-6.269422, 2.182237, -5.701125>, 
      <-9.868141, 3.342850, -2.165868>, <-8.080803, 6.318175, -2.734892>, <-6.786002, 6.094623, -5.830705>, <-5.907342, 4.126500, -5.171809>, 
      <-9.868141, 4.163565, -1.694505>, <-8.080803, 7.015275, -1.958200>, <-6.786002, 7.000423, -5.060309>, <-5.778621, 5.051565, -4.619704>, 
      <-9.971042, 4.716447, -1.832771>, <-8.481672, 6.590015, -2.770923>, <-7.186871, 6.470813, -5.869884>, <-5.955425, 5.552272, -4.875629>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.971042, 4.716447, -1.832771>, <-8.481672, 6.590015, -2.770923>, <-7.186871, 6.470813, -5.869884>, <-5.955425, 5.552272, -4.875629>, 
      <-10.073943, 5.269329, -1.971037>, <-8.882541, 6.164755, -3.583647>, <-7.587740, 5.941203, -6.679460>, <-6.132229, 6.052979, -5.131553>, 
      <-10.107712, 6.838313, -1.313832>, <-8.950080, 8.358394, -2.452873>, <-7.528441, 6.522758, -6.011292>, <-6.259097, 7.080249, -4.964733>, 
      <-10.124597, 8.027480, -0.868964>, <-8.950080, 9.288690, -2.219731>, <-7.591860, 8.363446, -5.549994>, <-6.229433, 8.645904, -4.251188>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.124597, 8.027480, -0.868964>, <-8.950080, 9.288690, -2.219731>, <-7.591860, 8.363446, -5.549994>, <-6.229433, 8.645904, -4.251188>, 
      <-10.141482, 9.216646, -0.424096>, <-8.950080, 10.218985, -1.986588>, <-7.655280, 10.204133, -5.088697>, <-6.199768, 10.211559, -3.537642>, 
      <-9.507950, 10.389385, -0.190953>, <-7.683017, 11.634168, -1.753445>, <-6.572421, 11.618807, -4.855554>, <-5.444369, 11.626487, -3.304500>, 
      <-9.250251, 11.335640, 0.186779>, <-7.167618, 12.596382, -1.231124>, <-6.132280, 12.581021, -4.593696>, <-5.080668, 12.588702, -2.912410>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.250251, 11.335640, 0.186779>, <-7.167618, 12.596382, -1.231124>, <-6.132280, 12.581021, -4.593696>, <-5.080668, 12.588702, -2.912410>, 
      <-8.992552, 12.281894, 0.564511>, <-6.652219, 13.558597, -0.708803>, <-5.692139, 13.543235, -4.331838>, <-4.716968, 13.550916, -2.520320>, 
      <-7.535631, 15.338795, 1.819962>, <-6.652219, 14.520811, -0.436509>, <-5.692139, 14.505449, -4.059545>, <-4.716968, 14.513130, -2.248027>, 
      <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 15.467664, -3.787251>, <-4.957567, 19.080868, -1.893626>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-8.233425, -18.722338, -8.117832>, <-6.398819, -18.109363, -8.038859>, <-3.551851, -18.693821, -7.041999>, <-3.158105, -18.401592, -8.930422>, 
      <-8.263100, -17.758415, -8.159731>, <-6.428494, -17.145440, -8.080757>, <-3.581526, -17.729898, -7.083898>, <-3.174911, -17.437669, -8.976968>, 
      <-8.283230, -15.768163, -8.275380>, <-6.439078, -14.128858, -8.270158>, <-3.611202, -16.765975, -7.125797>, <-3.145638, -15.447417, -9.081884>, 
      <-8.382973, -13.209286, -8.008843>, <-6.309099, -11.850595, -8.086640>, <-3.885822, -14.168536, -7.100831>, <-3.274329, -13.009565, -8.957289>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-8.382973, -13.209286, -8.008843>, <-6.309099, -11.850595, -8.086640>, <-3.885822, -14.168536, -7.100831>, <-3.274329, -13.009565, -8.957289>, 
      <-8.482715, -10.650410, -7.742305>, <-6.179119, -9.572331, -7.903122>, <-4.160442, -11.571096, -7.075866>, <-3.403020, -10.571713, -8.832695>, 
      <-7.595825, -7.038426, -7.052702>, <-4.932701, -4.704024, -6.268637>, <-3.354338, -9.676781, -6.937588>, <-2.155480, -7.190402, -6.603113>, 
      <-7.113664, -4.197029, -6.781667>, <-4.980691, -2.675567, -5.637408>, <-3.359994, -6.175241, -5.138515>, <-2.182303, -4.425404, -5.387962>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-7.113664, -4.197029, -6.781667>, <-4.980691, -2.675567, -5.637408>, <-3.359994, -6.175241, -5.138515>, <-2.182303, -4.425404, -5.387962>, 
      <-6.631502, -1.355631, -6.510633>, <-5.028681, -0.647110, -5.006179>, <-3.365650, -2.673701, -3.339441>, <-2.209126, -1.660406, -4.172810>, 
      <-6.631502, 0.237975, -6.230442>, <-5.028681, 0.402282, -4.821673>, <-3.365650, -1.300519, -2.226680>, <-2.209126, -0.449119, -3.524177>, 
      <-6.269422, 2.182237, -5.701125>, <-5.028681, 1.280329, -4.667293>, <-3.365650, -0.422472, -2.072300>, <-2.209126, 0.428929, -3.369797>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-6.269422, 2.182237, -5.701125>, <-5.028681, 1.280329, -4.667293>, <-3.365650, -0.422472, -2.072300>, <-2.209126, 0.428929, -3.369797>, 
      <-5.907342, 4.126500, -5.171809>, <-5.028681, 2.158377, -4.512913>, <-3.365650, 0.455575, -1.917920>, <-2.209126, 1.306976, -3.215416>, 
      <-5.778621, 5.051565, -4.619704>, <-4.771239, 3.102706, -4.179099>, <-3.365650, 1.399905, -1.751886>, <-2.423643, 2.813055, -2.297899>, 
      <-5.955425, 5.552272, -4.875629>, <-4.723978, 4.633731, -3.881373>, <-3.370041, 2.930929, -1.232714>, <-2.425838, 4.050732, -1.946494>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.955425, 5.552272, -4.875629>, <-4.723978, 4.633731, -3.881373>, <-3.370041, 2.930929, -1.232714>, <-2.425838, 4.050732, -1.946494>, 
      <-6.132229, 6.052979, -5.131553>, <-4.676717, 6.164755, -3.583647>, <-3.374432, 4.461953, -0.713542>, <-2.428033, 5.288409, -1.595090>, 
      <-6.259097, 7.080249, -4.964733>, <-4.989752, 7.637740, -3.918175>, <-3.374432, 5.406283, -0.529905>, <-2.430079, 6.522011, -2.224040>, 
      <-6.229433, 8.645904, -4.251188>, <-4.867005, 8.928363, -2.952381>, <-3.530950, 6.505861, -0.603324>, <-2.446964, 7.717112, -1.777852>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-6.229433, 8.645904, -4.251188>, <-4.867005, 8.928363, -2.952381>, <-3.530950, 6.505861, -0.603324>, <-2.446964, 7.717112, -1.777852>, 
      <-6.199768, 10.211559, -3.537642>, <-4.744257, 10.218985, -1.986588>, <-3.687467, 7.605439, -0.676742>, <-2.463849, 8.912212, -1.331665>, 
      <-5.444369, 11.626487, -3.304500>, <-4.316317, 11.634168, -1.753445>, <-3.441972, 9.256389, 1.021702>, <-2.341101, 10.202835, -0.365871>, 
      <-5.080668, 12.588702, -2.912410>, <-4.029057, 12.596382, -1.231124>, <-3.441972, 10.186685, 1.254845>, <-2.264906, 11.270312, 0.011861>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.080668, 12.588702, -2.912410>, <-4.029057, 12.596382, -1.231124>, <-3.441972, 10.186685, 1.254845>, <-2.264906, 11.270312, 0.011861>, 
      <-4.716968, 13.550916, -2.520320>, <-3.741797, 13.558597, -0.708803>, <-3.441972, 11.116980, 1.487988>, <-2.188710, 12.337788, 0.389592>, 
      <-4.716968, 14.513130, -2.248027>, <-3.741797, 14.520811, -0.436509>, <-2.958520, 12.562974, 1.721130>, <-1.946984, 13.541892, 0.642311>, 
      <-4.957567, 19.080868, -1.893626>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 13.525188, 3.076952>, <-1.855808, 18.064122, 1.538476>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.158105, -18.401592, -8.930422>, <-2.764359, -18.109363, -10.818845>, <-3.121671, -19.328952, -13.047901>, <-0.764820, -18.719157, -12.100829>, 
      <-3.174911, -17.437669, -8.976968>, <-2.768295, -17.145440, -10.870037>, <-3.151347, -18.365029, -13.089800>, <-0.781625, -17.755235, -12.147374>, 
      <-3.145638, -15.447417, -9.081884>, <-2.680075, -14.128858, -11.037971>, <-3.181022, -17.401106, -13.131699>, <-0.999802, -15.818604, -12.230402>, 
      <-3.274329, -13.009565, -8.957289>, <-2.662837, -11.850595, -10.813747>, <-3.320847, -14.567246, -12.916416>, <-1.061289, -13.262575, -12.013169>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-3.274329, -13.009565, -8.957289>, <-2.662837, -11.850595, -10.813747>, <-3.320847, -14.567246, -12.916416>, <-1.061289, -13.262575, -12.013169>, 
      <-3.403020, -10.571713, -8.832695>, <-2.645599, -9.572331, -10.589523>, <-3.460671, -11.733386, -12.701133>, <-1.122776, -10.706546, -11.795936>, 
      <-2.155480, -7.190402, -6.603113>, <-0.956621, -4.704024, -6.268637>, <-1.429625, -9.377725, -12.937360>, <0.649928, -7.094562, -9.605567>, 
      <-2.182303, -4.425404, -5.387962>, <-1.004612, -2.675567, -5.637408>, <-0.578434, -5.729744, -10.444116>, <1.051528, -4.255765, -8.046664>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.182303, -4.425404, -5.387962>, <-1.004612, -2.675567, -5.637408>, <-0.578434, -5.729744, -10.444116>, <1.051528, -4.255765, -8.046664>, 
      <-2.209126, -1.660406, -4.172810>, <-1.052602, -0.647110, -5.006179>, <0.272758, -2.081763, -7.950872>, <1.453129, -1.416968, -6.487762>, 
      <-2.209126, -0.449119, -3.524177>, <-1.052602, 0.402282, -4.821673>, <0.272758, 0.056057, -7.574996>, <1.689574, 0.229170, -6.198334>, 
      <-2.209126, 0.428929, -3.369797>, <-1.052602, 1.280329, -4.667293>, <0.272758, 0.986636, -7.411380>, <1.701579, 2.200373, -5.794322>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.209126, 0.428929, -3.369797>, <-1.052602, 1.280329, -4.667293>, <0.272758, 0.986636, -7.411380>, <1.701579, 2.200373, -5.794322>, 
      <-2.209126, 1.306976, -3.215416>, <-1.052602, 2.158377, -4.512913>, <0.272758, 1.917215, -7.247763>, <1.713583, 4.171576, -5.390310>, 
      <-2.423643, 2.813055, -2.297899>, <-1.481635, 4.226205, -2.843911>, <0.275088, 2.861544, -7.203890>, <1.714748, 5.019041, -4.976475>, 
      <-2.425838, 4.050732, -1.946494>, <-1.481635, 5.170534, -2.660275>, <0.027517, 4.367623, -6.352659>, <1.498902, 5.519134, -4.759506>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.425838, 4.050732, -1.946494>, <-1.481635, 5.170534, -2.660275>, <0.027517, 4.367623, -6.352659>, <1.498902, 5.519134, -4.759506>, 
      <-2.428033, 5.288409, -1.595090>, <-1.481635, 6.114864, -2.476639>, <-0.220053, 5.873702, -5.501429>, <1.283056, 6.019228, -4.542538>, 
      <-2.430079, 6.522011, -2.224040>, <-1.485726, 7.637740, -3.918175>, <-0.220053, 6.757739, -4.743276>, <1.249287, 7.558067, -3.598075>, 
      <-2.446964, 7.717112, -1.777852>, <-1.362978, 8.928363, -2.952381>, <-0.222099, 8.109430, -5.613654>, <1.248264, 8.699060, -3.916692>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.446964, 7.717112, -1.777852>, <-1.362978, 8.928363, -2.952381>, <-0.222099, 8.109430, -5.613654>, <1.248264, 8.699060, -3.916692>, 
      <-2.463849, 8.912212, -1.331665>, <-1.240230, 10.218985, -1.986588>, <-0.224144, 9.461121, -6.484031>, <1.247241, 9.840053, -4.235309>, 
      <-2.341101, 10.202835, -0.365871>, <-1.240230, 11.149281, -1.753445>, <0.012093, 11.595682, -4.785587>, <1.365360, 11.372481, -3.269516>, 
      <-2.264906, 11.270312, 0.011861>, <-1.087840, 12.353939, -1.231124>, <0.006047, 12.557896, -4.517854>, <1.182680, 12.455917, -2.874489>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.264906, 11.270312, 0.011861>, <-1.087840, 12.353939, -1.231124>, <0.006047, 12.557896, -4.517854>, <1.182680, 12.455917, -2.874489>, 
      <-2.188710, 12.337788, 0.389592>, <-0.935449, 13.558597, -0.708803>, <0.000000, 13.520110, -4.250121>, <1.000000, 13.539354, -2.479462>, 
      <-1.946984, 13.541892, 0.642311>, <-0.935449, 14.520811, -0.436509>, <0.000000, 14.482325, -3.977828>, <1.000000, 14.501568, -2.207169>, 
      <-1.855808, 18.064122, 1.538476>, <-1.143599, 22.603056, 0.000000>, <0.000000, 15.444539, -3.705534>, <0.888743, 19.023797, -1.852767>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-0.764820, -18.719157, -12.100829>, <1.592032, -18.109363, -11.153756>, <3.243071, -18.725622, -9.095890>, <4.639344, -18.423852, -10.351918>, 
      <-0.781625, -17.755235, -12.147374>, <1.588097, -17.145440, -11.204948>, <3.239135, -17.761699, -9.147082>, <4.635409, -17.459929, -10.403111>, 
      <-0.999802, -15.818604, -12.230402>, <1.181419, -14.236101, -11.329106>, <3.235200, -16.797776, -9.198275>, <4.677551, -15.469677, -10.512674>, 
      <-1.061289, -13.262575, -12.013169>, <1.198269, -11.957903, -11.109922>, <2.739315, -14.253957, -9.296048>, <4.438225, -13.053008, -10.449483>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.061289, -13.262575, -12.013169>, <1.198269, -11.957903, -11.109922>, <2.739315, -14.253957, -9.296048>, <4.438225, -13.053008, -10.449483>, 
      <-1.122776, -10.706546, -11.795936>, <1.215120, -9.679706, -10.890738>, <2.243429, -11.710139, -9.393821>, <4.198898, -10.636338, -10.386291>, 
      <0.649928, -7.094562, -9.605567>, <2.729480, -4.811399, -6.273774>, <2.863190, -9.759672, -8.871491>, <5.158005, -7.226951, -8.900004>, 
      <1.051528, -4.255765, -8.046664>, <2.681490, -2.781786, -5.649213>, <3.456753, -6.258132, -6.272104>, <5.509607, -4.455596, -7.283990>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.051528, -4.255765, -8.046664>, <2.681490, -2.781786, -5.649213>, <3.456753, -6.258132, -6.272104>, <5.509607, -4.455596, -7.283990>, 
      <1.453129, -1.416968, -6.487762>, <2.633500, -0.752173, -5.024652>, <4.050316, -2.756592, -3.672717>, <5.861208, -1.684241, -5.667976>, 
      <1.689574, 0.229170, -6.198334>, <3.106391, 0.402282, -4.821673>, <4.050316, -1.317532, -2.566228>, <5.861208, -0.440015, -5.022478>, 
      <1.701579, 2.200373, -5.794322>, <3.130400, 3.414109, -4.177265>, <4.286762, -0.386953, -2.402611>, <5.979431, 0.464298, -4.863479>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.701579, 2.200373, -5.794322>, <3.130400, 3.414109, -4.177265>, <4.286762, -0.386953, -2.402611>, <5.979431, 0.464298, -4.863479>, 
      <1.713583, 4.171576, -5.390310>, <3.154409, 6.425937, -3.532857>, <4.523207, 0.543626, -2.238995>, <6.097654, 1.368611, -4.704481>, 
      <1.714748, 5.019041, -4.976475>, <3.154409, 7.176537, -2.749060>, <4.523207, 1.487955, -2.072961>, <5.920786, 2.312941, -4.461365>, 
      <1.498902, 5.519134, -4.759506>, <2.970287, 6.670646, -3.166354>, <4.329005, 3.018980, -1.570808>, <5.777136, 3.843965, -3.429270>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.498902, 5.519134, -4.759506>, <2.970287, 6.670646, -3.166354>, <4.329005, 3.018980, -1.570808>, <5.777136, 3.843965, -3.429270>, 
      <1.283056, 6.019228, -4.542538>, <2.786166, 6.164755, -3.583647>, <4.134803, 4.550004, -1.068656>, <5.633486, 5.374990, -2.397174>, 
      <1.249287, 7.558067, -3.598075>, <2.718626, 8.358394, -2.452873>, <4.134803, 5.494333, -0.885020>, <5.599716, 6.948722, -1.738914>, 
      <1.248264, 8.699060, -3.916692>, <2.718626, 9.288690, -2.219731>, <4.101034, 6.966108, -0.223148>, <5.507808, 8.149756, -1.291407>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.248264, 8.699060, -3.916692>, <2.718626, 9.288690, -2.219731>, <4.101034, 6.966108, -0.223148>, <5.507808, 8.149756, -1.291407>, 
      <1.247241, 9.840053, -4.235309>, <2.718626, 10.218985, -1.986588>, <4.067264, 8.437882, 0.438723>, <5.415901, 9.350791, -0.843900>, 
      <1.365360, 11.372481, -3.269516>, <2.718626, 11.149281, -1.753445>, <4.067264, 9.368177, 0.671866>, <4.931612, 10.524298, -0.610757>, 
      <1.182680, 12.455917, -2.874489>, <2.359313, 12.353939, -1.231124>, <4.067264, 10.298473, 0.905008>, <4.732622, 11.470552, -0.238900>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.182680, 12.455917, -2.874489>, <2.359313, 12.353939, -1.231124>, <4.067264, 10.298473, 0.905008>, <4.732622, 11.470552, -0.238900>, 
      <1.000000, 13.539354, -2.479462>, <2.000000, 13.558597, -0.708803>, <4.067264, 11.228768, 1.138151>, <4.533632, 12.416807, 0.132957>, 
      <1.000000, 14.501568, -2.207169>, <2.000000, 14.520811, -0.436509>, <3.482413, 12.678597, 1.371294>, <4.241207, 13.622829, 0.385675>, 
      <0.888743, 19.023797, -1.852767>, <1.777487, 22.603056, 0.000000>, <3.000000, 13.640811, 2.668369>, <4.516881, 18.057206, 1.249259>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.639344, -18.423852, -10.351918>, <6.035617, -18.122083, -11.607946>, <6.581710, -19.286961, -10.530558>, <8.832609, -18.851698, -9.839720>, 
      <4.635409, -17.459929, -10.403111>, <6.031682, -17.158160, -11.659139>, <7.334703, -18.396830, -14.128153>, <9.207138, -17.924671, -11.664114>, 
      <4.677551, -15.469677, -10.512674>, <6.119902, -14.141579, -11.827073>, <7.330768, -17.432907, -14.179345>, <9.203202, -16.960748, -11.715306>, 
      <4.438225, -13.053008, -10.449483>, <6.137135, -11.852058, -11.602917>, <7.100195, -14.570905, -14.066646>, <9.118531, -14.012721, -11.589595>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.438225, -13.053008, -10.449483>, <6.137135, -11.852058, -11.602917>, <7.100195, -14.570905, -14.066646>, <9.118531, -14.012721, -11.589595>, 
      <4.198898, -10.636338, -10.386291>, <6.154367, -9.562538, -11.378762>, <6.869622, -11.708903, -13.953948>, <9.033859, -11.064693, -11.463884>, 
      <5.158005, -7.226951, -8.900004>, <7.452821, -4.694231, -8.928518>, <7.453217, -9.353242, -13.902042>, <9.327172, -9.404310, -11.418225>, 
      <5.509607, -4.455596, -7.283990>, <7.562460, -2.653060, -8.295876>, <8.113436, -5.673477, -12.351307>, <9.849065, -5.813657, -9.791296>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.509607, -4.455596, -7.283990>, <7.562460, -2.653060, -8.295876>, <8.113436, -5.673477, -12.351307>, <9.849065, -5.813657, -9.791296>, 
      <5.861208, -1.684241, -5.667976>, <7.672100, -0.611890, -7.663234>, <8.773656, -1.993712, -10.800572>, <10.370959, -2.223005, -8.164368>, 
      <5.861208, -0.440015, -5.022478>, <7.672100, 0.437502, -7.478728>, <9.088917, 0.144108, -10.424696>, <10.528589, -0.501934, -7.408312>, 
      <5.979431, 0.464298, -4.863479>, <7.672100, 1.315550, -7.324348>, <9.088917, 1.074687, -10.261080>, <10.528589, 0.402379, -7.249314>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.979431, 0.464298, -4.863479>, <7.672100, 1.315550, -7.324348>, <9.088917, 1.074687, -10.261080>, <10.528589, 0.402379, -7.249314>, 
      <6.097654, 1.368611, -4.704481>, <7.672100, 2.193597, -7.169968>, <9.088917, 2.005265, -10.097463>, <10.528589, 1.306692, -7.090316>, 
      <5.920786, 2.312941, -4.461365>, <7.318364, 3.137926, -6.849770>, <8.667002, 2.949595, -10.087629>, <10.317632, 2.251021, -7.002382>, 
      <5.777136, 3.843965, -3.429270>, <7.225266, 4.668951, -5.287731>, <8.573904, 4.480619, -8.525590>, <10.084415, 3.782046, -5.319989>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.777136, 3.843965, -3.429270>, <7.225266, 4.668951, -5.287731>, <8.573904, 4.480619, -8.525590>, <10.084415, 3.782046, -5.319989>, 
      <5.633486, 5.374990, -2.397174>, <7.132168, 6.199975, -3.725693>, <8.480805, 6.011644, -6.963551>, <9.851199, 5.313070, -3.637596>, 
      <5.599716, 6.948722, -1.738914>, <7.064628, 8.403110, -2.592808>, <8.480805, 6.993815, -6.195521>, <9.851199, 6.276320, -3.161763>, 
      <5.507808, 8.149756, -1.291407>, <6.914583, 9.333405, -2.359665>, <8.296991, 8.643689, -5.782044>, <9.742407, 7.824382, -2.623574>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.507808, 8.149756, -1.291407>, <6.914583, 9.333405, -2.359665>, <8.296991, 8.643689, -5.782044>, <9.742407, 7.824382, -2.623574>, 
      <5.415901, 9.350791, -0.843900>, <6.764539, 10.263701, -2.126523>, <8.113176, 10.293564, -5.368566>, <9.633614, 9.372444, -2.085385>, 
      <4.931612, 10.524298, -0.610757>, <5.795960, 11.680418, -1.893380>, <6.952734, 11.711305, -5.135424>, <9.053393, 10.546462, -1.852243>, 
      <4.732622, 11.470552, -0.238900>, <5.397980, 12.642632, -1.382808>, <6.476367, 13.430984, -4.478540>, <8.152589, 12.932990, -0.862427>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.732622, 11.470552, -0.238900>, <5.397980, 12.642632, -1.382808>, <6.476367, 13.430984, -4.478540>, <8.152589, 12.932990, -0.862427>, 
      <4.533632, 12.416807, 0.132957>, <5.000000, 13.604846, -0.872236>, <6.000000, 15.150663, -3.821656>, <7.251785, 15.319517, 0.127389>, 
      <4.241207, 13.622829, 0.385675>, <5.000000, 14.567060, -0.599943>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, 0.127389>, 
      <4.516881, 18.057206, 1.249259>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, 0.127389>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.832609, -18.851698, -9.839720>, <11.083508, -18.416435, -9.148882>, <11.980473, -18.109363, -11.952398>, <12.899991, -19.000756, -11.910764>, 
      <9.207138, -17.924671, -11.664114>, <11.079572, -17.452512, -9.200075>, <11.976538, -17.145440, -12.003590>, <13.464542, -18.110625, -12.066423>, 
      <9.203202, -16.960748, -11.715306>, <11.075637, -16.488589, -9.251267>, <12.064758, -14.128858, -12.171524>, <13.460606, -17.146703, -12.117615>, 
      <9.118531, -14.012721, -11.589595>, <11.136867, -13.454537, -9.112544>, <12.081996, -11.850595, -11.947300>, <13.212170, -14.549263, -12.237276>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.118531, -14.012721, -11.589595>, <11.136867, -13.454537, -9.112544>, <12.081996, -11.850595, -11.947300>, <13.212170, -14.549263, -12.237276>, 
      <9.033859, -11.064693, -11.463884>, <11.198097, -10.420484, -8.973821>, <12.099234, -9.572331, -11.723076>, <12.963733, -11.951823, -12.356937>, 
      <9.327172, -9.404310, -11.418225>, <11.201127, -9.455377, -8.934407>, <12.804826, -5.133523, -8.817808>, <13.583293, -9.573595, -11.837219>, 
      <9.849065, -5.813657, -9.791296>, <11.584694, -5.953838, -7.231286>, <12.756835, -3.697188, -8.318172>, <13.854477, -6.286805, -10.276483>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.849065, -5.813657, -9.791296>, <11.584694, -5.953838, -7.231286>, <12.756835, -3.697188, -8.318172>, <13.854477, -6.286805, -10.276483>, 
      <10.370959, -2.223005, -8.164368>, <11.968261, -2.452298, -5.528164>, <12.708845, -2.260853, -7.818536>, <14.125661, -3.000014, -8.715747>, 
      <10.528589, -0.501934, -7.408312>, <11.968261, -1.147976, -4.391929>, <12.708845, -0.017970, -7.424187>, <14.125661, -2.262090, -7.818753>, 
      <10.528589, 0.402379, -7.249314>, <11.968261, -0.269929, -4.237549>, <12.708845, 0.860078, -7.269807>, <14.125661, -0.734765, -7.550216>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.528589, 0.402379, -7.249314>, <11.968261, -0.269929, -4.237549>, <12.708845, 0.860078, -7.269807>, <14.125661, -0.734765, -7.550216>, 
      <10.528589, 1.306692, -7.090316>, <11.968261, 0.608118, -4.083168>, <12.708845, 1.738125, -7.115427>, <14.125661, 0.792559, -7.281679>, 
      <10.317632, 2.251021, -7.002382>, <11.968261, 1.552448, -3.917134>, <12.708845, 2.682454, -6.949393>, <14.125661, 1.736888, -7.115645>, 
      <10.084415, 3.782046, -5.319989>, <11.594927, 3.083472, -2.114388>, <12.317691, 4.213479, -5.307382>, <13.990475, 3.267912, -5.482446>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.084415, 3.782046, -5.319989>, <11.594927, 3.083472, -2.114388>, <12.317691, 4.213479, -5.307382>, <13.990475, 3.267912, -5.482446>, 
      <9.851199, 5.313070, -3.637596>, <11.221592, 4.614496, -0.311641>, <11.926538, 5.744503, -3.665370>, <13.855290, 4.798937, -3.849247>, 
      <9.851199, 6.276320, -3.161763>, <11.221592, 5.558826, -0.128005>, <11.858998, 7.944388, -2.556628>, <13.855290, 5.663086, -3.665610>, 
      <9.742407, 7.824382, -2.623574>, <11.187823, 7.005075, 0.534895>, <11.858998, 8.874684, -2.323485>, <13.531463, 7.268276, -2.994701>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.742407, 7.824382, -2.623574>, <11.187823, 7.005075, 0.534895>, <11.858998, 8.874684, -2.323485>, <13.531463, 7.268276, -2.994701>, 
      <9.633614, 9.372444, -2.085385>, <11.154053, 8.451324, 1.197796>, <11.858998, 9.804979, -2.090343>, <13.207636, 8.873465, -2.323791>, 
      <9.053393, 10.546462, -1.852243>, <11.154053, 9.381619, 1.430938>, <12.107791, 11.149928, -1.857200>, <13.456428, 10.052553, -2.090648>, 
      <8.152589, 12.932990, -0.862427>, <9.828811, 12.434995, 2.753686>, <11.175875, 12.146936, -1.283001>, <12.488753, 12.411708, -1.263400>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.152589, 12.932990, -0.862427>, <9.828811, 12.434995, 2.753686>, <11.175875, 12.146936, -1.283001>, <12.488753, 12.411708, -1.263400>, 
      <7.251785, 15.319517, 0.127389>, <8.503569, 15.488371, 4.076433>, <10.243960, 13.143943, -0.708803>, <11.521079, 14.770864, -0.436153>, 
      <7.127389, 16.278052, 0.127389>, <8.254777, 16.405440, 4.076433>, <9.248792, 14.603742, -0.436509>, <11.907406, 15.050089, -0.709159>, 
      <7.127389, 17.278052, 0.127389>, <8.254777, 17.405440, 4.076433>, <10.797790, 24.684825, 0.000000>, <11.409822, 14.768343, -0.436866>
    }
  }
  texture {
                    textex scale <1,10,3>
                  }
                  translate  <11.18, -20.280892, 0.0>
                  scale <1,.45*ycm/100,zplis/2>
  //translate  <0.185073, -20.280892, 0.0>
//  translate  <0.185073, -20.280892, 0.0>
}

#declare RideauVolant4g = union { // BezPtch001
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.730183, -18.109363, -12.866297>, <-7.619168, -19.532475, -18.428550>, <-11.404309, -18.662021, -9.864362>, <-9.952130, -18.385692, -11.087677>, 
      <-13.724762, -17.145440, -12.917353>, <-12.425787, -18.568553, -16.791294>, <-11.398888, -17.698098, -9.915418>, <-9.946709, -17.421769, -11.138734>, 
      <-13.607529, -14.128858, -13.066487>, <-12.420366, -17.604630, -16.842351>, <-11.393467, -16.734175, -9.966474>, <-10.411885, -15.406076, -11.068975>, 
      <-13.554250, -11.850595, -12.834680>, <-12.383137, -13.895383, -16.715470>, <-12.142564, -14.111295, -9.959384>, <-10.798320, -12.978018, -10.953479>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.554250, -11.850595, -12.834680>, <-12.383137, -13.895383, -16.715470>, <-12.142564, -14.111295, -9.959384>, <-10.798320, -12.978018, -10.953479>, 
      <-13.500971, -9.572331, -12.602874>, <-12.345909, -10.186136, -16.588590>, <-12.891660, -11.488414, -9.952294>, <-11.184754, -10.549960, -10.837982>, 
      <-12.489570, -4.704024, -14.092175>, <-12.196038, -9.221030, -16.532925>, <-12.378189, -9.740438, -9.314870>, <-10.809914, -7.241818, -10.595692>, 
      <-13.250430, -2.675567, -9.549177>, <-12.683547, -5.369634, -13.269338>, <-12.498131, -6.238899, -5.900574>, <-10.847529, -4.467027, -7.170961>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.250430, -2.675567, -9.549177>, <-12.683547, -5.369634, -13.269338>, <-12.498131, -6.238899, -5.900574>, <-10.847529, -4.467027, -7.170961>, 
      <-14.011289, -0.647110, -5.006179>, <-13.171056, -1.518239, -10.005751>, <-12.618073, -2.737359, -2.486279>, <-10.885144, -1.692235, -3.746229>, 
      <-14.011289, 0.402282, -4.821673>, <-13.171056, 0.619581, -9.629875>, <-11.655480, -1.388570, -1.905605>, <-10.403848, -0.493144, -3.363639>, 
      <-14.011289, 1.280329, -4.667293>, <-12.846424, 1.550160, -9.645066>, <-11.655480, -0.510523, -1.751225>, <-10.135995, 1.424853, -2.764754>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.011289, 1.280329, -4.667293>, <-12.846424, 1.550160, -9.645066>, <-11.655480, -0.510523, -1.751225>, <-10.135995, 1.424853, -2.764754>, 
      <-14.011289, 2.158377, -4.512913>, <-12.521793, 2.480739, -9.660257>, <-11.655480, 0.367525, -1.596845>, <-9.868141, 3.342850, -2.165868>, 
      <-13.901707, 3.263066, -4.179099>, <-12.521793, 3.425068, -9.476620>, <-11.655480, 1.311854, -1.430811>, <-9.868141, 4.163565, -1.694505>, 
      <-14.091491, 4.713910, -3.881373>, <-12.614891, 5.046121, -8.897201>, <-11.460412, 2.842879, -0.894619>, <-9.971042, 4.716447, -1.832771>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-14.091491, 4.713910, -3.881373>, <-12.614891, 5.046121, -8.897201>, <-11.460412, 2.842879, -0.894619>, <-9.971042, 4.716447, -1.832771>, 
      <-14.281275, 6.164755, -3.583647>, <-12.707989, 6.667175, -8.317782>, <-11.265345, 4.373903, -0.358428>, <-10.073943, 5.269329, -1.971037>, 
      <-13.575329, 8.358394, -2.452873>, <-12.707989, 7.597470, -8.084639>, <-11.265345, 5.318232, -0.174791>, <-10.107712, 6.838313, -1.313832>, 
      <-13.575329, 9.288690, -2.219731>, <-11.098368, 9.485464, -7.883288>, <-11.299115, 6.766269, 0.481803>, <-10.124597, 8.027480, -0.868964>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-13.575329, 9.288690, -2.219731>, <-11.098368, 9.485464, -7.883288>, <-11.299115, 6.766269, 0.481803>, <-10.124597, 8.027480, -0.868964>, 
      <-13.575329, 10.218985, -1.986588>, <-9.488748, 11.373458, -7.681936>, <-11.332884, 8.214306, 1.138396>, <-10.141482, 9.216646, -0.424096>, 
      <-12.894214, 12.048822, -1.753445>, <-9.488748, 12.335673, -7.409643>, <-11.332884, 9.144601, 1.371539>, <-9.507950, 10.389385, -0.190953>, 
      <-12.535209, 13.384224, -1.231124>, <-9.540785, 13.297887, -7.137349>, <-11.332884, 10.074897, 1.604682>, <-9.250251, 11.335640, 0.186779>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-12.535209, 13.384224, -1.231124>, <-9.540785, 13.297887, -7.137349>, <-11.332884, 10.074897, 1.604682>, <-9.250251, 11.335640, 0.186779>, 
      <-12.176203, 14.719626, -0.708803>, <-9.592823, 14.260101, -6.865056>, <-11.332884, 11.005192, 1.837824>, <-8.992552, 12.281894, 0.564511>, 
      <-12.436711, 15.930633, -7.541632>, <-10.173338, 15.990918, -6.114650>, <-8.419043, 16.156779, 4.076433>, <-7.535631, 15.338795, 1.819962>, 
      <-10.394016, 19.753449, 0.000000>, <-9.509892, 17.322641, -6.114650>, <-8.419043, 17.156779, 4.076433>, <-7.958262, 19.550482, 2.038217>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.952130, -18.385692, -11.087677>, <-8.499950, -18.109363, -12.310993>, <-6.841401, -19.335312, -14.397171>, <-5.516784, -18.722338, -13.125399>, 
      <-9.946709, -17.421769, -11.138734>, <-8.494530, -17.145440, -12.362049>, <-6.835980, -18.371389, -14.448227>, <-5.511363, -17.758415, -13.176455>, 
      <-10.411885, -15.406076, -11.068975>, <-9.430303, -14.077978, -12.171477>, <-6.830559, -17.407467, -14.499284>, <-5.450036, -15.768163, -13.276551>, 
      <-10.798320, -12.978018, -10.953479>, <-9.454075, -11.844741, -11.947573>, <-7.308837, -14.567978, -14.454699>, <-5.701046, -13.209286, -13.142444>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.798320, -12.978018, -10.953479>, <-9.454075, -11.844741, -11.947573>, <-7.308837, -14.567978, -14.454699>, <-5.701046, -13.209286, -13.142444>, 
      <-11.184754, -10.549960, -10.837982>, <-9.477847, -9.611505, -11.723670>, <-7.787115, -11.728489, -14.410114>, <-5.952057, -10.650410, -13.008337>, 
      <-10.809914, -7.241818, -10.595692>, <-9.241639, -4.743198, -11.876515>, <-7.222632, -9.372829, -14.253154>, <-5.841127, -7.038426, -12.159758>, 
      <-10.847529, -4.467027, -7.170961>, <-9.196927, -2.695154, -8.441347>, <-7.728478, -5.718491, -11.134120>, <-6.236315, -4.197029, -9.335196>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.847529, -4.467027, -7.170961>, <-9.196927, -2.695154, -8.441347>, <-7.728478, -5.718491, -11.134120>, <-6.236315, -4.197029, -9.335196>, 
      <-10.885144, -1.692235, -3.746229>, <-9.152216, -0.647110, -5.006179>, <-8.234323, -2.064152, -8.015087>, <-6.631502, -1.355631, -6.510633>, 
      <-10.403848, -0.493144, -3.363639>, <-9.152216, 0.402282, -4.821673>, <-8.234323, 0.073667, -7.639211>, <-6.631502, 0.237975, -6.230442>, 
      <-10.135995, 1.424853, -2.764754>, <-8.616509, 3.360228, -3.778282>, <-7.510163, 3.084145, -6.734958>, <-6.269422, 2.182237, -5.701125>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.135995, 1.424853, -2.764754>, <-8.616509, 3.360228, -3.778282>, <-7.510163, 3.084145, -6.734958>, <-6.269422, 2.182237, -5.701125>, 
      <-9.868141, 3.342850, -2.165868>, <-8.080803, 6.318175, -2.734892>, <-6.786002, 6.094623, -5.830705>, <-5.907342, 4.126500, -5.171809>, 
      <-9.868141, 4.163565, -1.694505>, <-8.080803, 7.015275, -1.958200>, <-6.786002, 7.000423, -5.060309>, <-5.778621, 5.051565, -4.619704>, 
      <-9.971042, 4.716447, -1.832771>, <-8.481672, 6.590015, -2.770923>, <-7.186871, 6.470813, -5.869884>, <-5.955425, 5.552272, -4.875629>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.971042, 4.716447, -1.832771>, <-8.481672, 6.590015, -2.770923>, <-7.186871, 6.470813, -5.869884>, <-5.955425, 5.552272, -4.875629>, 
      <-10.073943, 5.269329, -1.971037>, <-8.882541, 6.164755, -3.583647>, <-7.587740, 5.941203, -6.679460>, <-6.132229, 6.052979, -5.131553>, 
      <-10.107712, 6.838313, -1.313832>, <-8.950080, 8.358394, -2.452873>, <-7.528441, 6.522758, -6.011292>, <-6.259097, 7.080249, -4.964733>, 
      <-10.124597, 8.027480, -0.868964>, <-8.950080, 9.288690, -2.219731>, <-7.591860, 8.363446, -5.549994>, <-6.229433, 8.645904, -4.251188>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-10.124597, 8.027480, -0.868964>, <-8.950080, 9.288690, -2.219731>, <-7.591860, 8.363446, -5.549994>, <-6.229433, 8.645904, -4.251188>, 
      <-10.141482, 9.216646, -0.424096>, <-8.950080, 10.218985, -1.986588>, <-7.655280, 10.204133, -5.088697>, <-6.199768, 10.211559, -3.537642>, 
      <-9.507950, 10.389385, -0.190953>, <-7.683017, 11.634168, -1.753445>, <-6.572421, 11.618807, -4.855554>, <-5.444369, 11.626487, -3.304500>, 
      <-9.250251, 11.335640, 0.186779>, <-7.167618, 12.596382, -1.231124>, <-6.132280, 12.581021, -4.593696>, <-5.080668, 12.588702, -2.912410>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-9.250251, 11.335640, 0.186779>, <-7.167618, 12.596382, -1.231124>, <-6.132280, 12.581021, -4.593696>, <-5.080668, 12.588702, -2.912410>, 
      <-8.992552, 12.281894, 0.564511>, <-6.652219, 13.558597, -0.708803>, <-5.692139, 13.543235, -4.331838>, <-4.716968, 13.550916, -2.520320>, 
      <-7.535631, 15.338795, 1.819962>, <-6.652219, 14.520811, -0.436509>, <-5.692139, 14.505449, -4.059545>, <-4.716968, 14.513130, -2.248027>, 
      <-7.958262, 19.550482, 2.038217>, <-7.497482, 21.944184, 0.000000>, <-5.692139, 15.467664, -3.787251>, <-4.957567, 19.080868, -1.893626>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.516784, -18.722338, -13.125399>, <-4.192167, -18.109363, -11.853627>, <-2.714443, -18.693821, -9.223934>, <-1.376435, -18.401592, -10.318275>, 
      <-5.511363, -17.758415, -13.176455>, <-4.186746, -17.145440, -11.904683>, <-2.709022, -17.729898, -9.274990>, <-1.371014, -17.437669, -10.369331>, 
      <-5.450036, -15.768163, -13.276551>, <-4.069512, -14.128858, -12.053817>, <-2.703601, -16.765975, -9.326046>, <-1.309687, -15.447417, -10.469426>, 
      <-5.701046, -13.209286, -13.142444>, <-4.093255, -11.850595, -11.830188>, <-2.926194, -14.168536, -9.488809>, <-1.432855, -13.009565, -10.438993>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.701046, -13.209286, -13.142444>, <-4.093255, -11.850595, -11.830188>, <-2.926194, -14.168536, -9.488809>, <-1.432855, -13.009565, -10.438993>, 
      <-5.952057, -10.650410, -13.008337>, <-4.116999, -9.572331, -11.606559>, <-3.148787, -11.571096, -9.651572>, <-1.556023, -10.571713, -10.408560>, 
      <-5.841127, -7.038426, -12.159758>, <-4.459621, -4.704024, -10.066362>, <-2.635222, -9.676781, -9.015039>, <-1.770225, -7.190402, -8.649704>, 
      <-6.236315, -4.197029, -9.335196>, <-4.744151, -2.675567, -7.536271>, <-3.000436, -6.175241, -6.177240>, <-1.989676, -4.425404, -6.411257>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-6.236315, -4.197029, -9.335196>, <-4.744151, -2.675567, -7.536271>, <-3.000436, -6.175241, -6.177240>, <-1.989676, -4.425404, -6.411257>, 
      <-6.631502, -1.355631, -6.510633>, <-5.028681, -0.647110, -5.006179>, <-3.365650, -2.673701, -3.339441>, <-2.209126, -1.660406, -4.172810>, 
      <-6.631502, 0.237975, -6.230442>, <-5.028681, 0.402282, -4.821673>, <-3.365650, -1.300519, -2.226680>, <-2.209126, -0.449119, -3.524177>, 
      <-6.269422, 2.182237, -5.701125>, <-5.028681, 1.280329, -4.667293>, <-3.365650, -0.422472, -2.072300>, <-2.209126, 0.428929, -3.369797>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-6.269422, 2.182237, -5.701125>, <-5.028681, 1.280329, -4.667293>, <-3.365650, -0.422472, -2.072300>, <-2.209126, 0.428929, -3.369797>, 
      <-5.907342, 4.126500, -5.171809>, <-5.028681, 2.158377, -4.512913>, <-3.365650, 0.455575, -1.917920>, <-2.209126, 1.306976, -3.215416>, 
      <-5.778621, 5.051565, -4.619704>, <-4.771239, 3.102706, -4.179099>, <-3.365650, 1.399905, -1.751886>, <-2.423643, 2.813055, -2.297899>, 
      <-5.955425, 5.552272, -4.875629>, <-4.723978, 4.633731, -3.881373>, <-3.370041, 2.930929, -1.232714>, <-2.425838, 4.050732, -1.946494>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.955425, 5.552272, -4.875629>, <-4.723978, 4.633731, -3.881373>, <-3.370041, 2.930929, -1.232714>, <-2.425838, 4.050732, -1.946494>, 
      <-6.132229, 6.052979, -5.131553>, <-4.676717, 6.164755, -3.583647>, <-3.374432, 4.461953, -0.713542>, <-2.428033, 5.288409, -1.595090>, 
      <-6.259097, 7.080249, -4.964733>, <-4.989752, 7.637740, -3.918175>, <-3.374432, 5.406283, -0.529905>, <-2.430079, 6.522011, -2.224040>, 
      <-6.229433, 8.645904, -4.251188>, <-4.867005, 8.928363, -2.952381>, <-3.530950, 6.505861, -0.603324>, <-2.446964, 7.717112, -1.777852>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-6.229433, 8.645904, -4.251188>, <-4.867005, 8.928363, -2.952381>, <-3.530950, 6.505861, -0.603324>, <-2.446964, 7.717112, -1.777852>, 
      <-6.199768, 10.211559, -3.537642>, <-4.744257, 10.218985, -1.986588>, <-3.687467, 7.605439, -0.676742>, <-2.463849, 8.912212, -1.331665>, 
      <-5.444369, 11.626487, -3.304500>, <-4.316317, 11.634168, -1.753445>, <-3.441972, 9.256389, 1.021702>, <-2.341101, 10.202835, -0.365871>, 
      <-5.080668, 12.588702, -2.912410>, <-4.029057, 12.596382, -1.231124>, <-3.441972, 10.186685, 1.254845>, <-2.264906, 11.270312, 0.011861>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-5.080668, 12.588702, -2.912410>, <-4.029057, 12.596382, -1.231124>, <-3.441972, 10.186685, 1.254845>, <-2.264906, 11.270312, 0.011861>, 
      <-4.716968, 13.550916, -2.520320>, <-3.741797, 13.558597, -0.708803>, <-3.441972, 11.116980, 1.487988>, <-2.188710, 12.337788, 0.389592>, 
      <-4.716968, 14.513130, -2.248027>, <-3.741797, 14.520811, -0.436509>, <-2.958520, 12.562974, 1.721130>, <-1.946984, 13.541892, 0.642311>, 
      <-4.957567, 19.080868, -1.893626>, <-4.222995, 22.694072, 0.000000>, <-2.568017, 13.525188, 3.076952>, <-1.855808, 18.064122, 1.538476>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.376435, -18.401592, -10.318275>, <-0.038427, -18.109363, -11.412617>, <1.428514, -19.328952, -10.151353>, <2.267557, -18.719157, -8.503830>, 
      <-1.371014, -17.437669, -10.369331>, <-0.033006, -17.145440, -11.463673>, <1.451524, -18.365029, -10.197251>, <2.290568, -17.755235, -8.549728>, 
      <-1.309687, -15.447417, -10.469426>, <0.084228, -14.128858, -11.612807>, <1.474535, -17.401106, -10.243149>, <2.159814, -15.818604, -8.730674>, 
      <-1.432855, -13.009565, -10.438993>, <0.060485, -11.850595, -11.389178>, <1.218783, -14.567246, -10.265249>, <1.982677, -13.262575, -8.643466>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.432855, -13.009565, -10.438993>, <0.060485, -11.850595, -11.389178>, <1.218783, -14.567246, -10.265249>, <1.982677, -13.262575, -8.643466>, 
      <-1.556023, -10.571713, -10.408560>, <0.036741, -9.572331, -11.165549>, <0.963031, -11.733386, -10.287350>, <1.805539, -10.706546, -8.556258>, 
      <-1.770225, -7.190402, -8.649704>, <-0.905229, -4.704024, -8.284369>, <1.436398, -9.377725, -9.942095>, <1.914320, -7.094562, -8.289512>, 
      <-1.989676, -4.425404, -6.411257>, <-0.978916, -2.675567, -6.645274>, <0.854578, -5.729744, -8.946483>, <1.683724, -4.255765, -7.388637>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-1.989676, -4.425404, -6.411257>, <-0.978916, -2.675567, -6.645274>, <0.854578, -5.729744, -8.946483>, <1.683724, -4.255765, -7.388637>, 
      <-2.209126, -1.660406, -4.172810>, <-1.052602, -0.647110, -5.006179>, <0.272758, -2.081763, -7.950872>, <1.453129, -1.416968, -6.487762>, 
      <-2.209126, -0.449119, -3.524177>, <-1.052602, 0.402282, -4.821673>, <0.272758, 0.056057, -7.574996>, <1.689574, 0.229170, -6.198334>, 
      <-2.209126, 0.428929, -3.369797>, <-1.052602, 1.280329, -4.667293>, <0.272758, 0.986636, -7.411380>, <1.701579, 2.200373, -5.794322>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.209126, 0.428929, -3.369797>, <-1.052602, 1.280329, -4.667293>, <0.272758, 0.986636, -7.411380>, <1.701579, 2.200373, -5.794322>, 
      <-2.209126, 1.306976, -3.215416>, <-1.052602, 2.158377, -4.512913>, <0.272758, 1.917215, -7.247763>, <1.713583, 4.171576, -5.390310>, 
      <-2.423643, 2.813055, -2.297899>, <-1.481635, 4.226205, -2.843911>, <0.275088, 2.861544, -7.203890>, <1.714748, 5.019041, -4.976475>, 
      <-2.425838, 4.050732, -1.946494>, <-1.481635, 5.170534, -2.660275>, <0.027517, 4.367623, -6.352659>, <1.498902, 5.519134, -4.759506>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.425838, 4.050732, -1.946494>, <-1.481635, 5.170534, -2.660275>, <0.027517, 4.367623, -6.352659>, <1.498902, 5.519134, -4.759506>, 
      <-2.428033, 5.288409, -1.595090>, <-1.481635, 6.114864, -2.476639>, <-0.220053, 5.873702, -5.501429>, <1.283056, 6.019228, -4.542538>, 
      <-2.430079, 6.522011, -2.224040>, <-1.485726, 7.637740, -3.918175>, <-0.220053, 6.757739, -4.743276>, <1.249287, 7.558067, -3.598075>, 
      <-2.446964, 7.717112, -1.777852>, <-1.362978, 8.928363, -2.952381>, <-0.222099, 8.109430, -5.613654>, <1.248264, 8.699060, -3.916692>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.446964, 7.717112, -1.777852>, <-1.362978, 8.928363, -2.952381>, <-0.222099, 8.109430, -5.613654>, <1.248264, 8.699060, -3.916692>, 
      <-2.463849, 8.912212, -1.331665>, <-1.240230, 10.218985, -1.986588>, <-0.224144, 9.461121, -6.484031>, <1.247241, 9.840053, -4.235309>, 
      <-2.341101, 10.202835, -0.365871>, <-1.240230, 11.149281, -1.753445>, <0.012093, 11.595682, -4.785587>, <1.365360, 11.372481, -3.269516>, 
      <-2.264906, 11.270312, 0.011861>, <-1.087840, 12.353939, -1.231124>, <0.006047, 12.557896, -4.517854>, <1.182680, 12.455917, -2.874489>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <-2.264906, 11.270312, 0.011861>, <-1.087840, 12.353939, -1.231124>, <0.006047, 12.557896, -4.517854>, <1.182680, 12.455917, -2.874489>, 
      <-2.188710, 12.337788, 0.389592>, <-0.935449, 13.558597, -0.708803>, <0.000000, 13.520110, -4.250121>, <1.000000, 13.539354, -2.479462>, 
      <-1.946984, 13.541892, 0.642311>, <-0.935449, 14.520811, -0.436509>, <0.000000, 14.482325, -3.977828>, <1.000000, 14.501568, -2.207169>, 
      <-1.855808, 18.064122, 1.538476>, <-1.143599, 22.603056, 0.000000>, <0.000000, 15.444539, -3.705534>, <0.888743, 19.023797, -1.852767>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <2.267557, -18.719157, -8.503830>, <3.106600, -18.109363, -6.856308>, <3.460887, -18.725622, -4.241883>, <5.304773, -18.423852, -4.598634>, 
      <2.290568, -17.755235, -8.549728>, <3.129611, -17.145440, -6.902206>, <3.483898, -17.761699, -4.287781>, <5.327784, -17.459929, -4.644532>, 
      <2.159814, -15.818604, -8.730674>, <2.845094, -14.236101, -7.218199>, <3.506909, -16.797776, -4.333679>, <5.420365, -15.469677, -4.716704>, 
      <1.982677, -13.262575, -8.643466>, <2.746570, -11.957903, -7.021683>, <3.132346, -14.253957, -4.673037>, <5.182704, -13.053008, -4.785896>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.982677, -13.262575, -8.643466>, <2.746570, -11.957903, -7.021683>, <3.132346, -14.253957, -4.673037>, <5.182704, -13.053008, -4.785896>, 
      <1.805539, -10.706546, -8.556258>, <2.648047, -9.679706, -6.825166>, <2.757783, -11.710139, -5.012395>, <4.945044, -10.636338, -4.855089>, 
      <1.914320, -7.094562, -8.289512>, <2.392242, -4.811399, -6.636929>, <3.019693, -9.759672, -4.245366>, <4.845430, -7.226951, -4.439069>, 
      <1.683724, -4.255765, -7.388637>, <2.512871, -2.781786, -5.830790>, <3.535004, -6.258132, -3.959042>, <5.353319, -4.455596, -4.421366>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.683724, -4.255765, -7.388637>, <2.512871, -2.781786, -5.830790>, <3.535004, -6.258132, -3.959042>, <5.353319, -4.455596, -4.421366>, 
      <1.453129, -1.416968, -6.487762>, <2.633500, -0.752173, -5.024652>, <4.050316, -2.756592, -3.672717>, <5.861208, -1.684241, -4.403663>, 
      <1.689574, 0.229170, -6.198334>, <3.106391, 0.402282, -4.821673>, <4.050316, -1.317532, -2.566228>, <5.861208, -0.440015, -3.758165>, 
      <1.701579, 2.200373, -5.794322>, <3.130400, 3.414109, -4.177265>, <4.286762, -0.386953, -2.402611>, <5.979431, 0.464298, -3.599167>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.701579, 2.200373, -5.794322>, <3.130400, 3.414109, -4.177265>, <4.286762, -0.386953, -2.402611>, <5.979431, 0.464298, -3.599167>, 
      <1.713583, 4.171576, -5.390310>, <3.154409, 6.425937, -3.532857>, <4.523207, 0.543626, -2.238995>, <6.097654, 1.368611, -3.440169>, 
      <1.714748, 5.019041, -4.976475>, <3.154409, 7.176537, -2.749060>, <4.523207, 1.487955, -2.072961>, <5.920786, 2.312941, -3.197053>, 
      <1.498902, 5.519134, -4.759506>, <2.970287, 6.670646, -3.166354>, <4.329005, 3.018980, -1.570808>, <5.777136, 3.843965, -2.797114>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.498902, 5.519134, -4.759506>, <2.970287, 6.670646, -3.166354>, <4.329005, 3.018980, -1.570808>, <5.777136, 3.843965, -2.797114>, 
      <1.283056, 6.019228, -4.542538>, <2.786166, 6.164755, -3.583647>, <4.134803, 4.550004, -1.068656>, <5.633486, 5.374990, -2.397174>, 
      <1.249287, 7.558067, -3.598075>, <2.718626, 8.358394, -2.452873>, <4.134803, 5.494333, -0.885020>, <5.599716, 6.948722, -1.738914>, 
      <1.248264, 8.699060, -3.916692>, <2.718626, 9.288690, -2.219731>, <4.101034, 6.966108, -0.223148>, <5.507808, 8.149756, -1.291407>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.248264, 8.699060, -3.916692>, <2.718626, 9.288690, -2.219731>, <4.101034, 6.966108, -0.223148>, <5.507808, 8.149756, -1.291407>, 
      <1.247241, 9.840053, -4.235309>, <2.718626, 10.218985, -1.986588>, <4.067264, 8.437882, 0.438723>, <5.415901, 9.350791, -0.843900>, 
      <1.365360, 11.372481, -3.269516>, <2.718626, 11.149281, -1.753445>, <4.067264, 9.368177, 0.671866>, <4.931612, 10.524298, -0.610757>, 
      <1.182680, 12.455917, -2.874489>, <2.359313, 12.353939, -1.231124>, <4.067264, 10.298473, 0.905008>, <4.732622, 11.470552, -0.238900>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <1.182680, 12.455917, -2.874489>, <2.359313, 12.353939, -1.231124>, <4.067264, 10.298473, 0.905008>, <4.732622, 11.470552, -0.238900>, 
      <1.000000, 13.539354, -2.479462>, <2.000000, 13.558597, -0.708803>, <4.067264, 11.228768, 1.138151>, <4.533632, 12.416807, 0.132957>, 
      <1.000000, 14.501568, -2.207169>, <2.000000, 14.520811, -0.436509>, <3.482413, 12.678597, 1.371294>, <4.241207, 13.622829, 0.385675>, 
      <0.888743, 19.023797, -1.852767>, <1.777487, 22.603056, 0.000000>, <3.000000, 13.640811, 2.668369>, <4.516881, 18.057206, 1.249259>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.304773, -18.423852, -4.598634>, <7.148658, -18.122083, -4.955386>, <9.537783, -19.360753, -6.399679>, <9.872462, -18.888594, -3.323075>, 
      <5.327784, -17.459929, -4.644532>, <7.171669, -17.158160, -5.001284>, <9.560794, -18.396830, -6.445577>, <9.895473, -17.924671, -3.368973>, 
      <5.420365, -15.469677, -4.716704>, <7.333821, -14.141579, -5.099730>, <9.583805, -17.432907, -6.491475>, <9.918484, -16.960748, -3.414871>, 
      <5.182704, -13.053008, -4.785896>, <7.233063, -11.852058, -4.898756>, <9.328130, -14.570905, -6.513730>, <9.781135, -14.012721, -3.350780>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.182704, -13.053008, -4.785896>, <7.233063, -11.852058, -4.898756>, <9.328130, -14.570905, -6.513730>, <9.781135, -14.012721, -3.350780>, 
      <4.945044, -10.636338, -4.855089>, <7.132304, -9.562538, -4.697782>, <9.072455, -11.708903, -6.535985>, <9.643785, -11.064693, -3.286689>, 
      <4.845430, -7.226951, -4.439069>, <6.671167, -4.694231, -4.632772>, <9.545821, -9.353242, -6.190729>, <9.871611, -9.404310, -3.096393>, 
      <5.353319, -4.455596, -4.421366>, <7.171634, -2.653060, -4.883691>, <9.159739, -5.673477, -7.231338>, <10.121285, -5.813657, -4.366068>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.353319, -4.455596, -4.421366>, <7.171634, -2.653060, -4.883691>, <9.159739, -5.673477, -7.231338>, <10.121285, -5.813657, -4.366068>, 
      <5.861208, -1.684241, -4.403663>, <7.672100, -0.611890, -5.134609>, <8.773656, -1.993712, -8.271947>, <10.370959, -2.223005, -5.635743>, 
      <5.861208, -0.440015, -3.758165>, <7.672100, 0.437502, -4.950103>, <9.088917, 0.144108, -7.896071>, <10.528589, -0.501934, -4.879687>, 
      <5.979431, 0.464298, -3.599167>, <7.672100, 1.315550, -4.795723>, <9.088917, 1.074687, -7.732455>, <10.528589, 0.402379, -4.720689>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.979431, 0.464298, -3.599167>, <7.672100, 1.315550, -4.795723>, <9.088917, 1.074687, -7.732455>, <10.528589, 0.402379, -4.720689>, 
      <6.097654, 1.368611, -3.440169>, <7.672100, 2.193597, -4.641343>, <9.088917, 2.005265, -7.568838>, <10.528589, 1.306692, -4.561691>, 
      <5.920786, 2.312941, -3.197053>, <7.318364, 3.137926, -4.321145>, <8.667002, 2.949595, -7.559004>, <10.317632, 2.251021, -4.473757>, 
      <5.777136, 3.843965, -2.797114>, <7.225266, 4.668951, -4.023419>, <8.573904, 4.480619, -7.261278>, <10.084415, 3.782046, -4.055676>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.777136, 3.843965, -2.797114>, <7.225266, 4.668951, -4.023419>, <8.573904, 4.480619, -7.261278>, <10.084415, 3.782046, -4.055676>, 
      <5.633486, 5.374990, -2.397174>, <7.132168, 6.199975, -3.725693>, <8.480805, 6.011644, -6.963551>, <9.851199, 5.313070, -3.637596>, 
      <5.599716, 6.948722, -1.738914>, <7.064628, 8.403110, -2.592808>, <8.480805, 6.993815, -6.195521>, <9.851199, 6.276320, -3.161763>, 
      <5.507808, 8.149756, -1.291407>, <6.914583, 9.333405, -2.359665>, <8.296991, 8.643689, -5.782044>, <9.742407, 7.824382, -2.623574>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <5.507808, 8.149756, -1.291407>, <6.914583, 9.333405, -2.359665>, <8.296991, 8.643689, -5.782044>, <9.742407, 7.824382, -2.623574>, 
      <5.415901, 9.350791, -0.843900>, <6.764539, 10.263701, -2.126523>, <8.113176, 10.293564, -5.368566>, <9.633614, 9.372444, -2.085385>, 
      <4.931612, 10.524298, -0.610757>, <5.795960, 11.680418, -1.893380>, <6.952734, 11.711305, -5.135424>, <9.053393, 10.546462, -1.852243>, 
      <4.732622, 11.470552, -0.238900>, <5.397980, 12.642632, -1.382808>, <6.476367, 13.430984, -4.478540>, <8.152589, 12.932990, -0.862427>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <4.732622, 11.470552, -0.238900>, <5.397980, 12.642632, -1.382808>, <6.476367, 13.430984, -4.478540>, <8.152589, 12.932990, -0.862427>, 
      <4.533632, 12.416807, 0.132957>, <5.000000, 13.604846, -0.872236>, <6.000000, 15.150663, -3.821656>, <7.251785, 15.319517, 0.127389>, 
      <4.241207, 13.622829, 0.385675>, <5.000000, 14.567060, -0.599943>, <6.000000, 16.150663, -3.821656>, <7.127389, 16.278052, 0.127389>, 
      <4.516881, 18.057206, 1.249259>, <6.033763, 22.473601, -0.169851>, <6.000000, 17.150663, -3.821656>, <7.127389, 17.278052, 0.127389>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.872462, -18.888594, -3.323075>, <10.207142, -18.416435, -0.246472>, <12.420688, -18.109363, -2.186693>, <13.728231, -19.074548, -1.473647>, 
      <9.895473, -17.924671, -3.368973>, <10.230153, -17.452512, -0.292370>, <12.443699, -17.145440, -2.232591>, <13.751242, -18.110625, -1.519545>, 
      <9.918484, -16.960748, -3.414871>, <10.253164, -16.488589, -0.338268>, <12.605851, -14.128858, -2.331037>, <13.774253, -17.146703, -1.565443>, 
      <9.781135, -14.012721, -3.350780>, <10.234140, -13.454537, -0.187831>, <12.505062, -11.850595, -2.130001>, <13.623024, -14.549263, -1.796028>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.781135, -14.012721, -3.350780>, <10.234140, -13.454537, -0.187831>, <12.505062, -11.850595, -2.130001>, <13.623024, -14.549263, -1.796028>, 
      <9.643785, -11.064693, -3.286689>, <10.215116, -10.420484, -0.037394>, <12.404273, -9.572331, -1.928966>, <13.471795, -11.951823, -2.026612>, 
      <9.871611, -9.404310, -3.096393>, <10.197400, -9.455377, -0.002056>, <11.405943, -5.133523, -2.135150>, <13.734880, -9.573595, -1.261924>, 
      <10.121285, -5.813657, -4.366068>, <11.082830, -5.953838, -1.500798>, <12.057394, -3.697188, -3.712530>, <13.930270, -6.286805, -3.724523>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.121285, -5.813657, -4.366068>, <11.082830, -5.953838, -1.500798>, <12.057394, -3.697188, -3.712530>, <13.930270, -6.286805, -3.724523>, 
      <10.370959, -2.223005, -5.635743>, <11.968261, -2.452298, -2.999540>, <12.708845, -2.260853, -5.289911>, <14.125661, -3.000014, -6.187122>, 
      <10.528589, -0.501934, -4.879687>, <11.968261, -1.147976, -1.863304>, <12.708845, -0.017970, -4.895562>, <14.125661, -2.262090, -5.290128>, 
      <10.528589, 0.402379, -4.720689>, <11.968261, -0.269929, -1.708924>, <12.708845, 0.860078, -4.741182>, <14.125661, -0.734765, -5.021591>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.528589, 0.402379, -4.720689>, <11.968261, -0.269929, -1.708924>, <12.708845, 0.860078, -4.741182>, <14.125661, -0.734765, -5.021591>, 
      <10.528589, 1.306692, -4.561691>, <11.968261, 0.608118, -1.554544>, <12.708845, 1.738125, -4.586802>, <14.125661, 0.792559, -4.753054>, 
      <10.317632, 2.251021, -4.473757>, <11.968261, 1.552448, -1.388510>, <12.708845, 2.682454, -4.420768>, <14.125661, 1.736888, -4.587020>, 
      <10.084415, 3.782046, -4.055676>, <11.594927, 3.083472, -0.850075>, <12.317691, 4.213479, -4.043069>, <13.990475, 3.267912, -4.218133>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <10.084415, 3.782046, -4.055676>, <11.594927, 3.083472, -0.850075>, <12.317691, 4.213479, -4.043069>, <13.990475, 3.267912, -4.218133>, 
      <9.851199, 5.313070, -3.637596>, <11.221592, 4.614496, -0.311641>, <11.926538, 5.744503, -3.665370>, <13.855290, 4.798937, -3.849247>, 
      <9.851199, 6.276320, -3.161763>, <11.221592, 5.558826, -0.128005>, <11.858998, 7.944388, -2.556628>, <13.855290, 5.663086, -3.665610>, 
      <9.742407, 7.824382, -2.623574>, <11.187823, 7.005075, 0.534895>, <11.858998, 8.874684, -2.323485>, <13.531463, 7.268276, -2.994701>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <9.742407, 7.824382, -2.623574>, <11.187823, 7.005075, 0.534895>, <11.858998, 8.874684, -2.323485>, <13.531463, 7.268276, -2.994701>, 
      <9.633614, 9.372444, -2.085385>, <11.154053, 8.451324, 1.197796>, <11.858998, 9.804979, -2.090343>, <13.207636, 8.873465, -2.323791>, 
      <9.053393, 10.546462, -1.852243>, <11.154053, 9.381619, 1.430938>, <12.107791, 11.149928, -1.857200>, <13.456428, 10.052553, -2.090648>, 
      <8.152589, 12.932990, -0.862427>, <9.828811, 12.434995, 2.753686>, <11.175875, 12.146936, -1.283001>, <12.488753, 12.411708, -1.263400>
    }
  }
  object {
    bicubic_patch { type 1 flatness 0.0100 u_steps 3 v_steps 3,
      <8.152589, 12.932990, -0.862427>, <9.828811, 12.434995, 2.753686>, <11.175875, 12.146936, -1.283001>, <12.488753, 12.411708, -1.263400>, 
      <7.251785, 15.319517, 0.127389>, <8.503569, 15.488371, 4.076433>, <10.243960, 13.143943, -0.708803>, <11.521079, 14.770864, -0.436153>, 
      <7.127389, 16.278052, 0.127389>, <8.254777, 16.405440, 4.076433>, <9.248792, 14.603742, -0.436509>, <11.907406, 15.050089, -0.709159>, 
      <7.127389, 17.278052, 0.127389>, <8.254777, 17.405440, 4.076433>, <10.797790, 24.684825, 0.000000>, <11.409822, 14.768343, -0.436866>
    }
  }
  texture {
                    textex scale <1,10,3>
                  }   
                  


                  translate  <-11.18, -20.280892, 0.0>
                  scale <-1,.46*ycm/100,zplis/3>
  //translate  <0.185073, -20.280892, 0.0>
//  translate  <0.185073, -20.280892, 0.0>
}











        
        
        #declare uniRidAn1 = union {
                union { //tores
                        torus { // Torus007
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30   
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y
                          translate  <9.931574, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus006
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30 
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y
                          translate  <5.73724, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus005
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y 
                          
                          translate  <1.689392, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus004
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30   
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y
                          translate  <-1.186577, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus003
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30      
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y
                          translate  <-4.135789, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus002
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30     
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y
                          translate  <-7.158244, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus001
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30  
                          scale z * (100/xcm)*(nrd/howclosed)
                          rotate -90.0*y 
                          
                          translate  <-10.034213, -0.29297, 0.0>
                        }   
                        translate <11,0,0>
                        
                }// Union tores
                
                
 
                
                //object {RideauFremissant} 
                object {RideauVolant4g}
                translate <-1,0,0>
        scale 100/20 
        scale <xcm*1.2/100,1,1>
        scale <howclosed/nrd,1,1>
                
        
        
        }//Rideaux et anneaux  
        
        
        
        #declare uniRidAn2 = union {
                union { //tores
                        torus { // Torus007
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <9.931574, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus006
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30 
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <5.73724, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus005
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30  
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <1.689392, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus004
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30   
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <-1.186577, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus003
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30      
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <-4.135789, -0.219727, 0.0>
                        }
                        
                        
                        torus { // Torus002
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30  
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <-7.158244, -0.29297, 0.0>
                        }
                        
                        
                        torus { // Torus001
                          1.5, 0.5  rotate -x*90
                          material {
                            Copper_Metal1
                          }
                          scale 0.30 
                          scale z * (100/xcm)*(nrd/(howclosed*1.8))
                          rotate -90.0*y
                          translate  <-10.034213, -0.29297, 0.0>
                        }   
                        translate <11,0,0>
                        
                }// Union tores
                
                

                
                object {RideauVolant4d}
                translate <-1,0,0>
        scale 100/20 
        scale <xcm/100,1,1>
        scale <howclosed*1.8/nrd,1,1>
        no_reflection        
        
        
        }//Rideaux et anneaux
        
        
        union {
                object {tringle}
                
                object {uniRidAn1}   
                
                #if (nrd=2)
                        object{
                                uniRidAn2
                                scale<-1,1,1>
                                translate <xcm,0,0>
                        }
                #end  
                
        }
#end // macro RideauVar






#macro colvariable(fLum, nType, fNorm, scNorm, fTurb, cmpR, cmpV, cmpB, grainCol, scCol, fAmb, fDif, vRotTrans)
#local texVar = texture
                      {      
                         pigment
                         {
                            granite
                            color_map
                            {
                               [ 0.0     rgbft <cmpR, cmpV, cmpB, 0.0, 0.0> * 1 * fLum]
                               [ 0.25    rgbft <cmpR, cmpV, cmpB, 0.0, 0.0> * (1+grainCol/3) * fLum]
                               [ 0.5     rgbft <cmpR, cmpV, cmpB, 0.0, 0.0> * (1-grainCol/2) * fLum]
                               [ 0.75    rgbft <cmpR, cmpV, cmpB, 0.0, 0.0> * (1+grainCol/2) * fLum]
                               [ 1.0     rgbft <cmpR, cmpV, cmpB, 0.0, 0.0> * (1-grainCol/3) * fLum]
                            }
                            frequency 100.0
                            ramp_wave 
                            scale scCol
                         }      
                         normal
                         {
                            #switch (nType)
  #case (1)
        agate
  #break //First case ends
  #case (2)
       crackle
  #break //Second case ends
  #case (3)
        cells
  #break //Third case ends
  #case (4)
       granite
  #break //Fourth case ends
  #else
   // This section is parsed if no other case or
   // range is true.    
       bumps
 #end // End of conditional part nType 
                            
                            ,  fNorm   
                            
                            warp
                            {
                               turbulence fTurb
                               //turbulence <0.02, 0.02, 0.02>
                
                               omega 0.500404
                               lambda 1.999712
                            }  
                            
                            scale scNorm
                         }      
                         finish
                         {
                            ambient fAmb
                            diffuse fDif
                            specular 0.100002
                            roughness 0.5
                         }      
                
                         //  This texture was originally designed by Charles Fusner.
                         rotate vRotTrans.u
                         translate vRotTrans.v

                     } 
                     

 
                     #declare texObj = texVar;
#end //macro 


      




#macro bloctrot(xBloc,zBloc,yBloc, arTrans, arLng, fLum,fNorm,scNorm,fTurb,nType,cmpR,cmpV,cmpB,grainCol,scCol,fAmb,fDif,vRotTrans)    

/*
        #local fLum = 0.8;        // Niveau de luminosit du pigment (rel)
        #local fNorm = .2;            // Force de l'effet de surface     (rel)
        #local scNorm = <1,1,1>;            // Echelle de l'effet de surface   (rel ou vecteur <x,y,z>)
        #local fTurb = .7;            // Force de turbulence d'effet de surface   (rel ou vecteur <x,y,z>) 
        #local nType = 3;            // Type de normale
                                        // 1 = agate, 2 = crackle, 3 = cells, 4 = granite,   ....Autres =  bumps
        
        
        #local cmpR = .65;             // Composante rouge du pigment    (rel)
        #local cmpV = .55;            // Composante Verte du pigment    (rel)
        #local cmpB = .60;            // Composante Bleue du pigment    (rel)
        
        #local grainCol  = .4;        // Force du grain pigment   (rel)
        #local scCol  = <1,1,1>;             // Echelle du grain pigment   (rel ou vecteur <x,y,z>)
        
        #local fAmb  = .3;            //sensibilit Lumire ambiante  (rel)
        #local fDif  = .7;            //sensibilit Lumire diffuse  (rel)
        
        #local vRotTrans = <3,.5>;   // Rotation et translation texture  (vecteur <x,y,z>)   
*/        
        colvariable(fLum, nType, fNorm, scNorm, fTurb, cmpR, cmpV, cmpB, grainCol, scCol, fAmb, fDif, vRotTrans)
        
        
        
        #local xSUni = xBloc / yBloc;
        #local xSelli = (xBloc - yBloc)/ yBloc;
        #local fl = xSelli / 2;
        union {
                superellipsoid { // sqBrique5
                        <arTrans, 0.01> 
                        scale <.5*zBloc/yBloc,.5,fl> 
                        //texture  { texObj }
                }    
                
                
                superellipsoid { // sqBrique5
                        <arTrans, arLng>  
                        scale <.5*zBloc/yBloc,.5,.5>
                        translate <0,0,-fl> 
                        //texture  { texObj }
                }
                superellipsoid { // sqBrique5
                        <arTrans, arLng>  
                        scale <.5*zBloc/yBloc,.5,.5>
                        translate <0,0,fl> 
                        //texture  { texObj }
                } 
                
                #local indsec = 0;
                
                  
                rotate <0,90,0>
                 
                translate <xSUni/2,-.5,-.5*zBloc/yBloc> 
                texture  { texObj }
                scale xBloc/xSUni    
        }
#end





#macro dallecentree(xBloc,zBloc,yBloc, arTrans, arLng, fLum,fNorm,scNorm,fTurb,nType,cmpR,cmpV,cmpB,grainCol,scCol,fAmb,fDif,vRotTrans)    

/*
        #local fLum = 0.8;        // Niveau de luminosit du pigment (rel)
        #local fNorm = .2;            // Force de l'effet de surface     (rel)
        #local scNorm = <1,1,1>;            // Echelle de l'effet de surface   (rel ou vecteur <x,y,z>)
        #local fTurb = .7;            // Force de turbulence d'effet de surface   (rel ou vecteur <x,y,z>) 
        #local nType = 3;            // Type de normale
                                        // 1 = agate, 2 = crackle, 3 = cells, 4 = granite,   ....Autres =  bumps
        
        
        #local cmpR = .65;             // Composante rouge du pigment    (rel)
        #local cmpV = .55;            // Composante Verte du pigment    (rel)
        #local cmpB = .60;            // Composante Bleue du pigment    (rel)
        
        #local grainCol  = .4;        // Force du grain pigment   (rel)
        #local scCol  = <1,1,1>;             // Echelle du grain pigment   (rel ou vecteur <x,y,z>)
        
        #local fAmb  = .3;            //sensibilit Lumire ambiante  (rel)
        #local fDif  = .7;            //sensibilit Lumire diffuse  (rel)
        
        #local vRotTrans = <3,.5>;   // Rotation et translation texture  (vecteur <x,y,z>)   
*/        
        colvariable(fLum, nType, fNorm, scNorm, fTurb, cmpR, cmpV, cmpB, grainCol, scCol, fAmb, fDif, vRotTrans)
        
        
        
        //#local xSUni = xBloc / yBloc;
        //#local xSelli = (xBloc - yBloc)/ yBloc;
        //#local fl = xSelli / 2;
        union {  
                /*
                superellipsoid { // sqBrique5
                        <arTrans, 0.01> 
                        scale <.5*zBloc/yBloc,.5,fl> 
                        //texture  { texObj }
                }    
                */
                
                superellipsoid { // sqBrique5
                        <arTrans, arLng>  
                        scale <xBloc,yBloc,zBloc>*.5
                        translate <0,0,0> 
                        //texture  { texObj }
                }  
                /*
                superellipsoid { // sqBrique5
                        <arTrans, arLng>  
                        scale <.5*zBloc/yBloc,.5,.5>
                        translate <0,0,fl> 
                        //texture  { texObj }
                } 
                */
                
                
                  
                //rotate <0,90,0>
                 
                rotate <90,0,0> 
                texture  { texObj }
                //scale xBloc/xSUni  
        }
#end







#macro curvetop (anglerotz)
  


#declare dlBox = 2 * sin(anglerotz*pi/180);
#declare tpBox = cos(anglerotz*pi/180);
#declare btBox = -1+2*cos(anglerotz*pi/180); 

#if (btBox >= 0)
    #declare btBDif = btBox; 
#else
    #declare btBDif = btBox;
#end
difference {
        union { 
                box{<-dlBox,btBox,-.5>,<dlBox,tpBox,.5>
                         
                }
                cylinder {
                        <0,0,-.5>,<0,0,.5>,1
                        //pigment {color White}
                }
                 
        }
        cylinder {
                <0,0,-.5001>,<0,0,.5001>,1
                translate y*2 
                rotate z*anglerotz
                //pigment {color White}
        }
        cylinder {
                <0,0,-.5001>,<0,0,.5001>,1
                translate y*2 
                rotate -z*anglerotz
                //pigment {color White}
        } 
        #if (btBox >= 0)

 
                box{<-1.001,-1.001,-.5001>,<1.001,btBox,.5001>
                     pigment {color Green}         
                }
        #end
        scale <1/dlBox,1/dlBox,1>         
        translate -y*btBox*1/dlBox    
        rotate x *0
        pigment {color Green}
}    
#end //macro curv top





























#macro coindemur(eCoin, yCoin, eMortier,debord, xBlocMin, xBlocMax, yBlocMin, yBlocMax, arTrans, arLng, aleColBloc,alePosBloc, alearnSec,seedCoin, fLumBas, fLumHaut, fNorm,scNorm,fTurb,nType,cmpR,cmpV,cmpB,grainCol,scCol,fAmb,fDif,vRotTrans,pStart)    

/*
        #local fLum = 0.8;        // Niveau de luminosit du pigment (rel)
        #local fNorm = .2;            // Force de l'effet de surface     (rel)
        #local scNorm = <1,1,1>;            // Echelle de l'effet de surface   (rel ou vecteur <x,y,z>)
        #local fTurb = .7;            // Force de turbulence d'effet de surface   (rel ou vecteur <x,y,z>) 
        #local nType = 3;            // Type de normale
                                        // 1 = agate, 2 = crackle, 3 = cells, 4 = granite,   ....Autres =  bumps
        
        
        #local cmpR = .65;             // Composante rouge du pigment    (rel)
        #local cmpV = .55;            // Composante Verte du pigment    (rel)
        #local cmpB = .60;            // Composante Bleue du pigment    (rel)
        
        #local grainCol  = .4;        // Force du grain pigment   (rel)
        #local scCol  = <1,1,1>;             // Echelle du grain pigment   (rel ou vecteur <x,y,z>)
        
        #local fAmb  = .3;            //sensibilit Lumire ambiante  (rel)
        #local fDif  = .7;            //sensibilit Lumire diffuse  (rel)
        
        #local vRotTrans = <3,.5>;   // Rotation et translation texture  (vecteur <x,y,z>)   
*/        
        
        
        #local R1 = seed(seedCoin);
        
        #local dxBloc  =  xBlocMax - xBlocMin;
        #local dyBloc  =  yBlocMax - yBlocMin;  
        
        #local mxBloc  =  (xBlocMax + xBlocMin) / 2;
        #local myBloc  =  (yBlocMax + yBlocMin) / 2;    
        
        #local dfCol = fLumHaut-fLumBas;
        
        
        #local dPosBloc = eMortier *  2 * alePosBloc; 
        
         
        #local nBlocY = yCoin / (myBloc+eMortier);  
        
        #local posY = 0;
        #local flagRot = pStart;  
        
        #local coinProv = union{
                # while  (posY < yCoin -yBlocMax ) 
                        #warning concat("row ",str(posY,0,0),"\n")
                        #local fLum = fLumBas + dfCol * posY / yCoin;
                        #local xBloc = xBlocMin +rand(R1) * dxBloc;
                        #local yBloc = yBlocMin +rand(R1) * dyBloc;  
                        
                        #local zBloc = eCoin;
                        
                        //colvariable(fLum, nType, fNorm, scNorm, fTurb, cmpR, cmpV, cmpB, grainCol, scCol, fAmb, fDif, vRotTrans)
                                          //fNorm, scNorm, fTurb, nType,cmpR,cmpV, cmpB, grainCol, scCol, fAmb, fDif, vRotTrans) 
                                          
                        #declare cmpRt = cmpR -aleColBloc/2 +aleColBloc * rand(R1);
                        #declare cmpVt = cmpV -aleColBloc/2 +aleColBloc * rand(R1);
                        #declare cmpBt = cmpB -aleColBloc/2 +aleColBloc * rand(R1);                                          
                                          
                        
                        #declare bloc=bloctrot(xBloc,zBloc,yBloc, arTrans, arLng, fLum,fNorm,scNorm,fTurb,nType,cmpRt,cmpVt,cmpBt,grainCol,scCol,fAmb,fDif,vRotTrans)                                      
                        
                        #if (flagRot = 1)
                              #local flagRot = 0;
                              object {bloc rotate  -y * 90  translate <xBloc * alePosBloc*rand(R1), posY+yBloc* (1+alePosBloc*rand(R1)),-debord + zBloc * alePosBloc*rand(R1)>}
                        #else 
                             #local flagRot = 1;
                             object {bloc translate z*eCoin translate <-debord + xBloc * alePosBloc*rand(R1), posY+yBloc* (1+alePosBloc*rand(R1)), zBloc * alePosBloc*rand(R1)>}
                        #end   
                        
                        #local posY  =  posY +yBloc +eMortier*(1+alePosBloc);  
                        
                          
                  
                #end // While posY bloc 
        }// Union coinProv                                        
        #local coin = object{coinProv scale <1,yCoin/posY,1>}  
        object{coin}
#end
